import { useState } from "react";
import { Icon } from "shared/assets/icons";
import {
  MODAL_NAMES,
  MODAL_TYPES,
  useModalStore,
} from "shared/stores/modal-store";
import {
  Button,
  IconButton,
  Input,
  Tooltip,
  Typography,
} from "shared/ui/components";
import { CustomModal } from "shared/ui/templates";

export function AccountBlocking() {
  const store = useModalStore();
  const [value, setValue] = useState("");

  function onBlocking() {
    console.log("onBlocking: ", store.modalData?.fio);
  }

  return (
    <CustomModal
      title={MODAL_NAMES.AccountBlocking}
      open={!!store.openModalType}
      handleClose={store.actions.closeModal}
      actions={
        <>
          <Button color="error" disabled={!value} onClick={onBlocking}>
            Заблокировать
          </Button>
          <Button color="secondary" onClick={() => store.actions.closeModal()}>
            Отмена
          </Button>
        </>
      }
    >
      <Typography variant="body2">
        Вы уверены, что хотите заблокировать учетную запись&nbsp;
        <b>{store.modalData?.fio}</b>?
      </Typography>
      <Input
        label="Причина блокировки"
        placeholder="Злоупотребление служебными полномочиями"
        value={value}
        onChange={(event) => setValue(event.target.value)}
      />
    </CustomModal>
  );
}
type IconButtonAccountBlocking = {
  show: boolean;
  data: any;
};
export function IconButtonAccountBlocking(props: IconButtonAccountBlocking) {
  const { data, show } = props;
  const store = useModalStore();

  if (!show) return null;

  return (
    <Tooltip title={MODAL_NAMES.AccountBlocking}>
      <IconButton
        onClick={() =>
          store.actions.showModal(MODAL_TYPES.AccountBlocking, data)
        }
      >
        <Icon.Lock />
      </IconButton>
    </Tooltip>
  );
}
