import { zodResolver } from "@hookform/resolvers/zod";
import { useForm } from "react-hook-form";
import { Box, Button } from "shared/ui/components";
import { Form } from "shared/ui/form";
import { FormFieldText } from "shared/ui/form/Input";
import { z } from "zod";

const schema = z.object({
  fio: z.string().min(1, { message: "Это поле обязательно" }),
  name: z.string().min(1, { message: "Это поле обязательно" }),
  lastName: z.string().min(1, { message: "Это поле обязательно" }),
  email: z
    .string()
    .min(1, { message: "Это поле обязательно" })
    .email("Не корректный email"),
});

type FormData = z.infer<typeof schema>;

export type CreateAnAccountProps = {
  onSubmit: (data: FormData) => void;
  onCancel: () => void;
};
export function CreateAnAccount(props: CreateAnAccountProps) {
  const {
    handleSubmit,
    control,
    formState: { isValid },
  } = useForm<FormData>({
    defaultValues: { email: "", fio: "", lastName: "", name: "" },
    resolver: zodResolver(schema),
  });

  return (
    <Form onSubmit={handleSubmit(props.onSubmit)}>
      <FormFieldText control={control} name="fio" label="Фамилия" required />
      <FormFieldText control={control} name="name" label="Имя" required />
      <FormFieldText
        control={control}
        name="lastName"
        label="Отчество"
        required
      />
      <FormFieldText control={control} name="email" label="E-mail" required />
      <Box sx={{ display: "flex", gap: 2 }}>
        <Button disabled={!isValid} type="submit" color="primary">
          Создать
        </Button>
        <Button onClick={props.onCancel} color="secondary">
          Отмена
        </Button>
      </Box>
    </Form>
  );
}
