import { Icon } from "shared/assets/icons";
import {
  MODAL_NAMES,
  MODAL_TYPES,
  useModalStore,
} from "shared/stores/modal-store";
import { Button, IconButton, Tooltip, Typography } from "shared/ui/components";
import { CustomModal } from "shared/ui/templates";

export function DeleteAccount() {
  const store = useModalStore();

  function onDelete() {
    console.log("onDelete: ", store.modalData?.fio);
  }

  return (
    <CustomModal
      title={MODAL_NAMES.DeleteAccount}
      open={!!store.openModalType}
      handleClose={store.actions.closeModal}
      actions={
        <>
          <Button color="error" onClick={onDelete}>
            Удалить
          </Button>
          <Button color="secondary" onClick={() => store.actions.closeModal()}>
            Отмена
          </Button>
        </>
      }
    >
      <Typography variant="body2">
        Вы уверены, что хотите удалить учетную запись&nbsp;
        <b>{store.modalData?.fio}</b>?
      </Typography>
    </CustomModal>
  );
}

type IconButtonDeleteAccount = {
  show: boolean;
  data: any;
};
export function IconButtonDeleteAccount(props: IconButtonDeleteAccount) {
  const { data, show } = props;
  const store = useModalStore();

  if (!show) return null;

  return (
    <Tooltip title={MODAL_NAMES.DeleteAccount}>
      <IconButton
        onClick={() => store.actions.showModal(MODAL_TYPES.DeleteAccount, data)}
        color="error"
      >
        <Icon.Delete color="error" />
      </IconButton>
    </Tooltip>
  );
}
