import { Icon } from "shared/assets/icons";
import { DEVICE_STATUS_ID, DEVICE_STATUS_TYPES } from "shared/constants/device";
import { useDeviceChangeStatus } from "shared/queries/devices";
import {
  MODAL_NAMES,
  MODAL_TYPES,
  useModalStore,
} from "shared/stores/modal-store";
import { Button, IconButton, Tooltip, Typography } from "shared/ui/components";
import { CustomModal } from "shared/ui/templates";

export function DisablingDevice() {
  const store = useModalStore();
  const changeStatus = useDeviceChangeStatus();

  async function off() {
    console.log("off");
    await changeStatus.mutateAsync({
      deviceId: store.modalData.id,
      status: DEVICE_STATUS_ID[DEVICE_STATUS_TYPES.Disabled],
    });
    store.actions.closeModal();
  }

  return (
    <CustomModal
      title={MODAL_NAMES.DisablingDevice}
      open={!!store.openModalType}
      handleClose={() => store.actions.closeModal()}
      actions={
        <>
          <Button color="error" onClick={() => off()}>
            Отключить
          </Button>
          <Button color="secondary" onClick={() => store.actions.closeModal()}>
            Отмена
          </Button>
        </>
      }
    >
      <Typography variant="body2">
        Вы уверены, что хотите отключить устройство{" "}
        <b>
          {store.modalData?.model}, uuid {store.modalData?.uuid}
        </b>
        ?
      </Typography>
    </CustomModal>
  );
}

type IconButtonDisablingDevice = {
  show: boolean;
  data: any;
};
export function IconButtonDisablingDevice(props: IconButtonDisablingDevice) {
  const { data, show } = props;
  const store = useModalStore();

  if (!show) return null;

  return (
    <Tooltip title="Отключить">
      <IconButton
        onClick={() =>
          store.actions.showModal(MODAL_TYPES.DisablingDevice, data)
        }
      >
        <Icon.Power />
      </IconButton>
    </Tooltip>
  );
}
