import { useState } from "react";

import { useForm } from "react-hook-form";
import { z } from "zod";
import { zodResolver } from "@hookform/resolvers/zod";

import { Box, Button, Typography } from "shared/ui/components";
import { Form } from "shared/ui/form";
import { FormFieldText } from "shared/ui/form/Input";
import { CustomModal, PrimarySecondaryText } from "shared/ui/templates";

const schema = z.object({
  fio: z.string().min(1, { message: "Это поле обязательно" }),
  name: z.string().min(1, { message: "Это поле обязательно" }),
  lastName: z.string().min(1, { message: "Это поле обязательно" }),
  email: z
    .string()
    .min(1, { message: "Это поле обязательно" })
    .email("Не корректный email"),
});

type FormData = z.infer<typeof schema>;

export type EditAccountProps = {
  onSubmit: (data: FormData) => void;
  onCancel: () => void;
  data: FormData;
};
export function EditAccount(props: EditAccountProps) {
  const { data, onCancel, onSubmit } = props;
  const [open, setOpen] = useState(false);
  const [generated, setGenerated] = useState("");
  const {
    handleSubmit,
    control,
    formState: { isValid },
  } = useForm<FormData>({
    defaultValues: data,
    resolver: zodResolver(schema),
  });

  function onGenerate() {
    console.log("onGenerate");
    setGenerated("XXds#33_1");
    handleClose();
  }

  function handleClose() {
    setOpen(false);
  }

  return (
    <Form onSubmit={handleSubmit(onSubmit)}>
      <FormFieldText control={control} name="fio" label="Фамилия" />
      <FormFieldText control={control} name="name" label="Имя" />
      <FormFieldText control={control} name="lastName" label="Отчество" />
      <FormFieldText control={control} name="email" label="E-mail" />
      <Button variant="outlined" color="primary" onClick={() => setOpen(true)}>
        Сгенерировать временный пароль
      </Button>
      {generated && (
        <PrimarySecondaryText
          primary={generated}
          secondary="Временный пароль"
          variant="firstSecondary"
        />
      )}
      <Box sx={{ display: "flex", gap: 2 }}>
        <Button disabled={!isValid} type="submit" color="primary">
          Создать
        </Button>
        <Button onClick={onCancel} color="secondary">
          Отмена
        </Button>
      </Box>
      <CustomModal
        open={open}
        handleClose={handleClose}
        title="Генерация пароля"
        actions={
          <>
            <Button color="primary" onClick={onGenerate}>
              Сгенерировать
            </Button>
            <Button onClick={handleClose} color="secondary">
              Отмена
            </Button>
          </>
        }
      >
        <Typography variant="body2">
          Вы уверены, что хотите сгенерировать новый временный пароль для
          учетной записи {data.fio}?
        </Typography>
        <Typography variant="body2">
          Это приведет к завершению сессии на устройстве пользователя и сбросу
          старого пароля от учетной записи пользователя.
        </Typography>
      </CustomModal>
    </Form>
  );
}
