import { zodResolver } from "@hookform/resolvers/zod";
import { useForm } from "react-hook-form";
import { z } from "zod";

import { Icon } from "shared/assets/icons";
import { DEVICE_TYPE_ID } from "shared/constants/device";
import { useUpdateDevice } from "shared/queries/devices";
import { useDeviceHalls } from "shared/queries/halls";
import {
  MODAL_NAMES,
  MODAL_TYPES,
  useModalStore,
} from "shared/stores/modal-store";
import { ValueOf } from "shared/types";
import { Box, Button, IconButton, Tooltip } from "shared/ui/components";
import { Form } from "shared/ui/form";
import { FormFieldSelect, FormFieldText } from "shared/ui/form/Input";
import { CustomModal, PrimarySecondaryText } from "shared/ui/templates";

const schema = z.object({
  manufacturer: z.string(),
  model: z.string(),
  hallId: z.string(),
});

type FormData = z.infer<typeof schema>;

type EditDeviceProps = {
  deviceType: ValueOf<typeof DEVICE_TYPE_ID>;
};
export function EditDevice(props: EditDeviceProps) {
  const { deviceType } = props;
  const store = useModalStore();
  const halls = useDeviceHalls(deviceType);
  const updateDevice = useUpdateDevice();

  const { control, handleSubmit } = useForm<FormData>({
    defaultValues: {
      hallId: store.modalData?.hallId ?? "",
      manufacturer: store.modalData?.manufacturer ?? "",
      model: store.modalData?.model ?? "",
    },
    resolver: zodResolver(schema),
  });

  async function save(data: FormData) {
    const { manufacturer, model, hallId } = data;

    await updateDevice.mutateAsync({
      deviceId: store.modalData.id,
      manufacturer,
      model,
      hallId,
    });
    store.actions.closeModal();
  }

  return (
    <CustomModal
      title={MODAL_NAMES.EditDevice}
      open={!!store.openModalType}
      handleClose={() => store.actions.closeModal()}
    >
      <PrimarySecondaryText
        secondary="Uuid"
        primary={store.modalData.uuid}
        variant="firstSecondary"
      />
      <Form onSubmit={handleSubmit(save)}>
        <FormFieldText
          control={control}
          name="manufacturer"
          label="Производитель"
        />
        <FormFieldText control={control} name="model" label="Модель" />
        {deviceType !== 2 ? (
          <FormFieldSelect
            control={control}
            name="hallId"
            label="Номер зала"
            options={halls.data}
            required
          />
        ) : null}

        <Box sx={{ display: "flex", alignItems: "center", gap: 2 }}>
          <Button color="primary" type="submit">
            Сохранить
          </Button>
          <Button color="secondary" onClick={() => store.actions.closeModal()}>
            Отмена
          </Button>
        </Box>
      </Form>
    </CustomModal>
  );
}

type IconButtonEditDevice = {
  show: boolean;
  data: any;
};
export function IconButtonEditDevice(props: IconButtonEditDevice) {
  const { data, show } = props;
  const store = useModalStore();

  if (!show) return null;

  return (
    <Tooltip title="Редактировать">
      <IconButton
        onClick={() => store.actions.showModal(MODAL_TYPES.EditDevice, data)}
      >
        <Icon.EditIcon />
      </IconButton>
    </Tooltip>
  );
}

("Validation failed for argument [0] in public org.springframework.http.ResponseEntity<java.lang.Void> ru.avilex.session.controller.DeviceController.updateDevice(ru.avilex.session.dto.request.DeviceUpdateRequestDTO): [Field error in object 'deviceUpdateRequestDTO' on field 'deviceId': rejected value [null]; codes [NotNull.deviceUpdateRequestDTO.deviceId,NotNull.deviceId,NotNull.java.util.UUID,NotNull]; arguments [org.springframework.context.support.DefaultMessageSourceResolvable: codes [deviceUpdateRequestDTO.deviceId,deviceId]; arguments []; default message [deviceId]]; default message [не должно равняться null]] ");
