import { Icon } from "shared/assets/icons";
import { HALL_ACTIONS_STATUS_ID } from "shared/constants/hall";
import { useChangeStatusHall } from "shared/queries/halls";
import {
  MODAL_NAMES,
  MODAL_TYPES,
  useModalStore,
} from "shared/stores/modal-store";
import { Button, IconButton, Tooltip, Typography } from "shared/ui/components";
import { CustomModal } from "shared/ui/templates";

export function EndHallSession() {
  const store = useModalStore();
  const changeStatusHall = useChangeStatusHall();

  async function onEndHallSession() {
    await changeStatusHall.mutateAsync({
      deviceHallId: store.modalData?.id,
      status: HALL_ACTIONS_STATUS_ID.Logout,
    });
    store.actions.closeModal();
  }

  return (
    <CustomModal
      title={MODAL_NAMES.EndHallSession}
      open={!!store.openModalType}
      handleClose={store.actions.closeModal}
      actions={
        <>
          <Button color="error" onClick={onEndHallSession}>
            Завершить сессию
          </Button>
          <Button color="secondary" onClick={() => store.actions.closeModal()}>
            Отмена
          </Button>
        </>
      }
    >
      <Typography variant="body2">
        Вы Вы уверены, что хотите завершить сессию зала&nbsp;
        <b>{store.modalData?.numberHall}</b>?
      </Typography>
    </CustomModal>
  );
}

type IconButtonEndHallSession = {
  show: boolean;
  data: any;
};
export function IconButtonEndHallSession(props: IconButtonEndHallSession) {
  const { data, show } = props;
  const store = useModalStore();

  if (!show) return null;

  return (
    <Tooltip title={MODAL_NAMES.EndHallSession}>
      <IconButton
        onClick={() =>
          store.actions.showModal(MODAL_TYPES.EndHallSession, data)
        }
      >
        <Icon.Logout />
      </IconButton>
    </Tooltip>
  );
}
