import { useState } from "react";
import { Icon } from "shared/assets/icons";
import { HALL_ACTIONS_STATUS_ID } from "shared/constants/hall";
import { useChangeStatusHall } from "shared/queries/halls";
import {
  MODAL_NAMES,
  MODAL_TYPES,
  useModalStore,
} from "shared/stores/modal-store";
import {
  Button,
  IconButton,
  Input,
  Tooltip,
  Typography,
} from "shared/ui/components";
import { CustomModal } from "shared/ui/templates";

export function HallBlocking() {
  const store = useModalStore();
  const [blockReason, setBlockReason] = useState("");
  const changeStatusHall = useChangeStatusHall();

  async function onBlocking() {
    await changeStatusHall.mutateAsync({
      deviceHallId: store.modalData?.id,
      status: HALL_ACTIONS_STATUS_ID.Blocked,
      blockReason,
    });
    store.actions.closeModal();
  }

  return (
    <CustomModal
      title={MODAL_NAMES.HallBlocking}
      open={!!store.openModalType}
      handleClose={store.actions.closeModal}
      actions={
        <>
          <Button color="error" onClick={onBlocking}>
            Заблокировать
          </Button>
          <Button color="secondary" onClick={() => store.actions.closeModal()}>
            Отмена
          </Button>
        </>
      }
    >
      <Typography variant="body2">
        Вы уверены, что хотите заблокировать зал&nbsp;
        <b>{store.modalData?.mumberHall}</b>?
      </Typography>
      <Input
        label="Причина блокировки"
        placeholder="Зал на ремонте"
        value={blockReason}
        onChange={(event) => setBlockReason(event.target.value)}
      />
    </CustomModal>
  );
}
type IconButtonHallBlocking = {
  show: boolean;
  data: any;
};
export function IconButtonHallBlocking(props: IconButtonHallBlocking) {
  const { data, show } = props;
  const store = useModalStore();

  if (!show) return null;

  return (
    <Tooltip title={MODAL_NAMES.HallBlocking}>
      <IconButton
        onClick={() => store.actions.showModal(MODAL_TYPES.HallBlocking, data)}
      >
        <Icon.Lock />
      </IconButton>
    </Tooltip>
  );
}
