import { useForm } from "react-hook-form";

import { z } from "zod";
import { zodResolver } from "@hookform/resolvers/zod";

import { Button, Spinner } from "shared/ui/components";
import { Form } from "shared/ui/form";
import { FormFieldPassowrd, FormFieldText } from "shared/ui/form/Input";
import { styled } from "@mui/material";

const schema = z.object({
  email: z
    .string()
    .min(1, { message: "Это поле обязательно" })
    .email("Не корректный email"),
  password: z.string().min(1, { message: "Это поле обязательно" }),
});

type FormData = z.infer<typeof schema>;

export type SignInFormProps = {
  onSubmit: (data: FormData) => Promise<void>;
};
export function SignInForm(props: SignInFormProps) {
  const {
    handleSubmit,
    control,
    formState: { isDirty, isSubmitting },
  } = useForm<FormData>({
    defaultValues: { email: "", password: "" },
    resolver: zodResolver(schema),
  });

  async function onSubmit(data: FormData) {
    await props.onSubmit(data);
  }

  return (
    <Form onSubmit={handleSubmit(onSubmit)} autoComplete="off">
      <FormFieldText
        disabled={isSubmitting}
        control={control}
        name="email"
        label="E-mail"
        required
      />
      <FormFieldPassowrd
        disabled={isSubmitting}
        control={control}
        name="password"
        label="Пароль"
        required
        type="password"
      />
      <Button disabled={!isDirty || isSubmitting} type="submit">
        <TextWrapper>
          Войти
          {isSubmitting && (
            <Spinner
              sx={{
                position: "absolute",
                top: "50%",
                right: (theme) => `calc(0px - ${theme.spacing(2)})`,
                transform: "translate(50%, -50%)",
              }}
            />
          )}
        </TextWrapper>
      </Button>
    </Form>
  );
}

const TextWrapper = styled("div")(({ theme }) => {
  return {
    position: "relative",
    display: "flex",
    gap: theme.spacing(2),
    alignItems: "center",
  };
});
