import { Icon } from "shared/assets/icons";
import { DEVICE_STATUS_ID, DEVICE_STATUS_TYPES } from "shared/constants/device";
import { useDeviceChangeStatus } from "shared/queries/devices";
import {
  MODAL_NAMES,
  MODAL_TYPES,
  useModalStore,
} from "shared/stores/modal-store";
import { Button, IconButton, Tooltip, Typography } from "shared/ui/components";
import { CustomModal } from "shared/ui/templates";

export function TurningDevice() {
  const store = useModalStore();
  const changeStatus = useDeviceChangeStatus();

  async function on() {
    console.log("on: prev");
    await changeStatus.mutateAsync({
      deviceId: store.modalData.id,
      status: DEVICE_STATUS_ID[DEVICE_STATUS_TYPES.Actively],
    });
    console.log("on: post");
    store.actions.closeModal();
  }

  return (
    <CustomModal
      title={MODAL_NAMES.TurningDevice}
      open={!!store.openModalType}
      handleClose={() => store.actions.closeModal()}
      actions={
        <>
          <Button color="primary" onClick={() => on()}>
            Включить
          </Button>
          <Button color="secondary" onClick={() => store.actions.closeModal()}>
            Отмена
          </Button>
        </>
      }
    >
      <Typography variant="body2">
        Вы уверены, что хотите включить устройство{" "}
        <b>
          {store.modalData?.model}, uuid {store.modalData?.uuid}
        </b>
        ?
      </Typography>
    </CustomModal>
  );
}

type IconButtonTurningDevice = {
  show: boolean;
  data: any;
};
export function IconButtonTurningDevice(props: IconButtonTurningDevice) {
  const { data, show } = props;
  const store = useModalStore();

  if (!show) return null;

  return (
    <Tooltip title="Включить">
      <IconButton
        onClick={() => store.actions.showModal(MODAL_TYPES.TurningDevice, data)}
      >
        <Icon.Power />
      </IconButton>
    </Tooltip>
  );
}
