import { useState } from "react";
import { Icon } from "shared/assets/icons";
import {
  MODAL_NAMES,
  MODAL_TYPES,
  useModalStore,
} from "shared/stores/modal-store";
import {
  Button,
  IconButton,
  Input,
  Tooltip,
  Typography,
} from "shared/ui/components";
import { CustomModal, PrimarySecondaryText } from "shared/ui/templates";

export function UnlockAccount() {
  const store = useModalStore();
  const [value, setValue] = useState("");

  function onUnlock() {
    console.log("onBlocking: ", store.modalData?.fio);
  }

  return (
    <CustomModal
      title={MODAL_NAMES.UnlockAccount}
      open={!!store.openModalType}
      handleClose={store.actions.closeModal}
      actions={
        <>
          <Button color="primary" onClick={onUnlock}>
            Разблокировать
          </Button>
          <Button color="secondary" onClick={() => store.actions.closeModal()}>
            Отмена
          </Button>
        </>
      }
    >
      <Typography variant="body2">
        Вы уверены, что хотите разблокировать учетную запись&nbsp;
        <b>{store.modalData?.fio}</b>?
      </Typography>
      <PrimarySecondaryText
        primary={store.modalData?.description}
        secondary="Причина блокировки"
        variant="firstSecondary"
      />
      <Input
        label="Причина разблокировки"
        placeholder="Судья исправился и принес извинения"
        value={value}
        onChange={(event) => setValue(event.target.value)}
      />
    </CustomModal>
  );
}
type IconButtonUnlockAccount = {
  show: boolean;
  data: any;
};
export function IconButtonUnlockAccount(props: IconButtonUnlockAccount) {
  const { data, show } = props;
  const store = useModalStore();

  if (!show) return null;

  return (
    <Tooltip title={MODAL_NAMES.UnlockAccount}>
      <IconButton
        onClick={() => store.actions.showModal(MODAL_TYPES.UnlockAccount, data)}
      >
        <Icon.LockOpen />
      </IconButton>
    </Tooltip>
  );
}
