import { Icon } from "shared/assets/icons";
import { HALL_ACTIONS_STATUS_ID } from "shared/constants/hall";
import { useChangeStatusHall } from "shared/queries/halls";
import {
  MODAL_NAMES,
  MODAL_TYPES,
  useModalStore,
} from "shared/stores/modal-store";
import { Button, IconButton, Tooltip, Typography } from "shared/ui/components";
import { CustomModal, PrimarySecondaryText } from "shared/ui/templates";

export function UnlockHall() {
  const store = useModalStore();
  const changeStatusHall = useChangeStatusHall();

  async function onUnlock() {
    await changeStatusHall.mutateAsync({
      deviceHallId: store.modalData?.id,
      status: HALL_ACTIONS_STATUS_ID.Logout,
    });
    store.actions.closeModal();
  }

  return (
    <CustomModal
      title={MODAL_NAMES.UnlockHall}
      open={!!store.openModalType}
      handleClose={store.actions.closeModal}
      actions={
        <>
          <Button color="primary" onClick={onUnlock}>
            Разблокировать
          </Button>
          <Button color="secondary" onClick={() => store.actions.closeModal()}>
            Отмена
          </Button>
        </>
      }
    >
      <Typography variant="body2">
        Вы уверены, что хотите разблокировать зал&nbsp;
        <b>{store.modalData?.numberHall}</b>?
      </Typography>
      <PrimarySecondaryText
        primary={store.modalData?.reasonBlocking}
        secondary="Причина блокировки"
        variant="firstSecondary"
      />
    </CustomModal>
  );
}
type IconButtonUnlockHall = {
  show: boolean;
  data: any;
};
export function IconButtonUnlockHall(props: IconButtonUnlockHall) {
  const { data, show } = props;
  const store = useModalStore();

  if (!show) return null;

  return (
    <Tooltip title={MODAL_NAMES.UnlockHall}>
      <IconButton
        onClick={() => store.actions.showModal(MODAL_TYPES.UnlockHall, data)}
      >
        <Icon.LockOpen />
      </IconButton>
    </Tooltip>
  );
}
