import { usePagination } from "shared/stores/pagination";
import {
  useTableSorting,
  withProviderTableSorting,
} from "shared/stores/table-sorting";
import { Box, Table, Tooltip, Typography } from "shared/ui/components";

import { IconButtonEditHallCards } from "features/edit-hall-cards/EditHallCards";
import { IconButtonEndHallSession } from "features/end-hall-session/EndHallSession";
import { IconButtonHallBlocking } from "features/hall-blocking/HallBlocking";
import { IconButtonUnlockHall } from "features/unlocking-hall/UnlockHall";
import { Icon } from "shared/assets/icons";
import { HALL_ACTIVE_STATUS, HALL_STATUS_ID } from "shared/constants/hall";
import { useGetTableHalls } from "shared/queries/halls";
import { HallEntity } from "shared/types/halls/entities/hall";

function HallsTableComponent() {
  const tableSorting = useTableSorting();
  const pagination = usePagination();

  const judges = useGetTableHalls({
    page: pagination.page,
    size: pagination.pageSize,
  });

  return (
    <Table
      loading={judges.isLoading}
      columns={COLUMNS}
      rows={judges.data?.items ?? []}
      pagination={{
        page: pagination.page,
        pageSize: pagination.pageSize,
        rowCount: judges.data?.rowCount ?? 0,
        onPageChange: pagination.updatePage,
        onPageSizeChange: pagination.updatePageSize,
      }}
      sorting={{
        onOrederChange: ({ name, value }) =>
          tableSorting.handleSortingChange(name, value),
        order: tableSorting.order,
        orderBy: tableSorting.key,
      }}
    />
  );
}

export const HallsTable = withProviderTableSorting(HallsTableComponent);

export const COLUMNS = [
  {
    field: "hallNumber",
    headerName: "Номер зала",
    renderCell: (row: HallEntity) => {
      // null приходит в виде строки oO
      const hallNaumber = row?.hallNumber === "null" ? "" : row?.hallNumber;
      return (
        <Box sx={{ display: "flex", gap: 1, alignItems: "center" }}>
          {hallNaumber}
          {row?.reasonBlocking && (
            <Tooltip
              title={
                <Typography variant="caption">{row.reasonBlocking}</Typography>
              }
              placement="right"
            >
              <Icon.Info svgProps={{ color: "secondary" }} />
            </Tooltip>
          )}
        </Box>
      );
    },
  },
  { field: "tablet", headerName: "Планшет" },
  { field: "tv", headerName: "Телевизор" },
  { field: "note", headerName: "Примечание" },
  {
    field: "actions",
    renderCell: (row: HallEntity) => {
      return (
        <Box
          sx={{
            display: "flex",
            alignItems: "center",
            justifyContent: "end",
          }}
        >
          <IconButtonEditHallCards data={row} show />
          <IconButtonHallBlocking
            data={row}
            show={HALL_ACTIVE_STATUS[row.statusId]}
          />
          <IconButtonEndHallSession
            data={row}
            show={
              HALL_ACTIVE_STATUS[row.statusId] &&
              row.statusId !== HALL_STATUS_ID.Logout
            }
          />
          <IconButtonUnlockHall
            data={row}
            show={
              row.statusId === HALL_STATUS_ID.Blocked ||
              row.statusId === HALL_STATUS_ID.BlockedByPin
            }
          />
        </Box>
      );
    },
  },
];
