import { Navigate, Outlet, Route, Routes } from "react-router-dom";

import { useAppStore } from "shared/stores/app-store";

import { ErrorPage } from "./error";
import { SignInPage } from "./sign-in";
import { JudgesPage } from "./judges";
import { HallsPage } from "./halls";
import { TabletsPage } from "./tablets";
import { TelevisionsInTheGeneralCourtroomPage } from "./televisions-in-the-general-courtroom";
import { TelevisionsNearTheCourtroomPage } from "./televisions-near-the-courtroom";
import { AuthLayout, ErrorLayout, GeneralLayout } from "shared/ui/templates";

export const Routing = () => {
  const store = useAppStore();

  return (
    <Routes>
      <Route
        path="auth"
        element={
          <ProtectedRoute isAllowed={!store.isAuth} redirectPath="/tablets">
            <AuthLayout>
              <Outlet />
            </AuthLayout>
          </ProtectedRoute>
        }
      >
        <Route path="sign_in" element={<SignInPage />} />
      </Route>

      <Route
        path="error"
        element={
          <ErrorLayout>
            <Outlet />
          </ErrorLayout>
        }
      >
        <Route path=":code" element={<ErrorPage />} />
      </Route>

      <Route
        element={
          <ProtectedRoute isAllowed={store.isAuth}>
            <GeneralLayout>
              <Outlet />
            </GeneralLayout>
          </ProtectedRoute>
        }
      >
        <Route path="judges" element={<JudgesPage />} />
        <Route path="tablets" element={<TabletsPage />} />
        <Route path="halls" element={<HallsPage />} />
        <Route
          path="televisions-in-the-general-courtroom"
          element={<TelevisionsInTheGeneralCourtroomPage />}
        />
        <Route
          path="televisions-near-the-courtroom"
          element={<TelevisionsNearTheCourtroomPage />}
        />
      </Route>

      <Route path="/" element={<Navigate to={"/tablets"} />} />
      <Route path="*" element={<Navigate to={"/error/404"} replace />} />
    </Routes>
  );
};

type ProtectedRouteProps = {
  isAllowed: boolean;
  redirectPath?: string;
  children: React.ReactNode;
};
const ProtectedRoute = (props: ProtectedRouteProps) => {
  const { isAllowed, redirectPath = "/auth/sign_in", children } = props;

  if (!isAllowed) {
    return <Navigate to={redirectPath} replace />;
  }

  return children ? children : <Outlet />;
};
