import { styled } from "@mui/material";

import { Helmet, Typography } from "shared/ui/components";

import { SignInForm } from "features/sign-in";

import { useAppStore } from "shared/stores/app-store";
import { useState } from "react";
import { api } from "shared/api";

export const HELMET = {
  title: "Администрирование очередей | АС города Москвы",
};

function SignInPage() {
  const store = useAppStore();

  const [error, setError] = useState("");

  async function onSignIn({
    email,
    password,
  }: {
    email: string;
    password: string;
  }) {
    setError("");
    const res = await api.auth.signIn({ email, password });
    if (res.status === "success") {
      return store.setAuth(true);
    }
    if (res.status === "error") {
      setError(res.message);
    }
  }

  return (
    <Helmet helmet={HELMET}>
      <Wrapper>
        <TitleWrapper>
          <Typography variant="h1" color="primary" textAlign="center">
            Авторизация
          </Typography>
          {error && (
            <Typography variant="body2" color="error" textAlign="center">
              {error}
            </Typography>
          )}
        </TitleWrapper>
        <SignInForm onSubmit={onSignIn} />
        <Typography variant="body2" align="center">
          Если вы забыли логин или пароль, обратитесь в службу поддержки для
          восстановления учетной записи
        </Typography>
      </Wrapper>
    </Helmet>
  );
}

export default SignInPage;

const Wrapper = styled("div")(({ theme }) => {
  return {
    display: "flex",
    flexDirection: "column",
    gap: theme.spacing(5),
    alignItems: "center",
    maxWidth: 400,
  };
});

const TitleWrapper = styled("div")(({ theme }) => {
  return {
    display: "flex",
    flexDirection: "column",
    gap: theme.spacing(2),
  };
});
