import { Box, styled } from "@mui/material";

import { useDeviceHalls } from "shared/queries/halls";
import { Checkbox, Select } from "shared/ui/components";
import { useFilters } from "shared/stores/filters";
import { DEVICE_TYPE_ID } from "shared/constants/device";

const defaultOption = { value: "All", label: "Все" };

export function TabletsQueryFilter() {
  const { off, hallId, updateHallId, updateOff } = useFilters();
  const halls = useDeviceHalls(DEVICE_TYPE_ID.Tablets);

  function onChangeHallId(value: string) {
    const hallId = value === "All" ? undefined : value;
    updateHallId(hallId);
  }

  return (
    <Wrapper>
      <Select
        label="Номер зала"
        sx={{ minWidth: 280 }}
        value={String(hallId ?? "All")}
        onChange={(event: any) => onChangeHallId(event.target.value)}
        options={[defaultOption, ...(halls?.data ?? [])]}
      />
      <Checkbox
        label="Показать только отключенные"
        value={off}
        onChange={(_, checked) => updateOff(checked)}
      />
    </Wrapper>
  );
}

const Wrapper = styled(Box)(({ theme }) => {
  return {
    display: "flex",
    alignItems: "center",
    gap: theme.spacing(2),
  };
});
