import {
  DEVICE_STATUS_COLORS,
  DEVICE_STATUS_ID,
  DEVICE_STATUS_ID_TO_TYPES,
  DEVICE_STATUS_NAMES,
  DEVICE_STATUS_TYPES,
  DEVICE_TYPE_ID,
} from "shared/constants/device";
import { useFilters } from "shared/stores/filters";
import { usePagination } from "shared/stores/pagination";
import {
  useTableSorting,
  withProviderTableSorting,
} from "shared/stores/table-sorting";
import { Box, Table, TableProps, Typography } from "shared/ui/components";
import { checkAccessByDeviceStatus } from "shared/utils/checkAccessByStatus";

import { IconButtonDisablingDevice } from "features/disabling-device";
import { IconButtonEditDevice } from "features/edit-device";
import { IconButtonTurningDevice } from "features/turning-device";
import { useGetDevices } from "shared/queries/devices";
import { DeviceEntity } from "shared/types/devices/entities";

export function TelevisionsNearTheCourtroomTableComponent() {
  const tableSorting = useTableSorting();
  const filters = useFilters();
  const pagination = usePagination();

  const tablets = useGetDevices({
    deviceType: DEVICE_TYPE_ID.SamllTv,
    page: pagination.page,
    size: pagination.pageSize,
    hallId: filters.hallId,
    statusId: filters.off
      ? DEVICE_STATUS_ID[DEVICE_STATUS_TYPES.Disabled]
      : undefined,
    sortDirect: tableSorting.asc,
  });

  return (
    <Table
      loading={tablets.isLoading}
      columns={COLUMNS}
      rows={tablets.data?.items ?? []}
      pagination={{
        page: pagination.page,
        pageSize: pagination.pageSize,
        rowCount: tablets.data?.rowCount ?? 0,
        onPageChange: pagination.updatePage,
        onPageSizeChange: pagination.updatePageSize,
      }}
      sorting={{
        onOrederChange: ({ name, value }) =>
          tableSorting.handleSortingChange(name, value),
        order: tableSorting.order,
        orderBy: tableSorting.key,
      }}
    />
  );
}

export const TelevisionsNearTheCourtroomTable = withProviderTableSorting(
  TelevisionsNearTheCourtroomTableComponent,
);

const COLUMNS: TableProps["columns"] = [
  {
    field: "manufacturer",
    headerName: "Производитель",
    width: "17%",
  },
  { field: "model", headerName: "Модель", width: "17%" },
  { field: "uuid", headerName: "uuid", width: "22%" },
  {
    field: "hallName",
    headerName: "Номер зала",
    width: "17%",
  },
  {
    field: "status",
    renderCell: (row: DeviceEntity) => (
      <Typography
        color={DEVICE_STATUS_COLORS[DEVICE_STATUS_ID_TO_TYPES[row?.statusId]]}
        variant="body2"
      >
        {DEVICE_STATUS_NAMES[DEVICE_STATUS_ID_TO_TYPES[row?.statusId]]}
      </Typography>
    ),
    enableOrder: true,
    headerName: "Статус",
    width: "17%",
  },
  {
    field: "actions",
    renderCell: (row: DeviceEntity) => {
      const { statusId } = row;

      const { showEditDevice, showDisablingDevice, showTurningDevice } =
        checkAccessByDeviceStatus(DEVICE_STATUS_ID_TO_TYPES[statusId]);

      return (
        <Box
          sx={{
            display: "flex",
            alignItems: "center",
            justifyContent: "end",
          }}
        >
          <IconButtonEditDevice data={row} show={showEditDevice} />
          <IconButtonDisablingDevice data={row} show={showDisablingDevice} />
          <IconButtonTurningDevice data={row} show={showTurningDevice} />
        </Box>
      );
    },
  },
];
