import {
  UndefinedInitialDataOptions,
  useMutation,
  useQuery,
  useQueryClient,
} from "@tanstack/react-query";

import { devicesService } from "shared/services";
import { ChangeDeviceStatusParams, UpdateDeviceParams } from "shared/types";

const devicesKey = ["devices"];

export function useGetDevices(
  dto: Parameters<typeof devicesService.getDevices>[0],
  options?: UndefinedInitialDataOptions<
    Awaited<ReturnType<typeof devicesService.getDevices>>
  >,
) {
  return useQuery({
    queryKey: [...devicesKey, { ...dto }],
    queryFn: () => devicesService.getDevices(dto),
    staleTime: 1000,
    ...options,
  });
}

export function useUpdateDevice() {
  const queryClient = useQueryClient();

  return useMutation({
    mutationFn: (params: UpdateDeviceParams) =>
      devicesService.updateDevice(params),
    onSettled: async () => {
      await queryClient.invalidateQueries(["devices"] as any);
    },
  });
}

export function useDeviceChangeStatus() {
  const queryClient = useQueryClient();

  return useMutation({
    mutationFn: (params: ChangeDeviceStatusParams) =>
      devicesService.changeStatusDevice(params),
    onSettled: async () => {
      await queryClient.invalidateQueries(["devices"] as any);
    },
  });
}
