import {
  UndefinedInitialDataOptions,
  useMutation,
  useQuery,
  useQueryClient,
} from "@tanstack/react-query";

import { hallsService } from "shared/services/HallsService";
import { HallChangeStatusParams, HallEditRequestParams } from "shared/types";

const deviceHallsKey = "device-halls";

export function useDeviceHalls(
  deviceType: number,
  options?: UndefinedInitialDataOptions<
    Awaited<ReturnType<typeof hallsService.getHallsByDeviceType>>
  >,
) {
  return useQuery({
    queryKey: [deviceHallsKey, deviceType],
    queryFn: () => hallsService.getHallsByDeviceType(deviceType),
    ...options,
  });
}

const hallsForTableKey = "device-hall-list";

export function useGetTableHalls(
  dto: Parameters<typeof hallsService.getHallsList>[0],
  options?: UndefinedInitialDataOptions<
    Awaited<ReturnType<typeof hallsService.getHallsList>>
  >,
) {
  return useQuery({
    queryKey: [hallsForTableKey, { ...dto }],
    queryFn: () => hallsService.getHallsList(dto),
    ...options,
  });
}

export function useUpdateHall() {
  const queryClient = useQueryClient();

  return useMutation({
    mutationFn: (params: HallEditRequestParams) =>
      hallsService.updateHall(params),
    onSettled: async () => {
      await queryClient.invalidateQueries([hallsForTableKey] as any);
    },
  });
}

export function useChangeStatusHall() {
  const queryClient = useQueryClient();

  return useMutation({
    mutationFn: (params: HallChangeStatusParams) =>
      hallsService.changeStatus(params),
    onSettled: async () => {
      await queryClient.invalidateQueries([hallsForTableKey] as any);
    },
  });
}

const halleKey = "hall";

export function useHall(id: string) {
  return useQuery({
    queryKey: [halleKey, { id }],
    queryFn: () => hallsService.getCardById(id),
  });
}
