import { Axios } from "axios";
import { sessionCaseInstance, showCaseInstance } from "shared/api";
import { DevicesDTO, DevicesParams, UpdateDeviceParams } from "shared/types";
import { errorHandler } from "shared/utils";

export class DevicesRepositories {
  #showCaseApi: Axios = showCaseInstance;
  #sessionCaseApi: Axios = sessionCaseInstance;

  async getDevices(params: DevicesParams): Promise<DevicesDTO> {
    try {
      const res = await this.#showCaseApi.get("/api/device-hall", {
        params: params,
      });

      return res.data;
    } catch (error) {
      throw errorHandler(error);
    }
  }

  async updateDevice(params: UpdateDeviceParams): Promise<void> {
    try {
      const res = await this.#sessionCaseApi.put("/api/device", params);

      return res.data;
    } catch (error) {
      throw errorHandler(error);
    }
  }

  async changeStatusDevice(deviceId: string, status: number): Promise<void> {
    try {
      const res = await this.#sessionCaseApi.post(
        `/api/device/${deviceId}/change-status`,
        {
          status: status,
        },
      );

      return res.data;
    } catch (error) {
      throw errorHandler(error);
    }
  }
}
