import { Axios } from "axios";
import { sessionCaseInstance, showCaseInstance } from "shared/api";
import {
  HallCardResponseDTO,
  HallChangeStatusParams,
  HallEditRequestParams,
  HallsByDeviceTypeDTO,
  HallsDTO,
  HallsParams,
} from "shared/types";
import { errorHandler } from "shared/utils";

export class HallsRepositories {
  #showCaseApi: Axios = showCaseInstance;
  #sessionCaseApi: Axios = sessionCaseInstance;

  async getHalls(params: HallsParams): Promise<HallsDTO> {
    try {
      const res = await this.#showCaseApi.get("/api/device-hall/list", {
        params: params,
      });

      return res.data;
    } catch (error) {
      throw errorHandler(error);
    }
  }

  async getHallsByDeviceId(params: {
    deviceTypeId: number;
  }): Promise<HallsByDeviceTypeDTO> {
    try {
      const res = await this.#showCaseApi.get("/api/device-hall/device-type", {
        params: params,
      });

      return res.data;
    } catch (error) {
      throw errorHandler(error);
    }
  }

  async getCardById(id: string): Promise<HallCardResponseDTO> {
    try {
      const res = await this.#showCaseApi.get(`/api/device-hall/${id}`);

      return res.data;
    } catch (error) {
      throw errorHandler(error);
    }
  }

  async updateHall(params: HallEditRequestParams): Promise<void> {
    try {
      const res = await this.#sessionCaseApi.post("/api/device-hall", params);

      return res.data;
    } catch (error) {
      throw errorHandler(error);
    }
  }

  async changeStatus(params: HallChangeStatusParams): Promise<void> {
    try {
      const res = await this.#sessionCaseApi.post(
        `/api/device-hall/${params.deviceHallId}/change-status`,
        { status: params.status },
      );

      return res.data;
    } catch (error) {
      throw errorHandler(error);
    }
  }
}
