import { DevicesRepositories } from "shared/repositories/DevicesRepositories";
import {
  ChangeDeviceStatusParams,
  DeviceElementDTO,
  DevicesList,
  DevicesParams,
  UpdateDeviceParams,
} from "shared/types";
import { DeviceEntity } from "shared/types/devices/entities";

class DevicesService {
  static #instance: DevicesService;
  #repo: DevicesRepositories;

  private constructor() {
    this.#repo = new DevicesRepositories();
  }

  public static get instance(): DevicesService {
    if (!DevicesService.#instance) {
      DevicesService.#instance = new DevicesService();
    }

    return DevicesService.#instance;
  }

  private DeviceDtoToDeviceEntity(dto: DeviceElementDTO): DeviceEntity {
    const { hallId, hallName, id, manufacturer, model, statusId } = dto;

    return {
      hallName: hallName ?? "-",
      hallId: hallId ?? "",
      id: String(id),
      manufacturer: manufacturer ?? "",
      model: model ?? "",
      statusId: Number(statusId),
      uuid: String(id),
    };
  }

  async getDevices(params: DevicesParams): Promise<DevicesList> {
    const data = await this.#repo.getDevices(params);

    const { content, totalElements } = data;
    const items = content.map(this.DeviceDtoToDeviceEntity);

    return { items, rowCount: totalElements };
  }

  updateDevice(params: UpdateDeviceParams): Promise<void> {
    return this.#repo.updateDevice(params);
  }

  changeStatusDevice(params: ChangeDeviceStatusParams): Promise<void> {
    return this.#repo.changeStatusDevice(params.deviceId, params.status);
  }
}

export const devicesService = DevicesService.instance;
