import { create } from "zustand";
import { devtools, persist } from "zustand/middleware";
import { immer } from "zustand/middleware/immer";

type State = {
  isReady: boolean;
  isAuth: boolean;
};
type Action = {
  setReady: (ready: boolean) => void;
  setAuth: (auth: boolean) => void;
};

export const useAppStore = create<State & Action>()(
  devtools(
    persist(
      immer((set) => ({
        isReady: false,
        isAuth: false,
        setReady: (ready) => {
          set((state) => {
            state.isReady = ready;
          });
        },
        setAuth: (auth) => {
          set((state) => {
            state.isAuth = auth;
          });
        },
      })),
      { name: "app-state" },
    ),
  ),
);
