import {
  Dispatch,
  ReactNode,
  SetStateAction,
  createContext,
  useContext,
  useMemo,
  useState,
} from "react";

export type FiltersData = {
  hallId?: string;
  off: boolean;
};

const initialState: FiltersData = {
  hallId: undefined,
  off: false,
};

const filtersContext = createContext<{
  data: FiltersData;
  setData: Dispatch<SetStateAction<FiltersData>>;
} | null>(null);

export function FiltersProvider({ children }: { children: ReactNode }) {
  const [data, setData] = useState<FiltersData>(initialState);

  return (
    <filtersContext.Provider value={useMemo(() => ({ data, setData }), [data])}>
      {children}
    </filtersContext.Provider>
  );
}

export function useFilters() {
  const contextValue = useContext(filtersContext);
  if (!contextValue) throw new Error("context not provided");

  const { data, setData } = contextValue;

  const updateHallId = (hallId: string | undefined) => {
    setData((d) => ({ ...d, hallId }));
  };

  const updateOff = (off: boolean) => {
    setData((d) => ({ ...d, off }));
  };

  const reset = () => {
    setData(initialState);
  };

  return {
    ...data,
    updateHallId,
    updateOff,
    reset,
  };
}
