import { create } from "zustand";
import { devtools } from "zustand/middleware";
import { immer } from "zustand/middleware/immer";

export const MODAL_TYPES = {
  DeviceCode: "DeviceCode",
  DisablingDevice: "DisablingDevice",
  TurningDevice: "TurningDevice",
  EditDevice: "EditDevice",
  DeleteAccount: "DeleteAccount",
  AccountBlocking: "AccountBlocking",
  UnlockAccount: "UnlockAccount",
  EndTheSession: "EndTheSession",
  CreateAnAccount: "CreateAnAccount",
  AccountCreatedSuccessfully: "AccountCreatedSuccessfully",
  EditAccount: "EditAccount",
  PasswordGeneration: "PasswordGeneration",
  EndHallSession: "EndHallSession",
  UnlockHall: "UnlockHall",
  HallBlocking: "HallBlocking",
  EditHallCards: "EditHallCards",
} as const;

export const MODAL_NAMES = {
  EditDevice: "Редактировать",
  TurningDevice: "Включение устройства",
  DisablingDevice: "Отключение устройства",
  DeleteAccount: "Удаление учетной записи",
  AccountBlocking: "Блокирование учетной записи",
  UnlockAccount: "Разблокирование учетной записи",
  EndTheSession: "Завершение сессии",
  CreateAnAccount: "Создание учетной записи",
  AccountCreatedSuccessfully: "Учетная запись успешно создана",
  EditAccount: "Редактирование учетной записи",
  PasswordGeneration: "Генерация пароля",
  EndHallSession: "Завершение сессии",
  UnlockHall: "Разблокирование зала",
  HallBlocking: "Блокирование зала",
  EditHallCards: "Редактирование карточки зала",
};

type ModalTypes = typeof MODAL_TYPES;
type ModalType = keyof ModalTypes;

type State = {
  openModalType: ModalType | null;
  modalData: any;
};
type Actions = {
  showModal: (type: ModalType, data?: any) => void;
  closeModal: () => void;
};
type Store = State & { actions: Actions };
const INITIAL_STATE = {
  openModalType: null,
  modalData: null,
};

export const useModalStore = create<Store>()(
  devtools(
    immer((set) => ({
      ...INITIAL_STATE,
      actions: {
        showModal: (type: ModalType, data: any) => {
          set((state) => {
            state.openModalType = type;
            state.modalData = data;
          });
        },
        closeModal: () => {
          set((state) => {
            state.openModalType = null;
            state.modalData = null;
          });
        },
      },
    })),
  ),
);
