import {
  Dispatch,
  ReactNode,
  SetStateAction,
  createContext,
  useContext,
  useEffect,
  useMemo,
  useState,
} from "react";

export type PaginationData = {
  pageSize: number;
  page: number;
};

const initialState: PaginationData = { page: 1, pageSize: 10 };

const paginationContext = createContext<{
  data: PaginationData;
  setData: Dispatch<SetStateAction<PaginationData>>;
} | null>(null);

export function PaginationProvider({ children }: { children: ReactNode }) {
  const [data, setData] = useState<PaginationData>(initialState);

  return (
    <paginationContext.Provider
      value={useMemo(() => ({ data, setData }), [data])}
    >
      {children}
    </paginationContext.Provider>
  );
}

export function usePagination(...observed: any[]) {
  const contextValue = useContext(paginationContext);
  if (!contextValue) throw new Error("context not provided");

  const { data, setData } = contextValue;

  const updatePage = (page: number) => {
    setData((d) => ({ ...d, page }));
  };

  const updatePageSize = (pageSize: number) => {
    setData((d) => ({ ...d, pageSize }));
  };

  const reset = () => {
    setData(initialState);
  };

  useEffect(() => {
    updatePage(1);
  }, [...observed]);

  return {
    ...data,
    updatePage,
    updatePageSize,
    reset,
  };
}
