import { Control, Controller } from "react-hook-form";
import { Input, InputPassword, Select } from "../components";

export type FieldType =
  | "text"
  | "number"
  | "textarea"
  | "cheackbox"
  | "select"
  | "multiselect";

type FieldCommon = {
  label?: string;
  required?: boolean;
};
type FieldText = FieldCommon & {
  type: "text";
  value: string;
};

type FieldTextarea = FieldCommon & {
  type: "textarea";
  value: number;
};

type FieldNumber = FieldCommon & {
  type: "number";
  value: number;
};

type FieldCheackbox = FieldCommon & {
  type: "cheackbox";
  value: number;
};

type FieldSelect = FieldCommon & {
  type: "select";
  value: number;
};

type FieldMultiselect = FieldCommon & {
  type: "multiselect";
  value: number;
};

export type Field =
  | FieldText
  | FieldNumber
  | FieldTextarea
  | FieldCheackbox
  | FieldSelect
  | FieldMultiselect;

type FormInputProps<T extends Record<string, unknown>> = {
  name: keyof T;
  control: Control<T>;
  disabled?: boolean;
  label?: string;
  required?: boolean;
  type?: string;
};

export function FormFieldText<T extends Record<string, unknown>>({
  disabled,
  label,
  name,
  control,
  required,
}: FormInputProps<T>) {
  return (
    <Controller
      name={name as any}
      control={control}
      render={({ field: { onChange, value }, fieldState: { error } }) => (
        <Input
          required={required}
          helperText={error ? error.message : null}
          error={!!error}
          onChange={onChange}
          value={value}
          label={label}
          disabled={disabled}
        />
      )}
    />
  );
}

export function FormFieldPassowrd<T extends Record<string, unknown>>({
  disabled,
  label,
  name,
  control,
  required,
}: FormInputProps<T>) {
  return (
    <Controller
      name={name as any}
      control={control}
      render={({ field: { onChange, value }, fieldState: { error } }) => (
        <InputPassword
          required={required}
          helperText={error ? error.message : null}
          error={!!error}
          onChange={onChange}
          value={value}
          disabled={disabled}
          label={label}
        />
      )}
    />
  );
}

export const FormFieldSelect = ({ label, options, required, ...rest }: any) => {
  return (
    <Controller
      {...rest}
      render={({ field: { onChange, value }, fieldState: { error } }) => (
        <Select
          required={required}
          helperText={error ? error.message : null}
          error={!!error}
          onChange={onChange}
          value={value}
          label={label}
          name={rest.name}
          options={options}
        />
      )}
    />
  );
};
