import { Icon } from "shared/assets/icons";
import { Box, IconButton, Modal, Typography } from "shared/ui/components";

export type CustomModalProps = {
  open: boolean;
  handleClose: () => void;
  title: string;
  children?: React.ReactNode;
  actions?: React.ReactNode;
};

export function CustomModal(props: CustomModalProps) {
  const { handleClose, open, title, actions, children } = props;
  return (
    <Modal
      open={open}
      onClose={handleClose}
      PaperProps={{ sx: { minWidth: 528, padding: 3, gap: 3 } }}
    >
      <Box
        sx={{
          display: "flex",
          alignItems: "center",
          justifyContent: "space-between",
        }}
      >
        <Typography variant="h3">{title}</Typography>
        <IconButton onClick={handleClose}>
          <Icon.CloseIcon />
        </IconButton>
      </Box>
      {children}
      {actions && (
        <Box
          sx={{
            display: "flex",
            alignItems: "center",
            gap: 2,
          }}
        >
          {actions}
        </Box>
      )}
    </Modal>
  );
}
