import {
  Box,
  Header,
  List,
  ListItemButton,
  ListItemText,
  Typography,
} from "shared/ui/components";

import { Clock } from "features/clock";

import { SignOut } from "features/sign-out/SignOut";
import { styled } from "@mui/material";

type GeneralLayoutProps = {
  children?: React.ReactNode;
};
export function GeneralLayout(props: GeneralLayoutProps) {
  const { children } = props;
  const email = "IvanIvanov@yandex.ru";
  return (
    <>
      <Header
        leftContent={<Clock />}
        rightContent={
          <>
            <Typography variant="body2">{email}</Typography>
            <SignOut />
          </>
        }
      />
      <WrapperAside component={"aside"}>
        <List sx={{ width: "100%", padding: 0 }} component="nav">
          <ListItemButton to="/tablets">
            <ListItemText primary="Планшеты" />
          </ListItemButton>
          <ListItemButton to="/televisions-near-the-courtroom">
            <ListItemText primary="Телевизоры у зала суда" />
          </ListItemButton>
          <ListItemButton to="/televisions-in-the-general-courtroom">
            <ListItemText primary="Телевизоры общего зала суда" />
          </ListItemButton>
          {/* <ListItemButton to="/judges">
            <ListItemText primary="Судьи" />
          </ListItemButton> */}
          <ListItemButton to="/halls">
            <ListItemText primary="Залы" />
          </ListItemButton>
        </List>
      </WrapperAside>
      <WrapperMain component={"main"}>{children}</WrapperMain>
    </>
  );
}

const WrapperMain = styled(Box)(({ theme }) => {
  return {
    display: "flex",
    flexDirection: "column",
    flexGrow: 1,
    gap: theme.spacing(4),
    marginLeft: 320,
    padding: theme.spacing(4),
    background: theme.colors.BG_LIGHT,
  };
});

const WrapperAside = styled(Box)(({ theme }) => {
  return {
    position: "absolute",
    top: 72,
    left: 0,
    bottom: 0,
    display: "flex",
    flexDirection: "column",
    flexGrow: 1,
    width: 320,
    backgroundColor: theme.colors.GRAY_DARK,
    color: theme.colors.BG_LIGHT,
    borderTop: "1px solid white",
  };
});
