import { styled } from "@mui/material";
import { Box, Checkbox, Select, SelectProps } from "shared/ui/components";

type OnChange<T> = (data: { name: string; value: T }) => void;
export type FieldCommon = {
  type: string;
  name: string;
  label: string;
  options?: SelectProps["options"];
};
export type FieldQueryFilterProps = FieldCommon;
export type QueryFilterProps = {
  loading?: boolean;
  fields?: FieldQueryFilterProps[];
  query: any;
  onChange: OnChange<any>;
};
export function QueryFilter(props: QueryFilterProps) {
  const { fields = [], loading, query, onChange } = props;

  return (
    <Wrapper>
      {fields.map((field) => {
        const { type, name, label, options } = field;
        const defaultOption = { value: "-1", label: "Все" };
        switch (type) {
          case "checkbox":
            return (
              <Checkbox
                key={name}
                disabled={loading}
                value={query[name]}
                onChange={(_, checked) => onChange({ name, value: checked })}
                label={label}
              />
            );
          case "select":
            return (
              <Select
                key={name}
                disabled={loading}
                label={label}
                sx={{ minWidth: 280 }}
                value={String(query[name])}
                options={[defaultOption, ...(options ? options : [])]}
                renderValue={(value) =>
                  value === "-1" ? "Все" : String(value)
                }
                onChange={(event: any) =>
                  onChange({ name, value: event.target.value })
                }
              />
            );
          default:
            return null;
        }
      })}
    </Wrapper>
  );
}

const Wrapper = styled(Box)(({ theme }) => {
  return {
    display: "flex",
    alignItems: "center",
    gap: theme.spacing(2),
  };
});
