import { styled } from "@mui/material";
import { Icon } from "shared/assets/icons";
import { Box, Tooltip, Typography } from "shared/ui/components";

export type TablePageTemplateProps = {
  title: string;
  tooltip?: string;
  Actions?: React.ReactNode;
  Table?: React.ReactNode;
  QueryFilter?: React.ReactNode;
};
export function TablePageTemplate(props: TablePageTemplateProps) {
  const { title, tooltip, Table, QueryFilter, Actions } = props;

  return (
    <WrapperFlexColumn>
      <WrapperFlexRow
        component="section"
        sx={{ justifyContent: "space-between" }}
      >
        <WrapperFlexRow gap={1}>
          <Typography variant="h1" color="primary">
            {title}
          </Typography>
          {tooltip && (
            <Tooltip
              title={<Typography variant="caption">{tooltip}</Typography>}
              placement="right"
            >
              <Icon.Info svgProps={{ color: "secondary" }} />
            </Tooltip>
          )}
        </WrapperFlexRow>
        {Actions && <WrapperFlexRow gap={1}>{Actions}</WrapperFlexRow>}
      </WrapperFlexRow>
      {QueryFilter && (
        <WrapperFlexRow component="section">{QueryFilter}</WrapperFlexRow>
      )}
      {Table && (
        <WrapperFlexColumn component="section">{Table}</WrapperFlexColumn>
      )}
    </WrapperFlexColumn>
  );
}

const WrapperFlexRow = styled(Box)<{ gap?: number }>(({ theme, gap }) => {
  return {
    display: "flex",
    alignItems: "center",
    gap: theme.spacing(gap ?? 2),
  };
});

const WrapperFlexColumn = styled(Box)<{ gap?: number }>(({ theme, gap }) => {
  return {
    display: "flex",
    flexDirection: "column",
    gap: theme.spacing(gap ?? 3),
    flexGrow: 1,
  };
});
