import { jwtDecode } from "jwt-decode";
import { CookieService } from "./cookie";

type TokenData = {
  email: string;
};

export class TokenService {
  private static ACCESS_TOKEN_KEY = "accessToken";
  private static REFRESH_TOKEN_KEY = "refreshToken";

  public static accessToken: string | null = null;
  public static accessTokenData: TokenData | null = null;
  public static refreshToken: string | null = null;

  private static decodeAccessToken(accessToken: string | null) {
    if (!accessToken) return null;
    try {
      return jwtDecode<TokenData>(accessToken) ?? null;
    } catch (error) {
      return null;
    }
  }

  public static setAccessToken(accessToken: string | null) {
    this.accessToken = accessToken;
    this.accessTokenData = this.decodeAccessToken(accessToken);
  }
  public static setRefreshToken(refreshToken: string | null) {
    this.accessToken = refreshToken;
  }

  public static clearTokens() {
    this.accessToken = null;
    this.accessTokenData = null;
    this.refreshToken = null;
  }

  public static init() {
    const accessToken = CookieService.get(this.ACCESS_TOKEN_KEY);
    const refreshToken = CookieService.get(this.REFRESH_TOKEN_KEY);
    this.setAccessToken(accessToken);
    this.setRefreshToken(refreshToken);
  }
}
