import { defineConfig, loadEnv } from "vite";
import react from "@vitejs/plugin-react";
import svgr from "vite-plugin-svgr";

import { alias } from "./tools/alias";

// https://vitejs.dev/config/
export default defineConfig(({ mode }) => {
  process.env = { ...process.env, ...loadEnv(mode, process.cwd()) };

  return {
    plugins: [react(), svgr()],
    resolve: { alias },
    base: "./",
    define: {
      "process.env": {},
    },
    server: {
      port: Number(process.env.VITE_APP_PORT) ?? 3000,
      host: process.env.VITE_APP_HOSTNAME ?? "127.0.0.1",
      proxy: {
        "/showcase-service/api": {
          target: process.env.VITE_APP_SHOWCASE_SERVICE_API_URI,
          changeOrigin: true,
          rewrite: (path) => path.replace(/^\/showcase-service\/api/, ""),
        },
        "/session-service/api": {
          target: process.env.VITE_APP_SESSION_SERVICE_API_URI,
          changeOrigin: true,
          rewrite: (path) => path.replace(/^\/session-service\/api/, ""),
        },
      },
    },
  };
});
