import {
  Dispatch,
  ReactNode,
  SetStateAction,
  createContext,
  useContext,
  useEffect,
  useMemo,
  useState,
} from "react";
import { SECOND } from "shared/constants/time";

type ClockData = {
  data: Date;
  setData: Dispatch<SetStateAction<Date>>;
};

const ClockContext = createContext<ClockData | null>(null);

export function ClockProvider({ children }: { children: ReactNode }) {
  const [data, setData] = useState(new Date());

  const setCurrentDate = () => setData(new Date());

  useEffect(() => {
    const intervalId = setInterval(setCurrentDate, UPDATE_INTERVAL);
    return () => clearInterval(intervalId);
  }, []);

  return (
    <ClockContext.Provider value={useMemo(() => ({ data, setData }), [data])}>
      {children}
    </ClockContext.Provider>
  );
}

export function useClock() {
  const contextValue = useContext(ClockContext);
  if (!contextValue) throw new Error("context not provided");

  const time = timeFormat.format(contextValue.data);
  const date = dateFormat.format(contextValue.data);

  return { time, date };
}

const timeFormat = new Intl.DateTimeFormat("ru", {
  hour: "numeric",
  minute: "numeric",
});

const dateFormat = new Intl.DateTimeFormat("ru", {
  year: "numeric",
  month: "numeric",
  day: "numeric",
  hour12: false,
});

const UPDATE_INTERVAL = SECOND * 10;
