import { Navigate, Outlet, Route, Routes } from "react-router-dom";

import { ActivateDevicePage } from "./activate-device";
import { ScheduleMeetingsPage } from "./schedule-meetings";

export const Routing = () => {
  return (
    <Routes>
      <Route
        path={PATHS.ACTIVATE}
        element={
          <ProtectedRoute
            isAllowed={!isActivated}
            redirectPath={PATHS.MEETINGS}
          >
            <Outlet />
          </ProtectedRoute>
        }
      >
        <Route path="" element={<ActivateDevicePage />} />
      </Route>
      <Route
        path={PATHS.MEETINGS}
        element={
          <ProtectedRoute isAllowed={isActivated} redirectPath={PATHS.ACTIVATE}>
            <Outlet />
          </ProtectedRoute>
        }
      >
        <Route path="" element={<ScheduleMeetingsPage />} />
      </Route>
      <Route path="*" element={<Navigate to={PATHS.ACTIVATE} replace />} />
    </Routes>
  );
};

const isActivated = true;

const PATHS = {
  ACTIVATE: "/activate-device",
  MEETINGS: "/schedule-meetings",
};

type ProtectedRouteProps = {
  isAllowed: boolean;
  redirectPath?: string;
  children: React.ReactNode;
};
const ProtectedRoute = (props: ProtectedRouteProps) => {
  const { isAllowed, redirectPath = PATHS.ACTIVATE, children } = props;

  if (!isAllowed) {
    return <Navigate to={redirectPath} replace />;
  }

  return children ? children : <Outlet />;
};
