import { Typography } from "@mui/material";
import { Column, MeetingTable } from "./meeting-table";
import { useScheduleMeetings } from "../schedule-meetings-service";

export function MainContent() {
  const { meetingsExpected, meetingsProgress } = useScheduleMeetings();

  return (
    <>
      <MeetingTable
        title="Идет заседание"
        data={meetingsProgress}
        columns={COLUMNS("success")}
      />
      <MeetingTable
        title="Ожидается заседание"
        data={meetingsExpected}
        columns={COLUMNS("error")}
      />
    </>
  );
}

const COLUMNS = (color: "success" | "error"): Column[] => {
  return [
    {
      field: "start",
      headerName: "Время начала",
      renderCell: (row) => {
        const value = timeFormat.format(row.start);
        return value;
      },
    },
    {
      field: "caseNumber",
      headerName: "Номер дела",
      renderCell: (row) => {
        const { caseNumber, prefix, postfix } = row;
        return (
          <>
            {prefix}-
            <Typography
              component="span"
              sx={{ color: (theme) => theme.palette[color].main }}
              variant="body2"
            >
              {caseNumber}
            </Typography>
            /{postfix}
          </>
        );
      },
    },
    {
      field: "hallNumber",
      headerName: "Номер зала",
      renderCell: (row) => {
        return (
          <Typography component="span" variant="body1">
            {row.hallNumber}
          </Typography>
        );
      },
    },
  ];
};

const timeFormat = new Intl.DateTimeFormat("ru", {
  hour: "numeric",
  minute: "numeric",
});
