import {
  Box,
  Table,
  TableBody,
  TableCell,
  TableContainer,
  TableHead,
  TableRow,
  Typography,
} from "@mui/material";
import { useRef } from "react";
import { entities } from "shared/services";

export type Column = {
  field: keyof entities.meetings.MeetingEntity;
  headerName: string;
  renderCell?: (
    row: entities.meetings.MeetingEntity,
    index?: number,
  ) => React.ReactNode;
};

const CELL_HEIGHT = 115;
const TABLE_GAP = 7;

export function MeetingTable({
  title,
  data,
  columns,
}: {
  title: string;
  data: entities.meetings.MeetingEntities;
  columns: Column[];
}) {
  const currentHallNumber = useRef(0);
  const wrapperRef = useRef<HTMLElement>(null);
  const titleRef = useRef<HTMLElement>(null);

  return (
    <Box
      ref={wrapperRef}
      sx={{
        display: "flex",
        flexDirection: "column",
        gap: TABLE_GAP,
        width: "100%",
      }}
    >
      <Typography ref={titleRef} variant="h2" color="primary" fontWeight={700}>
        {title}
      </Typography>
      <TableContainer>
        <Table>
          <TableHead>
            <TableRow>
              {columns.map((column) => {
                return (
                  <TableCell
                    key={column.field}
                    sx={{ padding: 0, height: CELL_HEIGHT }}
                  >
                    <Typography align="center" variant="body1">
                      {column.headerName}
                    </Typography>
                  </TableCell>
                );
              })}
            </TableRow>
          </TableHead>
          <TableBody>
            {data.map((_, index) => {
              const row = data?.[index];
              if (!currentHallNumber.current) {
                currentHallNumber.current = row?.hallNumber;
              }
              const isShowDivider = (() => {
                if (currentHallNumber.current === row?.hallNumber) return false;
                currentHallNumber.current = row?.hallNumber;
                return true;
              })();
              return (
                <TableRow key={index}>
                  {columns.map((column) => {
                    const { field, renderCell } = column;
                    if (!row) {
                      return (
                        <TableCell
                          key={field}
                          sx={{ padding: 0, height: CELL_HEIGHT }}
                        />
                      );
                    }
                    const value = row?.[field] as string;
                    const renderValue = renderCell
                      ? renderCell(row, index)
                      : value;
                    return (
                      <TableCell
                        key={field}
                        sx={{
                          padding: 0,
                          height: CELL_HEIGHT,
                          ...(isShowDivider
                            ? { borderTop: `4px solid #919FBA` }
                            : {}),
                        }}
                      >
                        <Typography align="center" variant="body2">
                          {renderValue}
                        </Typography>
                      </TableCell>
                    );
                  })}
                </TableRow>
              );
            })}
          </TableBody>
        </Table>
      </TableContainer>
    </Box>
  );
}
