import { useEffect, useState } from "react";

import { SECOND } from "shared/constants/time";
import { MeetingService } from "shared/services/MeetingService";
import { MeetingEntity } from "shared/types/session/entities/meeting";

const GUID = "3fa85f64-5717-4562-b3fc-2c963f66afa6";

import { Client } from "@stomp/stompjs";

const client = new Client({
  brokerURL: "ws://al-suo.stage.dev.local/websocket",
  onConnect: () => {
    console.log("connected");

    client.subscribe("/topic/big-tv", (message) =>
      console.log(`Received: ${message.body}`),
    );
  },
  onWebSocketError: (error) => {
    console.log("error :>> ", error);
  },
  reconnectDelay: 5000,
  connectionTimeout: 5000,
});

client.activate();

export function useScheduleMeetings() {
  const [meetingsExpected, setMeetingsExpected] = useState<MeetingEntity[]>([]);
  const [meetingsProgress, setMeetingsProgress] = useState<MeetingEntity[]>([]);

  async function getData() {
    const res = await MeetingService.instance.getMeetings(GUID);

    const { expected, progress } = res;

    setMeetingsExpected(expected);
    setMeetingsProgress(progress);
  }

  useEffect(() => {
    getData();
    const intervalId = setInterval(getData, SECOND * 5);

    return () => clearInterval(intervalId);
  }, []);

  return { meetingsExpected, meetingsProgress };
}
