import { createTheme } from "@mui/material";

declare module "@mui/material/styles" {
  interface Theme {
    colors: Colors;
    custom: {
      background: {
        light: string;
        dark: string;
        hover: string;
      };
      header: {
        height: number;
        color: string;
      };
    };
  }
  // allow configuration using `createTheme`
  interface ThemeOptions {
    colors: Colors;
    custom?: {
      background?: {
        light?: string;
        dark?: string;
        hover?: string;
      };
      header: {
        height?: number;
        color?: string;
      };
    };
  }
}

export const COLORS = {
  BG_LIGHT: "#FAF7FB",
  BG_DARK: "#F1EEF2",
  BG_HOVER: "#E5E2E5",
  GRAY_LIGHT: "#99A6BF",
  GRAY: "#62708C",
  GRAY_DARK: "#323F5A",
  BLUE: "#306CBF",
  BLUE_DARK: "#1C4B8C",
  RED: "#F2320C",
  RED_DARK: "#BF2000",
  GREEN: "#1BB267",
};

type Colors = typeof COLORS;

export const theme = createTheme({
  colors: COLORS,
  custom: {
    header: {
      color: "#34415A",
      height: 158,
    },
  },
  palette: {
    primary: {
      main: COLORS.BLUE,
      dark: COLORS.BLUE_DARK,
    },
    secondary: {
      main: COLORS.GRAY_LIGHT,
      dark: COLORS.GRAY,
      contrastText: COLORS.BG_LIGHT,
    },
    error: {
      main: COLORS.RED,
      dark: COLORS.RED_DARK,
    },
    success: {
      main: COLORS.GREEN,
    },
    text: {
      primary: COLORS.GRAY_DARK,
      secondary: COLORS.GRAY_LIGHT,
    },
    background: {
      default: COLORS.BG_LIGHT,
    },
  },
  typography: {
    h1: {
      fontFamily: "Lora",
      fontWeight: 500,
      fontSize: "130px",
      color: "#22262A",
    },
    h2: {
      fontFamily: "Lora",
      fontWeight: 700,
      fontSize: "90px",
    },
    h3: {
      fontFamily: "Lora",
      fontWeight: 500,
      fontSize: "70px",
    },
    body1: {
      fontFamily: "OpenSans",
      fontWeight: 600,
      fontSize: "60px",
    },
    body2: {
      fontFamily: "OpenSans",
      fontWeight: 400,
      fontSize: "50px",
    },
    caption: {
      fontFamily: "OpenSans",
      fontWeight: 400,
      fontSize: "12px",
    },
    button: {
      fontFamily: "OpenSans",
      fontWeight: 600,
      fontSize: "16px",
      textTransform: "none",
    },
  },
  components: {
    MuiListItemButton: {
      styleOverrides: {
        root: {
          "&.Mui-focusVisible": {
            background: COLORS.BLUE_DARK,
          },
          "&.Mui-selected": {
            background: COLORS.BLUE,
          },
          "&:hover, &.Mui-selected:hover": {
            background: COLORS.BLUE_DARK,
          },
        },
        gutters: {
          padding: "16px 32px",
        },
      },
    },
    MuiInputBase: {
      styleOverrides: {
        input: {
          color: COLORS.GRAY_DARK,
          fontSize: "74px",
        },
      },
    },
    MuiFormLabel: {
      styleOverrides: {
        root: {
          "&": {
            fontWeight: 400,
            fontSize: "60px",
            color: "#3D444D",
            top: -24,
          },
        },
        asterisk: {
          color: COLORS.RED,
        },
      },
    },
    MuiTableContainer: {
      styleOverrides: {
        root: {
          "&": {
            display: "flex",
            flexDirection: "column",
            flexGrow: 1,
            gap: "16px",
          },
        },
      },
    },
    MuiTableRow: {
      styleOverrides: {
        root: {
          "&:nth-of-type(2n)": {
            backgroundColor: "#EBEBEB",
          },
          // hide last border
          "&:last-child td, &:last-child th": {
            border: 0,
          },
        },
      },
    },
  },
});
