import { MeetingRepository } from "shared/repositories";
import { SessionDto } from "shared/types/session/dto";
import { SessionList } from "shared/types/session/SessionList";
import { MeetingEntity } from "../types/session/entities/meeting";

export class MeetingService {
  static #instance: MeetingService;
  #repo: MeetingRepository;

  public static get instance(): MeetingService {
    if (!MeetingService.#instance) {
      MeetingService.#instance = new MeetingService();
    }

    return MeetingService.#instance;
  }

  private constructor() {
    this.#repo = new MeetingRepository();
  }

  private SessionDtoToMeetingEntity(dto: SessionDto): MeetingEntity {
    const { hallId, hallName, primaryCaseNumber = "", hearingDate } = dto;
    const [prefix, caseNumber, postfix] = primaryCaseNumber.split(/\/|-/);

    return {
      id: hallId!,
      hallNumber: Number(hallName.replace(/[^0-9]/g, "")),
      prefix,
      caseNumber: Number(caseNumber),
      postfix,
      start: new Date(hearingDate),
    };
  }

  async getMeetings(id: string): Promise<SessionList> {
    const data = await this.#repo.getSessions(id);

    return {
      progress: data.inProgressSessions.map(this.SessionDtoToMeetingEntity),
      expected: data.waitingSessions.map(this.SessionDtoToMeetingEntity),
    };
  }
}
