package ru.avilex.session.config;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.messaging.Message;
import ru.avilex.session.dto.HallStreamDTO;
import ru.avilex.session.mapper.DeviceHallMapper;
import ru.avilex.session.mapper.SessionMapper;
import ru.avilex.session.service.DeviceHallService;
import ru.avilex.session.service.SessionService;
import ru.avilex.session.stream.dto.external.HearingStreamDTO;

import java.util.Set;
import java.util.function.Consumer;

@Slf4j
@Configuration
@RequiredArgsConstructor

public class StreamConfig {

    private final SessionService sessionService;

    private final SessionMapper sessionMapper;

    private final DeviceHallService deviceHallService;

    private final DeviceHallMapper deviceMapper;


    @Bean
    public Consumer<Message<HallStreamDTO>> hallConsumer() {
        return message -> {
            if (message == null) {
                log.warn("Received message from hall-service is null");
                return;
            }

            log.info("Received {}", message);
            var crud = (String) message.getHeaders().get("crud");
            if (Set.of("create", "update").contains(crud)) {
                log.info("Current CRUD operation - {}", crud);
                var dto = message.getPayload();
                var deviceHall = deviceMapper.fromHallStreamDto(dto);
                deviceHallService.save(deviceHall);
            }
        };
    }

    @Bean
    public Consumer<Message<HearingStreamDTO>> hearingConsumer() {
        return message -> {
            if (message == null) {
                log.warn("Received message from hearing-service is null");
                return;
            }
            log.info("Received {}", message);
            var crud = (String) message.getHeaders().get("crud");
            if (Set.of("create", "update").contains(crud)) {
                log.info("Current CRUD operation - {}", crud);
                var dto = message.getPayload();
                var session = sessionMapper.fromStreamToSession(dto);
                sessionService.save(session);
            }
        };
    }
}
