package ru.avilex.session.controller;

import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.http.ResponseEntity;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import ru.avilex.session.dto.request.BigTvDeviceUpdateRequestDTO;
import ru.avilex.session.dto.request.ChangeStatusRequestDTO;
import ru.avilex.session.dto.request.DeviceUpdateRequestDTO;
import ru.avilex.session.enumeration.DeviceStatus;
import ru.avilex.session.service.DeviceService;

import java.util.UUID;

@Validated
@RestController
@RequestMapping("/api/device")
@RequiredArgsConstructor
public class DeviceController {

    private final DeviceService deviceService;

    @PutMapping
    public ResponseEntity<Void> updateDevice(@Valid @RequestBody DeviceUpdateRequestDTO requestDTO) {
        deviceService.updateDevice(requestDTO);
        return ResponseEntity.noContent().build();
    }

    @PostMapping("/{deviceId}/change-status")
    public ResponseEntity<Void> changeStatus(@PathVariable("deviceId") UUID deviceId,
                                             @Valid @RequestBody ChangeStatusRequestDTO status) {
        deviceService.changeStatus(deviceId, DeviceStatus.fromCode(status.getStatus()));
        return ResponseEntity.noContent().build();
    }

    @PostMapping("/configuration-bulk-edit")
    public ResponseEntity<Void> bulkUpdate(@Valid @RequestBody BigTvDeviceUpdateRequestDTO requestDTO) {
        deviceService.updateDeviceList(requestDTO.getDevices(), requestDTO.getDisplayTime());
        return ResponseEntity.ok().build();
    }

}
