package ru.avilex.session.controller;

import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import ru.avilex.session.dto.ChangeRequestHallIdDTO;
import ru.avilex.session.dto.GeneratePinResponseDTO;
import ru.avilex.session.dto.LogoutRequestDTO;
import ru.avilex.session.dto.request.ChangeStatusRequestDTO;
import ru.avilex.session.dto.request.HallBlockRequestDTO;
import ru.avilex.session.dto.request.HallEditRequestDTO;
import ru.avilex.session.enumeration.DeviceHallStatus;
import ru.avilex.session.service.DeviceHallService;

import java.util.Optional;
import java.util.UUID;

@RestController
@RequestMapping("/api/device-hall")
@RequiredArgsConstructor
public class DeviceHallController {

    private final DeviceHallService deviceHallService;

    @PostMapping("/{deviceHallId}/change-status")
    public ResponseEntity<Void> changeStatus(@PathVariable("deviceHallId") UUID deviceHallId,
                                             @Valid @RequestBody ChangeStatusRequestDTO status) {
        deviceHallService.changeStatus(deviceHallId, DeviceHallStatus.fromCode(status.getStatus()));
        return ResponseEntity.noContent().build();
    }

    @PostMapping("/{deviceHallId}/block")
    public ResponseEntity<Void> changeStatusBlock(@PathVariable("deviceHallId") UUID deviceHallId,
                                                  @Valid @RequestBody HallBlockRequestDTO requestDTO) {
        deviceHallService.changeStatusBlock(deviceHallId, DeviceHallStatus.fromCode(requestDTO.getStatus()), requestDTO.getBlockReason());
        return ResponseEntity.noContent().build();
    }

    @PostMapping
    public ResponseEntity<Void> update(@Valid @RequestBody HallEditRequestDTO requestDTO) {
        deviceHallService.update(requestDTO);
        return ResponseEntity.noContent().build();
    }

    @PostMapping("/logout")
    public ResponseEntity<Void> changeStatusLogout(@Valid @RequestBody LogoutRequestDTO requestDTO) {
        deviceHallService.changeStatusLogout(requestDTO);
        return ResponseEntity.noContent().build();
    }

    @PostMapping("/generate-pin")
    public ResponseEntity<GeneratePinResponseDTO> generatePin(@RequestBody ChangeRequestHallIdDTO changeRequestHallIdDTO) {
        Optional<GeneratePinResponseDTO> changeResponsePinDTO = Optional.of(deviceHallService.changePin(changeRequestHallIdDTO));
        return changeResponsePinDTO
                .map(ResponseEntity::ok)
                .orElseGet(() -> ResponseEntity.status(HttpStatus.NOT_FOUND).build());
    }
}
