package ru.avilex.session.controller;

import jakarta.servlet.http.Cookie;
import jakarta.servlet.http.HttpServletResponse;
import lombok.RequiredArgsConstructor;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import ru.avilex.session.dto.DeviceDTO;
import ru.avilex.session.enumeration.DeviceType;
import ru.avilex.session.mapper.DeviceMapper;
import ru.avilex.session.service.DeviceService;

@RestController
@RequestMapping("/api/device/identification")
@RequiredArgsConstructor
public class DeviceIdentityController {

    private final DeviceService deviceService;
    private final DeviceMapper deviceMapper;

    @PostMapping("/big-tv")
    public ResponseEntity<String> identificateBigTV(@RequestBody DeviceDTO dto, HttpServletResponse response) {
        return identificate(DeviceType.BIGTV, dto, response);
    }

    @PostMapping("/small-tv")
    public ResponseEntity<String> identificateSmallTV(@RequestBody DeviceDTO dto, HttpServletResponse response) {
        return identificate(DeviceType.SMALLTV, dto, response);
    }

    @PostMapping("/tablet")
    public ResponseEntity<String> identificateTablet(@RequestBody DeviceDTO dto, HttpServletResponse response) {
        return identificate(DeviceType.TABLET, dto, response);
    }

    private ResponseEntity<String> identificate(DeviceType type, DeviceDTO dto, HttpServletResponse response) {
        String deviceUuid = deviceService.saveDeviceAndGenerateUuid(type, deviceMapper.toDevice(dto));
        response.addCookie(new Cookie("deviceId", deviceUuid));
        return ResponseEntity.ok(deviceUuid);
    }
}