package ru.avilex.session.controller;

import io.swagger.v3.oas.annotations.Hidden;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.data.domain.Page;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import ru.avilex.session.dto.SessionDTO;
import ru.avilex.session.mapper.SessionMapper;
import ru.avilex.session.model.Session;
import ru.avilex.session.service.SessionService;

import java.util.Objects;
import java.util.UUID;
@Hidden
@RestController
@RequestMapping(value = "api/v1/session")
@RequiredArgsConstructor
public class SessionController {

    private final SessionService sessionService;

    private final SessionMapper sessionMapper;

    @GetMapping("")
    public ResponseEntity<Page<SessionDTO>> getAll(@RequestParam(defaultValue = "0") Integer page,
                                                   @RequestParam(defaultValue = "10") Integer size,
                                                   @RequestParam(defaultValue = "id") String sortBy) {
        if (size > 1000) {
            return new ResponseEntity<>(HttpStatus.BAD_REQUEST);
        }
        return new ResponseEntity<>(sessionService.getAll(page, size, sortBy).map(sessionMapper::toSessionDTO), HttpStatus.OK);
    }

    @GetMapping("/{id}")
    public ResponseEntity<SessionDTO> getById(@PathVariable("id") UUID uuid) {
        return new ResponseEntity<>(sessionMapper.toSessionDTO(sessionService.getById(uuid)), HttpStatus.OK);
    }

    @PostMapping("")
    public ResponseEntity<SessionDTO> create(@Valid @RequestBody SessionDTO sessionDTO) {
        return new ResponseEntity<>(sessionMapper.toSessionDTO(sessionService.save(sessionMapper.toSession(sessionDTO))), HttpStatus.CREATED);
    }

    @PutMapping("/{id}")
    public ResponseEntity<SessionDTO> update(@PathVariable("id") UUID uuid, @Valid @RequestBody SessionDTO sessionDTO) {
        Session currentSession = sessionService.getById(uuid);

        if (currentSession == null) {
            return new ResponseEntity<>(HttpStatus.NOT_FOUND);
        }

        if (!Objects.equals(currentSession.getVersionRow(), sessionDTO.getVersionRow())) {
            return new ResponseEntity<>(HttpStatus.UPGRADE_REQUIRED);
        }

        return new ResponseEntity<>(sessionMapper.toSessionDTO(sessionService.save(sessionMapper.copyDTOtoSession(sessionDTO, currentSession))), HttpStatus.OK);
    }

    @DeleteMapping("/{id}")
    public ResponseEntity<HttpStatus> delete(@PathVariable("id") UUID uuid) {
        sessionService.delete(sessionService.getById(uuid));
        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }
}
