package ru.avilex.session.mapper;

import org.mapstruct.*;
import org.springframework.context.annotation.Configuration;
import ru.avilex.session.dto.SessionDTO;
import ru.avilex.session.dto.SmallTvSessionDTO;
import ru.avilex.session.model.Session;
import ru.avilex.session.stream.dto.SessionStreamDTO;
import ru.avilex.session.stream.dto.external.HearingStreamDTO;

import java.util.List;

@Configuration
@Mapper(
        componentModel = "spring",
        nullValuePropertyMappingStrategy = NullValuePropertyMappingStrategy.IGNORE,
        unmappedTargetPolicy = ReportingPolicy.IGNORE
)
public interface SessionMapper {
    List<SessionDTO> toSessionDTOList(List<Session> sessions);
    List<Session> toSessionList(List<SessionDTO> sessionDTOS);
    Session toSession(SessionDTO sessionDTO);
    SessionDTO toSessionDTO(Session session);
    SessionStreamDTO toStream(Session session);
    @Mapping(target = "statusCodeDeal", source = "statusCode")
    SmallTvSessionDTO fromSessionToSmallTvSessionDTO(Session session);

    @Mapping(target = "uuid", source = "objectId")
    @Mapping(target = "statusCode", ignore = true)
    Session fromStreamToSession(HearingStreamDTO hearingStreamDTO);

    @Mapping(target = "domainEvents", ignore = true)
    @Mapping(target = "createdBy", ignore = true)
    @Mapping(target = "createdOn", ignore = true)
    @Mapping(target = "updatedBy", ignore = true)
    @Mapping(target = "deleted", ignore = true)
    @Mapping(target = "versionRow", ignore = true)
    Session copyDTOtoSession(SessionDTO sessionDTO, @MappingTarget Session session);

    @Mapping(target = "uuid", ignore = true)
    Session updateSession(@MappingTarget Session oldData, Session newData);
}
