package ru.avilex.session.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonProperty.Access;
import jakarta.persistence.*;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import org.springframework.data.annotation.CreatedBy;
import org.springframework.data.annotation.CreatedDate;
import org.springframework.data.annotation.LastModifiedBy;
import org.springframework.data.annotation.LastModifiedDate;
import org.springframework.data.domain.AbstractAggregateRoot;
import org.springframework.data.domain.AfterDomainEventPublication;
import org.springframework.data.domain.DomainEvents;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

@MappedSuperclass
@NoArgsConstructor
@Getter
@Setter
@EntityListeners(AuditingEntityListener.class)
public abstract class AbstractEntity extends AbstractAggregateRoot<AbstractEntity> {

    @Transient
    @JsonIgnore
    private final List<Object> domainEvents = new ArrayList<>();

    @Id
    @Column(name = "id", nullable = false)
    @JsonProperty(access = Access.READ_ONLY)
    public UUID uuid;

    @Version
    @JsonProperty(access = Access.READ_ONLY)
    @Column(name = "version_row", nullable = false)
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long versionRow;

    //TODO impl AuditorAware
    @CreatedBy
    @JsonProperty(access = Access.READ_ONLY)
    @Column(name = "created_by")
    private String createdBy;

    @LastModifiedBy
    @JsonProperty(access = Access.READ_ONLY)
    @Column(name = "updated_by")
    private String updatedBy;

    @CreatedDate
    @JsonProperty(access = Access.READ_ONLY)
    @Column(name = "created_on", nullable = false)
    private LocalDateTime createdOn;

    @LastModifiedDate
    @JsonProperty(access = Access.READ_ONLY)
    @Column(name = "updated_on", nullable = false)
    private LocalDateTime updatedOn;

    @Transient
    @JsonIgnore
    private boolean isDeleted;

    @JsonProperty(access = Access.READ_ONLY)
    public Long getCurrentVersion() {
        return versionRow;
    }

    @DomainEvents
    public List<Object> getDomainEvents() {
        return domainEvents;
    }

    @AfterDomainEventPublication
    public void clearDomainEvents() {
        domainEvents.clear();
    }

    public void publishEvent() {
        registerEvent(this);
    }
}
