package ru.avilex.session.model;

import jakarta.persistence.*;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import ru.avilex.session.enumeration.DeviceHallStatus;
import ru.avilex.session.enumeration.DeviceStatus;
import java.util.UUID;

@Data
@Entity
@AllArgsConstructor
@NoArgsConstructor
@Table(name = "device", schema = "session_service")
@Builder
public class Device {

    @Id
    @GeneratedValue(strategy = GenerationType.UUID)
    private UUID id;

    @Column(name = "device_type", nullable = false)
    private Integer deviceType;

    @Column(name = "manufacturer")
    private String manufacturer;

    @Column(name = "model")
    private String model;

    @Column(name = "status")
    private Integer status;

    @Column(name = "display_hearing_status")
    private Short displayHearingStatus;

    @Column(name ="display_time")
    private Short displayTime;


    @OneToOne(cascade = CascadeType.ALL, fetch = FetchType.LAZY)
    private DeviceHall deviceHall;

    public boolean isConfigured() {
        return status == DeviceStatus.ACTIVATED.getCode()
                && deviceHall != null
                && deviceHall.getUuid() != null
                && deviceHall.getStatus() == DeviceHallStatus.ACTIVATED.getCode();
    }
}

