package ru.avilex.session.repository;

import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;
import ru.avilex.session.model.Device;
import ru.avilex.session.model.DeviceHall;

import java.util.List;
import java.util.Optional;
import java.util.UUID;

@Repository
public interface DeviceRepository extends JpaRepository<Device, UUID> {

    @Query("""
        select d
          from Device d
         where d.deviceType = :deviceType
           and d.deviceHall.uuid = :deviceHallId
    """)
    List<Device> getListByHallId(UUID deviceHallId, Integer deviceType);

    @Modifying
    @Query("""
        update Device d set d.displayTime = :displayTime
            where d.id IN :deviceIds
            and d.deviceType = :deviceType""")
    void updateDisplayTimeForDevicesByIdsAndDeviceType(@Param("displayTime") Integer displayTime,
                                     @Param("deviceIds") List<UUID> deviceIds,
                                     @Param("deviceType") Integer deviceType);

    Device findDeviceByDeviceHall(DeviceHall deviceHall);

    Optional<Device> findDeviceByDeviceHallAndDeviceType(DeviceHall deviceHall, Integer deviceType);
}
