package ru.avilex.session.service;

import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import ru.avilex.session.config.WebSocketPropertiesConfig;
import ru.avilex.session.dto.SmallTvSessionDTO;
import ru.avilex.session.enumeration.DeviceType;
import ru.avilex.session.enumeration.SessionStatus;
import ru.avilex.session.exception.DealStatusChangesException;
import ru.avilex.session.model.Device;
import ru.avilex.session.model.DeviceHall;
import ru.avilex.session.model.Session;
import ru.avilex.session.repository.DeviceRepository;
import ru.avilex.session.repository.SessionRepository;
import ru.avilex.session.validator.DeviceConfigurationValidator;

import java.time.LocalDateTime;
import java.util.List;
import java.util.UUID;

@Service
@RequiredArgsConstructor
public class HearingService {

    private final WebSocketPropertiesConfig webSocketProperties;

    private final SessionRepository sessionRepository;

    private final SessionService sessionService;

    private final DeviceRepository deviceRepository;

    private final DeviceConfigurationValidator deviceConfigurationValidator;

    private final NotificationService notificationService;

    private final SmallTvDtoBuilderService smallTvDtoMappingService;

    private final BigTvDtoBuilderService bigTvDtoMappingService;

    @Transactional
    public void changeHearingStatus(UUID hearingId, Integer status) {
        try {
            Session session = sessionService.getSessionById(hearingId);
            validate(session);
            session.setStatusCode(status);
            if (SessionStatus.COMPLETED.getCode() == status) {
                session.setCompleteTime(LocalDateTime.now());
            }
            sessionRepository.save(session);
            SmallTvSessionDTO smallTvSessionDTO = smallTvDtoMappingService.createSmallTvSessionDTO(session);
            notificationService.notify(webSocketProperties.getSmallTvDestination(), smallTvSessionDTO);
            String bigTvMessage = bigTvDtoMappingService.createBigTvCommonUpdateMessageDTO();
            notificationService.notify(webSocketProperties.getBigTvDestination(), bigTvMessage);
        } catch (Exception e) {
            throw new DealStatusChangesException();
        }
    }

    private void validate(Session session) {
        DeviceHall deviceHall = session.getDeviceHall();
        List<Device> devices = deviceRepository.getListByHallId(deviceHall.getUuid(), DeviceType.TABLET.getId());
        devices.forEach(deviceConfigurationValidator::deviceValidateWithCheckConnectedOrDisabled);
    }
}
