package ru.avilex.session.service;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.messaging.simp.SimpMessagingTemplate;
import org.springframework.stereotype.Service;
import ru.avilex.session.exception.MessageConvertingException;
import ru.avilex.session.exception.SendNotificationException;

@Slf4j
@Service
@RequiredArgsConstructor
public class NotificationServiceImpl implements NotificationService {

    private final SimpMessagingTemplate messagingTemplate;

    private final ObjectMapper objectMapper;

    @Override
    public void notify(String destination, Object message) {
        try {
            String messageAsString = objectMapper.writeValueAsString(message);
            messagingTemplate.convertAndSend(destination, messageAsString);
            log.info("Notification sent: destination - {} and message - {}", destination, messageAsString);
        } catch (JsonProcessingException e) {
            log.error("Failed to convert message - {}", message, e);
            throw new MessageConvertingException(
                    String.format("Message converting exception for message %s", message));
        } catch (Exception e) {
            log.error("Failed to send notification: destination - {} and message - {}", destination, message, e);
            throw new SendNotificationException(
                    String.format("Failed to send notification to destination %s for message %s", destination, message));
        }
    }
}
