package ru.avilex.session.service;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import ru.avilex.session.enumeration.DeviceHallStatus;
import ru.avilex.session.exception.DeviceHallStatusBlockedException;
import ru.avilex.session.exception.NotAuthenticatedPinException;
import ru.avilex.session.model.Device;
import ru.avilex.session.model.DeviceHall;
import ru.avilex.session.model.constant.BlockReasonConstants;
import ru.avilex.session.repository.DeviceRepository;

import java.util.Random;

@Slf4j
@Service
@RequiredArgsConstructor
public class PinCodeService {

    private final DeviceRepository deviceRepository;

    @Transactional(noRollbackFor = {NotAuthenticatedPinException.class, DeviceHallStatusBlockedException.class})
    public void authenticate(Device device, String pinToAuth) {
        DeviceHall deviceHall = device.getDeviceHall();
        String existingPin = deviceHall.getPin();

        if (!pinToAuth.equals(existingPin)) {
            deviceHall.incrementFailedAttempts();
            if (deviceHall.getFailedAttempts() == 3) {
                resetDeviceHall(deviceHall);
                deviceRepository.save(device);
                throw new DeviceHallStatusBlockedException();
            }
            deviceRepository.save(device);
            throw new NotAuthenticatedPinException();
        }
        if (deviceHall.getFailedAttempts() > 0 && deviceHall.getFailedAttempts() < 3) {
            deviceHall.setFailedAttempts((short) 0);
            deviceRepository.save(device);
        }
    }

    private void resetDeviceHall(DeviceHall deviceHall) {
        deviceHall.setBlockReason(BlockReasonConstants.INCORRECT_ENTERED_PIN_BLOCK);
        deviceHall.setPin(null);
        deviceHall.setStatus(DeviceHallStatus.BLOCKED_BY_PIN.getCode());
        deviceHall.setFailedAttempts((short) 0);
    }

    public static String generateRandomPin() {
        Random random = new Random();
        int pin = 1000 + random.nextInt(9000);
        return String.valueOf(pin);
    }

}
