package ru.avilex.session.service;

import jakarta.transaction.Transactional;
import lombok.RequiredArgsConstructor;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;
import ru.avilex.session.exception.DeviceHallAbsentException;
import ru.avilex.session.mapper.SessionMapper;
import ru.avilex.session.model.Session;
import ru.avilex.session.repository.SessionRepository;

import java.util.Objects;
import java.util.UUID;

@Service
@Transactional
@RequiredArgsConstructor
public class SessionService {

    private final SessionRepository sessionRepository;

    private final SessionMapper sessionMapper;

    public Page<Session> getAll(Integer pageNo, Integer pageSize, String sortBy) {
        return sessionRepository.findAll(PageRequest.of(pageNo, pageSize, Sort.by(sortBy)));
    }

    public Session getById(UUID id) {
        return sessionRepository.getReferenceById(id);
    }

    public Session save(Session session) {
        return sessionRepository.save(sessionRepository.findById(session.getUuid())
                .map(existingSession -> sessionMapper.updateSession(existingSession, session))
                .orElse(session));
    }

    public void delete(Session session) {
        sessionRepository.delete(session);
    }

    public Session getSessionById(UUID hearingID) {
        Session session = sessionRepository.getReferenceById(hearingID);
        if (session==null) {
            throw new DeviceHallAbsentException();
        }
        return session;
    }
}
