package ru.avilex.session.service;

import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import ru.avilex.session.dto.SmallTvSessionDTO;
import ru.avilex.session.enumeration.DeviceType;
import ru.avilex.session.exception.EntityNotFoundException;
import ru.avilex.session.mapper.SessionMapper;
import ru.avilex.session.model.Device;
import ru.avilex.session.model.DeviceHall;
import ru.avilex.session.model.Session;
import ru.avilex.session.repository.DeviceRepository;

@Service
@RequiredArgsConstructor
public class SmallTvDtoBuilderService {

    private final DeviceRepository deviceRepository;

    private final SessionMapper sessionMapper;

    public SmallTvSessionDTO createSmallTvSessionDTO(Session session) {
        SmallTvSessionDTO smallTvSessionDTO = sessionMapper.fromSessionToSmallTvSessionDTO(session);
        DeviceHall deviceHall = session.getDeviceHall();
        Integer deviceTypeId = DeviceType.SMALLTV.getId();
        Device device = deviceRepository.findDeviceByDeviceHallAndDeviceType(deviceHall, deviceTypeId)
                .orElseThrow(() -> new EntityNotFoundException(
                        String.format("Device with given deviceHallId [%s] and deviceTypeId [%s] not found",
                                deviceHall.getUuid(), deviceTypeId)));
        smallTvSessionDTO.setDeviceId(device.getId());
        return smallTvSessionDTO;
    }

}