package ru.avilex.session.stream;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.stream.function.StreamBridge;
import org.springframework.messaging.Message;
import org.springframework.messaging.support.MessageBuilder;
import org.springframework.stereotype.Component;
import org.springframework.transaction.event.TransactionPhase;
import org.springframework.transaction.event.TransactionalEventListener;
import ru.avilex.session.mapper.SessionMapper;
import ru.avilex.session.model.Session;
import ru.avilex.session.stream.dto.SessionStreamDTO;

@Slf4j
@Component
@RequiredArgsConstructor
public class SessionStream {

    private final StreamBridge streamBridge;

    private final SessionMapper sessionMapper;

    @TransactionalEventListener(phase = TransactionPhase.AFTER_COMMIT)
    public void event(Session session) {
        try {
            Message<SessionStreamDTO> message = MessageBuilder.withPayload(sessionMapper.toStream(session))
//                  .setHeader("partitionKey", Long partitionKey)
                    .setHeader("crud", getCrudOperation(session))
                    .build();
            streamBridge.send("entityProducer-out-0", message);
            log.info("Headers: {} Payload: {}", message.getHeaders(), message.getPayload());
        } catch (Exception e) {
            log.error("Error", e);
            throw new RuntimeException(e);
        }
    }

    private String getCrudOperation(Session session) {
        if (session.isDeleted()) {
            return "delete";
        }
        if (session.getVersionRow() == 0) {
            return "create";
        } else {
            return "update";
        }
    }
}