package ru.avilex.session.validator;

import org.springframework.stereotype.Component;
import ru.avilex.session.enumeration.DeviceHallStatus;
import ru.avilex.session.enumeration.DeviceStatus;
import ru.avilex.session.exception.*;
import ru.avilex.session.model.Device;

import java.util.Set;

@Component
public class DeviceConfigurationValidator implements Validator<Device> {

    @Override
    public void validate(Device device) {
        validateOnDeviceHallAbsent(device);
        validateOnDeviceDisabled(device);
        validateDeviceHallCheckActivateOrNot(device);
        validateOnDeviceHallBlockedOrDeleted(device);
    }

    public void validateDeviceHallCheckActivateOrNot(Device device) {
        if (DeviceHallStatus.ACTIVATED.getCode() == device.getDeviceHall().getStatus()) {
            throw new DeviceHallActivateOrNotException();
        }
    }

    public void deviceValidateWithCheckConnectedOrDisabled(Device device) {
        validateOnDeviceHallConnectedOrDisabled(device);
        validateOnDeviceHallLogout(device);
        validateOnDeviceHallBlockedOrDeleted(device);
    }

    private void validateOnDeviceHallAbsent(Device device) {
        if (device.getDeviceHall() == null) {
            throw new DeviceHallAbsentException();
        }
    }

    private void validateOnDeviceDisabled(Device device) {
        if (Set.of(DeviceStatus.CONNECTED.getCode(), DeviceStatus.DISABLED.getCode()).contains(device.getStatus())) {
            throw new DeviceDisabledException();
        }
    }

    private void validateOnDeviceHallLogout(Device device) {
        if (DeviceHallStatus.LOGOUT.getCode() == device.getDeviceHall().getStatus()) {
            throw new DeviceHallLogoutException();
        }
    }

    public void validateOnDeviceHallBlockedOrDeleted(Device device) {
        if (DeviceHallStatus.DELETED.getCode() == device.getDeviceHall().getStatus()
                || DeviceHallStatus.BLOCKED.getCode() == device.getDeviceHall().getStatus()
                || DeviceHallStatus.BLOCKED_BY_PIN.getCode() == device.getDeviceHall().getStatus()) {
            throw new DeviceHallBlockedOrDeletedException();
        }
    }

    private void validateOnDeviceHallConnectedOrDisabled(Device device) {
        if (DeviceStatus.CONNECTED.getCode() == device.getStatus()
                || device.getStatus() == DeviceStatus.DISABLED.getCode()) {
            throw new DeviceHallAbsentException();
        }
    }

}
