package ru.avilex.showcase.controller;

import lombok.RequiredArgsConstructor;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import ru.avilex.showcase.dto.HallCardResponseDTO;
import ru.avilex.showcase.dto.HallDeviceDTO;
import ru.avilex.showcase.dto.HallResponseDTO;
import ru.avilex.showcase.dto.PageDTO;
import ru.avilex.showcase.dto.response.DeviceHallResponseDTO;
import ru.avilex.showcase.service.DeviceHallService;

import java.util.Objects;
import java.util.UUID;

@RestController
@RequestMapping(value = "/api/device-hall")
@RequiredArgsConstructor
public class DeviceHallController {

    private final DeviceHallService deviceHallService;

    @GetMapping("/device-type")
    public ResponseEntity<DeviceHallResponseDTO> getByDeviceTypeId(@RequestParam(required = false) Integer deviceTypeId) {
        return ResponseEntity.ok(new DeviceHallResponseDTO(deviceHallService.getListByDeviceTypeId(deviceTypeId)));
    }

    @GetMapping
    public ResponseEntity<PageDTO<HallResponseDTO>> getList(@RequestParam Integer deviceType,
                                                            @RequestParam(defaultValue = "0", required = false) Integer page,
                                                            @RequestParam(defaultValue = "20", required = false) Integer size,
                                                            @RequestParam(required = false) Integer statusId,
                                                            @RequestParam(required = false) String sortDirect,
                                                            @RequestParam(required = false) UUID hallId) {
        Boolean sort = null;
        if (Objects.nonNull(sortDirect) && !sortDirect.isEmpty()) {
            if (sortDirect.equalsIgnoreCase("True")) {
                sort = true;
            } else if (sortDirect.equalsIgnoreCase("False")) {
                sort = false;
            }
        }
        return deviceHallService.getList(deviceType, statusId, sort, hallId, page, size)
                .map(ResponseEntity::ok)
                .orElseGet(() -> ResponseEntity.status(417).build());
    }

    @GetMapping("/list")
    public ResponseEntity<PageDTO<HallDeviceDTO>> getHalls(@RequestParam(defaultValue = "0") int page,
                                                           @RequestParam(defaultValue = "20") int size) {
        return deviceHallService.getDeviceHallList(page, size)
                .map(ResponseEntity::ok)
                .orElseGet(() -> ResponseEntity.status(417).build());
    }

    @GetMapping("/{id}")
    public ResponseEntity<HallCardResponseDTO> getCard(@PathVariable UUID id) {
        return deviceHallService.getById(id)
                .map(ResponseEntity::ok)
                .orElseGet(() -> ResponseEntity.status(404).build());

    }

}
