package ru.avilex.showcase.controller;

import lombok.RequiredArgsConstructor;
import org.springframework.data.domain.Page;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import ru.avilex.showcase.dto.CompletedSessionDTO;
import ru.avilex.showcase.dto.HallSessionResponseDTO;
import ru.avilex.showcase.dto.device.BigTvSessionResponseDTO;
import ru.avilex.showcase.dto.device.SmallTvSessionDTO;
import ru.avilex.showcase.enumerations.DeviceType;
import ru.avilex.showcase.service.HearingSessionService;

import java.util.List;
import java.util.UUID;

@RestController
@RequiredArgsConstructor
@RequestMapping(value = "api/v1/hearing-session")
public class HearingSessionController {

    private final HearingSessionService hearingSessionService;

    @GetMapping(value = "/{deviceHallId}")
    public ResponseEntity<HallSessionResponseDTO> getById(@PathVariable("deviceHallId") UUID deviceHallId) {
        return new ResponseEntity<>(hearingSessionService.getById(deviceHallId, DeviceType.TABLET.getId()), HttpStatus.OK);
    }

    @GetMapping(value = "/big-tv/{deviceId}")
    public ResponseEntity<BigTvSessionResponseDTO> getBigTvSessions(@PathVariable("deviceId") UUID deviceId) {
        return new ResponseEntity<>(hearingSessionService.getByBigTvSessions(deviceId), HttpStatus.OK);
    }

    @GetMapping(value = "/small-tv/{deviceId}")
    public ResponseEntity<SmallTvSessionDTO> getSmallTvSession(@PathVariable("deviceId") UUID deviceId) {
        return new ResponseEntity<>(hearingSessionService.getSmallTvActiveSession(deviceId), HttpStatus.OK);
    }

    @GetMapping(value = "/{deviceId}/completed")
    public ResponseEntity<List<CompletedSessionDTO>> getCompleted(@PathVariable UUID deviceId,
                                                                  @RequestParam(defaultValue = "0") int page,
                                                                  @RequestParam(defaultValue = "20") int size) {
        List<CompletedSessionDTO> completedSessions = hearingSessionService.getCompletedSessions(deviceId, page, size);
        return ResponseEntity.ok(completedSessions);
    }
}
