package ru.avilex.showcase.repository;

import jakarta.persistence.EntityManager;
import jakarta.persistence.Tuple;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Repository;
import ru.avilex.showcase.dto.DeviceHallDeviceDTO;

import java.util.List;
import java.util.UUID;

@Repository
@RequiredArgsConstructor
public class DeviceHallDeviceRepository {

    private final EntityManager entityManager;

    public DeviceHallDeviceDTO findByDeviceId(UUID deviceId) {
        var sql = """
                 SELECT
                    dh.id as device_hall_id,
                    dh.status as device_hall_status,
                    d.status as device_status,
                    dh.name as device_hall_name
                 FROM session_service.device_hall dh
                 JOIN session_service.device d ON dh.id = d.device_hall_id
                 WHERE d.id = :deviceId
                """;

        var query = entityManager.createNativeQuery(sql, Tuple.class);
        query.setParameter("deviceId", deviceId);

        List<Tuple> results = query.getResultList();
        return results.stream()
                .map(tuple -> new DeviceHallDeviceDTO(
                        tuple.get("device_hall_id", UUID.class),
                        tuple.get("device_hall_status", Short.class),
                        tuple.get("device_status", Short.class),
                        tuple.get("device_hall_name", String.class)))
                .findFirst()
                .orElse(null);
    }
}
