package ru.avilex.showcase.repository;

import jakarta.persistence.EntityManager;
import jakarta.persistence.Tuple;
import lombok.RequiredArgsConstructor;
import org.springframework.jdbc.core.namedparam.MapSqlParameterSource;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;
import org.springframework.stereotype.Repository;
import ru.avilex.showcase.dto.DeviceConfigurationDTO;
import ru.avilex.showcase.dto.DeviceHallStatusDTO;
import ru.avilex.showcase.dto.DeviceHearingDTO;
import ru.avilex.showcase.dto.DeviceStatusDTO;
import ru.avilex.showcase.mapper.DeviceConfigurationDTORowMapper;

import java.util.Optional;
import java.util.UUID;

@Repository
@RequiredArgsConstructor
public class DeviceRepository {

    private final EntityManager entityManager;
    private final NamedParameterJdbcTemplate namedParameterJdbcTemplate;

    public Optional<DeviceStatusDTO> getByHallId(UUID hallId, Integer deviceType) {
        String sql = """
                                SELECT d.status AS statusDevice,
                                        dh.status AS statusHall
                                FROM session_service.device d
                inner join  session_service.device_hall dh on dh.id = d.device_hall_id
                                WHERE d.device_hall_id = :id and d.device_type = :deviceType
                        """;

        try {
            var query = entityManager.createNativeQuery(sql, Tuple.class);
            query.setParameter("id", hallId);
            query.setParameter("deviceType", deviceType);
            if (!query.getResultList().isEmpty()) {
                Tuple result = (Tuple) query.getResultList().get(0);
                DeviceStatusDTO dto = new DeviceStatusDTO(
                        result.get("statusDevice", Short.class),
                        new DeviceHallStatusDTO(result.get("statusHall", Short.class))
                );
                return Optional.of(dto);
            } else {
                return Optional.empty();
            }
        } catch (Exception e) {
            return Optional.empty();
        }
    }

    public DeviceConfigurationDTO findDeviceConfiguration(UUID deviceId) {
        MapSqlParameterSource parameters = new MapSqlParameterSource();
        parameters.addValue("deviceId", deviceId);

        String sql = """
                SELECT d.display_hearing_status, d.display_time ,d.status
                FROM session_service.device d
                WHERE id = :deviceId
                 """;

        return namedParameterJdbcTemplate.queryForObject(
                sql,
                parameters,
                new DeviceConfigurationDTORowMapper()
        );
    }

    public DeviceHearingDTO getDeviceId(UUID deviceId) {
        String sql = """
                 SELECT d.id as deviceId,
                        d.status 
                 FROM session_service.device d
                 WHERE d.id = :deviceId
                 LIMIT 1
                """;
        var query = entityManager.createNativeQuery(sql);
        query.setParameter("deviceId", deviceId);
        Object[] result = (Object[]) query.getSingleResult();
        return new DeviceHearingDTO(
                (UUID) result[0],
                (Short) result[1]
        );
    }
}

