package ru.avilex.showcase.service;

import jakarta.transaction.Transactional;
import lombok.RequiredArgsConstructor;
import org.springframework.data.domain.PageRequest;
import org.springframework.stereotype.Service;
import ru.avilex.showcase.dto.CompletedSessionDTO;
import ru.avilex.showcase.dto.DeviceHearingDTO;
import ru.avilex.showcase.dto.DeviceStatusDTO;
import ru.avilex.showcase.dto.HallSessionResponseDTO;
import ru.avilex.showcase.dto.device.BigTvSessionResponseDTO;
import ru.avilex.showcase.dto.device.SmallTvSessionDTO;
import ru.avilex.showcase.exception.CourtRoomInformationException;
import ru.avilex.showcase.exception.NotFoundException;
import ru.avilex.showcase.repository.DeviceRepository;
import ru.avilex.showcase.repository.HearingSessionRepository;
import ru.avilex.showcase.validator.ConfigurationValidator;
import ru.avilex.showcase.validator.DeviceConfigurationValidator;
import ru.avilex.showcase.validator.DeviceHearingValidator;

import java.util.List;
import java.util.UUID;


@Service
@Transactional
@RequiredArgsConstructor
public class HearingSessionService {

    private final HearingSessionRepository hearingSessionRepository;
    private final DeviceConfigurationValidator deviceConfigurationValidator;
    private final DeviceHearingValidator deviceHearingValidator;
    private final ConfigurationValidator configurationValidator;
    private final DeviceRepository deviceRepository;

    public HallSessionResponseDTO getById(UUID hallId, int id) {
        DeviceStatusDTO dto = deviceRepository.getByHallId(hallId, id).orElseThrow(CourtRoomInformationException::new);
        deviceConfigurationValidator.validate(dto);
        if (hallId == null) {
            throw new NotFoundException("Could not find session");
        }
        return hearingSessionRepository.findByHallId(hallId.toString());
    }

    public BigTvSessionResponseDTO getByBigTvSessions(UUID deviceId) {
        DeviceHearingDTO dto = deviceRepository.getDeviceId(deviceId);
        deviceHearingValidator.validate(dto);
        return BigTvSessionResponseDTO.builder()
                .waitingSessions(hearingSessionRepository.getSessionsByStatus(0))
                .inProgressSessions(hearingSessionRepository.getSessionsByStatus(1))
                .build();
    }

    public SmallTvSessionDTO getSmallTvActiveSession(UUID deviceId) {
        DeviceHearingDTO dto=deviceRepository.getDeviceId(deviceId);
        deviceHearingValidator.validate(dto);
        return hearingSessionRepository.getSmallTvActiveSession(deviceId);
    }


    public List<CompletedSessionDTO> getCompletedSessions(UUID deviceId, int page, int size) {
        List<CompletedSessionDTO> completedSessionDTOS = hearingSessionRepository.findCompletedSessions(deviceId, PageRequest.of(page, size));
        completedSessionDTOS.forEach(configurationValidator::validate);
        return completedSessionDTOS;
    }
}


