package ru.avilex.showcase.validator;

import org.springframework.stereotype.Component;
import ru.avilex.showcase.dto.CompletedSessionDTO;
import ru.avilex.showcase.enumerations.DeviceStatus;
import ru.avilex.showcase.enumerations.DisplayHearingStatus;
import ru.avilex.showcase.exception.СonfiguratioDataException;
import ru.avilex.showcase.exception.DeviceDisabledException;

import java.util.Set;


@Component
public class ConfigurationValidator implements Validator<CompletedSessionDTO> {

    @Override
    public void validate(CompletedSessionDTO completedSessionDTO) {
        validateOnDeviceDisabled(completedSessionDTO);
        validateOnDisplayHearingStatus(completedSessionDTO);
    }

    private void validateOnDeviceDisabled(CompletedSessionDTO completedSessionDTO) {
        if (completedSessionDTO.getStatus()==null || Set.of(DeviceStatus.CONNECTED.getCode(),
                DeviceStatus.DISABLED.getCode()).contains(Integer.valueOf(completedSessionDTO.getStatus()))) {
            throw new DeviceDisabledException();
        }
    }

    private void validateOnDisplayHearingStatus(CompletedSessionDTO completedSessionDTO) {
        if (completedSessionDTO.getStatus()==null ||
                completedSessionDTO.getDisplayHearingStatus() != DisplayHearingStatus.COMPLETED.getCode()) {
            throw new СonfiguratioDataException();
        }
    }
}
