package ru.avilex.showcase.validator;

import org.springframework.stereotype.Component;
import ru.avilex.showcase.dto.DeviceStatusDTO;
import ru.avilex.showcase.enumerations.DeviceHallStatus;
import ru.avilex.showcase.enumerations.DeviceStatus;
import ru.avilex.showcase.exception.DeviceDisabledException;
import ru.avilex.showcase.exception.DeviceHallLogoutException;

import java.util.Set;

@Component
public class DeviceConfigurationValidator implements Validator<DeviceStatusDTO> {

    @Override
    public void validate(DeviceStatusDTO device) {
        validateOnDeviceDisabled(device);
        validateOnDeviceHallLogout(device);
        validateOnDeviceHallBlockedOrDeleted(device);
    }

    private void validateOnDeviceDisabled(DeviceStatusDTO device) {
        if (Set.of(DeviceStatus.CONNECTED.getCode(), DeviceStatus.DISABLED.getCode()).contains(Integer.valueOf(device.getStatus()))) {
            throw new DeviceDisabledException();
        }
    }

    private void validateOnDeviceHallLogout(DeviceStatusDTO device) {
        if (DeviceHallStatus.LOGOUT.getCode() == device.getDeviceHall().getStatus()) {
            throw new DeviceHallLogoutException();
        }
    }

    private void validateOnDeviceHallBlockedOrDeleted(DeviceStatusDTO device) {
        if (DeviceHallStatus.DELETED.getCode() == device.getDeviceHall().getStatus()
                || DeviceHallStatus.BLOCKED.getCode() == device.getDeviceHall().getStatus()) {
            throw new DeviceDisabledException();
        }
    }


}
