import 'package:al/activation/activation_dependencies.dart';
import 'package:al/activation/logic/entities/activation_hall_info.dart';
import 'package:al/framework/storages/secure_storage.dart';
import 'package:al/framework/timer/logic/repositories/server_timer_repository.dart';
import 'package:al/activation/logic/repository/activation_repository.dart';
import 'package:bloc/bloc.dart';
import 'package:equatable/equatable.dart';

part 'activation_state.dart';

class ActivationCubit extends Cubit<ActivationState> {
  final IActivationCompletionDelegate completionDelegate;
  final ServerTimerRepository serverTimerRepository;
  final ActivationRepository activationRepository;

  ActivationCubit({
    required this.completionDelegate,
    required ISecureStorage secureStorage,
    required this.serverTimerRepository,
    required this.activationRepository,
  }) : super(ActivationInitial(
          date: null,
          uuid: secureStorage.uuid,
        ));

  Future<void> initialize() async {
    final date = await serverTimerRepository.getCurrentTime();

    emit(
      ActivationInitial(
        date: date,
        uuid: state.uuid,
      ),
    );

    _checkForActivation();
  }

  Future<void> _checkForActivation() async {
    final hallInfo = await activationRepository.checkActivationUntilActivated();

    emit(ActivationSuccess(
      date: state.date,
      uuid: state.uuid,
      activationHallInfo: hallInfo,
    ));

    completionDelegate.notifyActivationCompletion();
  }
}
