import 'package:al/framework/extensions/build_context_extension.dart';
import 'package:al/framework/formatters/al_date_formatter.dart';
import 'package:al/activation/logic/bloc/activation_cubit.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

class ActivationPage extends StatefulWidget {
  final PreferredSizeWidget Function({
    required BuildContext context,
    Widget? title,
  }) onGetAppBar;

  const ActivationPage({
    super.key,
    required this.onGetAppBar,
  });

  @override
  State<ActivationPage> createState() => _ActivationPageState();
}

class _ActivationPageState extends State<ActivationPage> {
  ActivationCubit get _cubit => context.read<ActivationCubit>();

  @override
  void initState() {
    _cubit.initialize();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<ActivationCubit, ActivationState>(
      builder: _buildCurrentState,
    );
  }

  Widget _buildCurrentState(BuildContext context, ActivationState state) {
    return Scaffold(
      appBar: widget.onGetAppBar(
        context: context,
      ),
      body: _buildContent(state),
    );
  }

  Widget _buildContent(ActivationState state) {
    return Center(
      child: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          Text(
            'Активируйте устройство',
            style: context.textStyles.pinTitle,
          ),
          const SizedBox(
            height: 20,
          ),
          Column(
            mainAxisSize: MainAxisSize.min,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              const Text(
                'UUID',
                style: TextStyle(fontSize: 18.0),
              ),
              Text(
                state.uuid ?? '',
              ),
            ],
          ),
        ],
      ),
    );
  }

  Widget _getCurrentDate(DateTime? date) {
    if (date == null) return const SizedBox.shrink();

    return Padding(
      padding: const EdgeInsets.only(
        left: 16.0,
      ),
      child: Text(
        ALDateFormatter.format(date, ALDateFormat.dmy),
        // TODO переделать нормально стили
        style: TextStyle(
          fontSize: 24.0,
          color: Colors.white,
        ),
      ),
    );
  }
}
