import 'dart:async';

import 'package:al/appbar/logic/cubit/appbar_state.dart';
import 'package:al/framework/timer/logic/repositories/server_timer_repository.dart';
import 'package:bloc/bloc.dart';

class AppBarCubit extends Cubit<AppBarState> {
  final ServerTimerRepository appBarRepository;

  late final StreamSubscription _eventsSubscription;

  AppBarCubit({
    required this.appBarRepository,
  }) : super(const AppBarInitial(time: null)) {
    _eventsSubscription = appBarRepository.eventStream.listen(_onTimeChange);
  }

  Future<void> init() async {
    try {
      final time = await appBarRepository.getCurrentTime();

      emit(AppBarInitial(time: time));
    } catch (_) {
      // TODO прикрепить обработку ошибок
    }
  }

  void _onTimeChange(DateTime time) {
    emit(AppBarInitial(time: time));
  }

  @override
  Future<void> close() {
    _eventsSubscription.cancel();
    return super.close();
  }
}
