import 'package:al/activation/logic/repository/activation_repository.dart';
import 'package:al/framework/storages/secure_storage.dart';
import 'package:bloc/bloc.dart';
import 'package:equatable/equatable.dart';
import 'package:al/auth/auth_dependencies.dart';
import 'package:al/auth/logic/repository/auth_repository.dart';

part 'auth_state.dart';

class AuthCubit extends Cubit<AuthState> {
  final AuthRepository authRepository;
  final IAuthCompletionDelegate completionDelegate;

  AuthCubit({
    required ISecureStorage secureStorage,
    required ActivationRepository activationRepository,
    required this.authRepository,
    required this.completionDelegate,
  }) : super(AuthInitial(
          hallName: activationRepository.hallInfo.hallName,
          uuid: secureStorage.uuid!,
          attemptCount: 0,
        ));

  Future<void> tryAuthorize({required String pin}) async {
    emit(AuthInProgress(
      hallName: state.hallName,
      uuid: state.uuid,
      attemptCount: state.attemptCount,
    ));

    final result = await authRepository.authorize(pin: pin);

    if (result == true) {
      emit(AuthSuccess(
        hallName: state.hallName,
        uuid: state.uuid,
        attemptCount: state.attemptCount,
      ));
      completionDelegate.notifyLoginCompletion();
    } else {
      emit(AuthFail(
        hallName: state.hallName,
        uuid: state.uuid,
        attemptCount: state.attemptCount,
      ));
    }
  }

  void notifyFailProcessed() {
    emit(AuthInitial(
      hallName: state.hallName,
      uuid: state.uuid,
      attemptCount: state.attemptCount,
    ));
  }
}
