import 'dart:async';

import 'package:al/auth/auth_dependencies.dart';
import 'package:al/auth/logic/network/auth_logout_request.dart';
import 'package:al/auth/logic/network/auth_logout_response.dart';
import 'package:al/auth/logic/network/auth_request.dart';
import 'package:al/auth/logic/network/auth_response.dart';
import 'package:al/framework/network/request_sender.dart';
import 'package:al/framework/storages/secure_storage.dart';

class AuthRepository {
  final ISecureStorage secureStorage;
  final RequestSender requestSender;
  final IAuthSleepTimeLogoutDelegate sleepTimeLogoutDelegate;

  Timer? _sleepTimer;

  AuthRepository({
    required this.secureStorage,
    required this.requestSender,
    required this.sleepTimeLogoutDelegate,
  });

  Future<bool> authorize({required String pin}) async {
    final uuid = secureStorage.uuid!;

    try {
      final response = await requestSender.send(
        AuthRequest(uuid: uuid, pin: pin),
        AuthResponse(),
      );

      final sleepTime = response.authHallInfo.sleepTime;
      _sleepTimer?.cancel();
      if (sleepTime != 0) {
        _sleepTimer = Timer(
          Duration(minutes: sleepTime),
          () => sleepTimeLogoutDelegate.notifySleepTimeLogout(),
        );
      }
      return true;
    } on Exception catch (_) {
      // TODO вставить обработку ошибок
    }

    return false;
  }

  Future<void> logout({required String hallId}) async {
    try {
      await requestSender.send(
        AuthLogoutRequest(hallId: hallId),
        AuthLogoutResponse(),
      );
      _sleepTimer?.cancel();
    } on Exception catch (_) {
      // TODO вставить обработку ошибок
    }
  }
}
