import 'package:al/appbar/res/appbar_styles.dart';
import 'package:al/framework/extensions/build_context_extension.dart';
import 'package:al/framework/ui/widgets/al_pincode.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:al/auth/logic/bloc/auth_cubit.dart';

class AuthPage extends StatefulWidget {
  final PreferredSizeWidget Function({
    required BuildContext context,
    Widget? title,
  }) onGetAppBar;

  const AuthPage({
    super.key,
    required this.onGetAppBar,
  });

  @override
  State<AuthPage> createState() => _AuthPageState();
}

class _AuthPageState extends State<AuthPage> {
  AuthCubit get _cubit => context.read<AuthCubit>();

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<AuthCubit, AuthState>(
      builder: _buildCurrentState,
    );
  }

  Widget _buildCurrentState(BuildContext context, AuthState state) {
    return AbsorbPointer(
      absorbing: state is AuthInProgress,
      child: Scaffold(
        appBar: widget.onGetAppBar(
          context: context,
          title: _buildAppBarTitle(state),
        ),
        body: _buildContent(state),
      ),
    );
  }

  Widget _buildContent(AuthState state) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: [
        _buildUuid(state),
        Expanded(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisSize: MainAxisSize.min,
            children: [
              Text(
                'Введите PIN-код',
                style: context.textStyles.pinTitle,
              ),
              const SizedBox(
                height: 20,
              ),
              if (state is AuthFail)
                const Text(
                  'PIN введен неверно',
                  style: TextStyle(color: Colors.red, fontSize: 24.0),
                ),
              _buildPin(state),
            ],
          ),
        ),
      ],
    );
  }

  Widget _buildAppBarTitle(AuthState state) {
    return Text(
      "Зал: ${state.hallName}",
      style: AppBarStyles.appBarText,
    );
  }

  Widget _buildUuid(AuthState state) {
    return Padding(
      padding: const EdgeInsets.all(20.0),
      child: Align(
        alignment: Alignment.topLeft,
        child: Text("UUID ${state.uuid}"),
      ),
    );
  }

  Widget _buildPin(AuthState state) {
    if (state is AuthInProgress) {
      return const Center(
        child: CircularProgressIndicator(),
      );
    } else {
      return SizedBox(
        height: 400.0,
        child: ALPin(
          onPinEntered: (pin) => _cubit.tryAuthorize(pin: pin),
          onPinChanged: () {
            if (state is AuthFail) _cubit.notifyFailProcessed();
          },
          isPinCorrect: state is AuthSuccess,
          attemptCount: state.attemptCount,
          hasError: state is AuthFail,
        ),
      );
    }
  }
}
