import 'dart:async';

import 'package:flutter/material.dart';
import 'package:oktoast/oktoast.dart';
import 'package:synchronized/synchronized.dart';

/// Виджет нужно положить в корень дерева виджетов. Он нужен, чтобы нормально работал
/// механизм отображения уведомлений об отправке событий аналитики
class AnalyticsNotifierWidget extends StatelessWidget {
  final Widget child;

  // Используется, чтобы тосты показывались друг за другом
  static final _toastLock = Lock();

  const AnalyticsNotifierWidget({
    super.key,
    required this.child,
  });

  static showNotification(String text) {
    _toastLock.synchronized(() async {
      final asyncToast = _AsyncToast();
      await asyncToast.show(text);
    });
  }

  @override
  Widget build(BuildContext context) {
    return OKToast(child: child);
  }
}

/// Класс дает возможность отследить скрытие тостов с помощью async/await
class _AsyncToast {
  final _completer = Completer();

  Future<void> show(String text) {
    showToast(
      text,
      backgroundColor: Colors.black.withOpacity(0.9),
      duration: const Duration(seconds: 4),
      position: ToastPosition.top,
      onDismiss: () => _completer.complete(),
    );

    return _completer.future;
  }
}
