import 'package:flutter/material.dart';
import 'package:al/framework/extensions/build_context_extension.dart';
import 'package:al/framework/ui/widgets/buttons/al_button.dart';

class ErrorHandlerWidget extends StatelessWidget {
  final String headerText;
  final String detailsText;
  final String? technicalInfoText;
  final String actionButtonText;
  final VoidCallback onActionButtonTap;

  const ErrorHandlerWidget({
    super.key,
    required this.headerText,
    required this.detailsText,
    required this.technicalInfoText,
    required this.actionButtonText,
    required this.onActionButtonTap,
  });

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      minimum: const EdgeInsets.only(bottom: 12.0),
      child: Container(
        padding: const EdgeInsets.symmetric(horizontal: 16.0),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.end,
          crossAxisAlignment: CrossAxisAlignment.stretch,
          children: [
            Expanded(
              child: _buildScrollableBlock(
                child: _buildMessageContent(context),
              ),
            ),
            ALButton(
              onPressed: onActionButtonTap,
              text: actionButtonText,
            ),
          ],
        ),
      ),
    );
  }

  Widget _buildScrollableBlock({required Widget child}) {
    return Center(
      child: SingleChildScrollView(
        physics: const ClampingScrollPhysics(),
        child: Padding(
          padding: const EdgeInsets.symmetric(vertical: 12.0),
          child: child,
        ),
      ),
    );
  }

  Widget _buildMessageContent(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        SizedBox(
          width: 300.0,
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              if (headerText.isNotEmpty) ...[
                Text(
                  headerText,
                  style: context.textStyles.title3Bold,
                  textAlign: TextAlign.center,
                ),
                const SizedBox(height: 12.0),
              ],
              Text(
                _detailsText,
                style: context.textStyles.textListRegular,
                textAlign: TextAlign.center,
              ),
            ],
          ),
        ),
      ],
    );
  }

  String get _detailsText {
    return technicalInfoText != null && technicalInfoText != detailsText
        ? "$detailsText\n\n$technicalInfoText"
        : detailsText;
  }
}
