
import 'package:al/framework/errors/exceptions/server_message_exception/server_message_exception_message.dart';

class _ErrorCodes {
  static const authError1 = 401;
  static const authError2 = 403;
  static const authError3 = 113;
  static const authError4 = 114;
}

class _ServerErrorCodes {
  static const internalServerError = 500;
  static const notImplemented = 501;
  static const badGateway = 502;
  static const serviceUnavailable = 503;
  static const gatewayTimeout = 504;
  static const httpVersionNotSupported = 505;
  static const variantAlsoNegotiates = 506;
  static const insufficientStorage = 507;
  static const loopDetected = 508;
  static const notExtended = 510;
}

enum ServerMessageExceptionType { noAuth, internal, general }

class ServerMessageException implements Exception {
  final String? rawMessage;
  final ServerMessageExceptionMessage? message;
  final int code;

  ServerMessageException({
    required this.rawMessage,
    required this.message,
    required this.code,
  });

  ServerMessageExceptionType get type {
    switch (code) {
      case _ErrorCodes.authError1:
      case _ErrorCodes.authError2:
      case _ErrorCodes.authError3:
      case _ErrorCodes.authError4:
        return ServerMessageExceptionType.noAuth;

      case _ServerErrorCodes.internalServerError:
      case _ServerErrorCodes.notImplemented:
      case _ServerErrorCodes.badGateway:
      case _ServerErrorCodes.serviceUnavailable:
      case _ServerErrorCodes.gatewayTimeout:
      case _ServerErrorCodes.httpVersionNotSupported:
      case _ServerErrorCodes.variantAlsoNegotiates:
      case _ServerErrorCodes.insufficientStorage:
      case _ServerErrorCodes.loopDetected:
      case _ServerErrorCodes.notExtended:
        return ServerMessageExceptionType.internal;

      default:
        return ServerMessageExceptionType.general;
    }
  }

  ServerMessageException copyWith({
    String? rawMessage,
    ServerMessageExceptionMessage? message,
    int? code,
  }) {
    return ServerMessageException(
      rawMessage: rawMessage ?? this.rawMessage,
      message: message ?? this.message,
      code: code ?? this.code,
    );
  }

  @override
  String toString() => 'Попробуйте позже. Код: $code, сообщение: $rawMessage';
}
