import 'package:collection/collection.dart';
import 'package:typed_json/typed_json.dart';

enum ServerMessageExceptionKey {
  /// Нельзя одновременно брать много заданий.
  maxTaskCount,

  /// Нельзя выполнять задание при не полностью заполненном профиле.
  notCompleteProfile,

  /// Задание не найдено
  taskNotFound,

  /// Игра на сегодня закончилась
  gameFinished,

  /// На сегодня для Вас скриншоты закончились.
  gameScreenshotFinished,

  /// Задание недоступно
  taskUnavailable,

  /// Задание приостановлено
  taskPaused,

  /// Задание завершено
  taskClosed,

  /// Игра не найдена
  gameNotFound,

  /// Время для отправки отчета ещё не пришло (Кнопка "Добавить отчёт")
  errorReportTime,

  /// Время для выполнения ещё не пришло (Кнопка "Выполнить")
  errorFinishTime,

  /// Время на выполнение решения каптчи истекло
  captchaExpired,

  /// необходимро пройти каптчу
  needCaptcha,

  /// Нельзя брать задание так часто
  toOften,

  /// достигнуто максимальное количество исполнителей
  maxUsersCount,

  /// Нельзя брать задание больше одного раза
  onceOfTime,

  /// Время задания закончилось
  timeIsOver,

  ///Задание с этим ID снято с публикации
  taskNotPublished,

  /// Сессия задания не найдено
  sessionNotFound,

  /// Данная сессия не принадлежит вашему пользователю
  wrongSession,

  /// Задание уже не активно
  taskNotActive,

  /// Недопустимый статус
  invalidStatus,

  /// Передан ID неверного вопроса
  wrongQuestionId,

  /// ID вопроса не относится к данному заданию
  wrongQuestionIdTask,

  ///Вы отвечали уже на этот вопрос
  answerToQuestionBeen,

  /// Передан ID неверного ответа
  wrongAnswerId,

  /// Нельзя отправлять отчёт из такого статуса выполнения
  incorrectStatusForReport,

  /// Нельзя отправлять файлы из такого статуса выполнения
  incorrectStatusForFile,

  /// Чистый город. Некорректный скриншот
  incorrectScreenshot,

  /// Игра не активна
  gameNotActive,

  /// Игра еще не началась
  gameNotStartedYet,

  /// Вы ответили не на все вопросы
  notAllAnswers,

  /// Нет такого типа задач
  typeId,

  ///Нет тренировочного задания с таким GameId
  notTrainingGameId,

  /// Нельзя заканчивать задание из такого статуса
  badFinishStatus,

  /// Слишком длинное имя файла
  fileNameTooLong,

  /// пользователь заблокирован
  userBlocked,

  /// Площадка недоступна
  siteSuspended,

  /// Ошибка повторной подписки на канал
  userTypeChannelNotUnique,

  /// Если пользователь не старгетирован и/или состоит в ЧС задания
  taskExcluded,

  /// Файл уже ранее был загружен на сервер
  md5CheckFailed,

  /// Не истекло время паузы между попытками выполнения задания
  toOftenUntil,
}

class ServerMessageExceptionKeyAdapter
    extends JsonAdapter<ServerMessageExceptionKey> {
  static const _map = {
    'maxTaskCount': ServerMessageExceptionKey.maxTaskCount,
    'notCompleteProfile': ServerMessageExceptionKey.notCompleteProfile,
    'taskNotFound': ServerMessageExceptionKey.taskNotFound,
    'gameFinished': ServerMessageExceptionKey.gameFinished,
    'gameScreenshotFinished': ServerMessageExceptionKey.gameScreenshotFinished,
    'taskUnavailable': ServerMessageExceptionKey.taskUnavailable,
    'taskPaused': ServerMessageExceptionKey.taskPaused,
    'gameNotFound': ServerMessageExceptionKey.gameNotFound,
    'errorReportTime': ServerMessageExceptionKey.errorReportTime,
    'errorFinishTime': ServerMessageExceptionKey.errorFinishTime,
    'captchaExpired': ServerMessageExceptionKey.captchaExpired,
    'toOften': ServerMessageExceptionKey.toOften,
    'maxUsersCount': ServerMessageExceptionKey.maxUsersCount,
    'onceOfTime': ServerMessageExceptionKey.onceOfTime,
    'timeIsOver': ServerMessageExceptionKey.timeIsOver,
    'taskNotPublished': ServerMessageExceptionKey.taskNotPublished,
    'sessionNotFound': ServerMessageExceptionKey.sessionNotFound,
    'wrongSession': ServerMessageExceptionKey.wrongSession,
    'taskNotActive': ServerMessageExceptionKey.taskNotActive,
    'invalidStatus': ServerMessageExceptionKey.invalidStatus,
    'wrongQuestionId': ServerMessageExceptionKey.wrongQuestionId,
    'wrongQuestionIdTask': ServerMessageExceptionKey.wrongQuestionIdTask,
    'answerToQuestionBeen': ServerMessageExceptionKey.answerToQuestionBeen,
    'wrongAnswerId': ServerMessageExceptionKey.wrongAnswerId,
    'incorrectStatusForReport':
        ServerMessageExceptionKey.incorrectStatusForReport,
    'incorrectStatusForFile': ServerMessageExceptionKey.incorrectStatusForFile,
    'incorrectScreenshot': ServerMessageExceptionKey.incorrectScreenshot,
    'gameNotActive': ServerMessageExceptionKey.gameNotActive,
    'gameNotStartedYet': ServerMessageExceptionKey.gameNotStartedYet,
    'notAllAnswers': ServerMessageExceptionKey.notAllAnswers,
    'typeId': ServerMessageExceptionKey.typeId,
    'notTrainingGameId': ServerMessageExceptionKey.notTrainingGameId,
    'badFinishStatus': ServerMessageExceptionKey.badFinishStatus,
    'FileNameTooLong': ServerMessageExceptionKey.fileNameTooLong,
    'needCaptcha': ServerMessageExceptionKey.needCaptcha,
    'userBlocked': ServerMessageExceptionKey.userBlocked,
    'siteSuspended': ServerMessageExceptionKey.siteSuspended,
    'taskClosed': ServerMessageExceptionKey.taskClosed,
    'userTypeChannelNotUnique':
        ServerMessageExceptionKey.userTypeChannelNotUnique,
    'taskExcluded': ServerMessageExceptionKey.taskExcluded,
    'md5CheckFailed': ServerMessageExceptionKey.md5CheckFailed,
    'toOftenUntil': ServerMessageExceptionKey.toOftenUntil,
  };

  String? _toString(ServerMessageExceptionKey? value) =>
      _map.entries.firstWhereOrNull((entry) => entry.value == value)?.key;

  @override
  ServerMessageExceptionKey? fromJson(Json json) =>
      _map[json.stringValue ?? ''];

  @override
  Json toJson(ServerMessageExceptionKey? value) => Json(_toString(value));
}
