import 'package:al/framework/errors/exceptions/server_message_exception/server_message_exception_message.dart';
import 'package:typed_json/typed_json.dart';

/// Типовая структура, которая возвращается если сервер ответил кодом 400
class ServerMessageExceptionResponse {
  String? name;
  int? code;
  int? status;
  String? rawMessage;
  ServerMessageExceptionMessage? message;

  ServerMessageExceptionResponse({
    required this.name,
    required this.code,
    required this.status,
    required this.rawMessage,
    required this.message,
  });

  static ServerMessageExceptionResponse? fromJson(Json json) {
    if (json.dynamicValue is! Map) {
      return null;
    }

    final messageJson = _getMessageJson(json['message'].stringValue);
    return ServerMessageExceptionResponse(
      name: json['name'].stringValue,
      code: json['code'].intValue,
      status: json['status'].intValue,
      rawMessage: json['message'].stringValue,
      message: messageJson != null
          ? ServerMessageExceptionMessage.fromJson(messageJson)
          : null,
    );
  }

  static Json? _getMessageJson(String? message) {
    if (message == null ||
        message.isEmpty ||
        !message.startsWith('[') ||
        !message.contains('{')) {
      return null;
    }

    try {
      return Json.parse(message);
    } on Exception {
      return null;
    }
  }
}
