import 'package:al/framework/analytics/analytics_sender.dart';
import 'package:al/framework/di/di_assembly.dart';
import 'package:al/framework/di/di_container.dart';
import 'package:al/framework/environment/build_type.dart';
import 'package:al/framework/environment/environment.dart';
import 'package:al/framework/log/crash_logger.dart';
import 'package:al/framework/network/request_sender.dart';
import 'package:al/framework/storages/preferences_storage.dart';
import 'package:al/framework/storages/secure_storage.dart';
import 'package:al/framework/timer/logic/repositories/server_timer_repository.dart';

class FrameworkAssembly extends DIAssembly {
  final BuildType buildType;

  FrameworkAssembly({required this.buildType});

  @override
  assembly(DIContainer container) {
    container.registerSingleton<IPreferencesStorage>(
      (container) => PreferencesStorage(),
    );

    container.registerSingleton<ISecureStorage>(
      (container) => SecureStorage(),
    );

    container.registerSingleton(
      (container) => CrashLogger(),
    );

    container.registerSingleton<Environment>(
      (container) => Environment(
        buildType: buildType,
        preferencesStorage: container.resolve<IPreferencesStorage>(),
      ),
    );

    container.registerSingleton(
      (container) => AnalyticsSender(
        isAnalyticsDebugEnabled:
            container.resolve<Environment>().isAnalyticsDebugEnabled,
      ),
    );

    container.registerSingleton(
      (container) => RequestSender(
        environment: container.resolve<Environment>(),
      ),
    );

    container.registerSingleton(
      (container) => ServerTimerRepository(
        requestSender: container.resolve<RequestSender>(),
      ),
    );
  }
}
