import 'package:equatable/equatable.dart';
import 'package:flutter/material.dart';

class ALAssetChange extends Equatable {
  /// Вариант изображения. Варианты изображения хранятся по тому же пути, что
  /// базовое изображение, но внутри директории, название которой совпадает с
  /// текстом варианта. Например, вариант `"landscape"` для картинки с названием
  /// `"pic/illustration.svg"` будет искаться по пути
  /// `"pic/landscape/illustration.svg"`.
  final String? variant;

  /// Размер изображения при выводе на экран. Не включает в себя [padding].
  ///
  /// Если размер по какой-то стороне должен быть неограничен, соответсвующая
  /// составляющая [size] должна иметь значение `double.infinite`.
  final Size? size;

  /// Множитель, на который домножаются размер изображения и параметры [padding]
  /// при выводе на экран.
  final double scale;

  /// Собственный отступ вокруг иллюстрации. Используется в первую очередь при
  /// выводе на экран векторных изображений.
  final EdgeInsets? padding;

  /// Конфигурация изменений ассета перед выводом на экран.
  const ALAssetChange({
    this.variant,
    this.scale = 1,
    this.size,
    this.padding,
  });

  ALAssetChange.width(double width)
      : variant = null,
        scale = 1,
        size = Size(width, double.infinity),
        padding = null;

  ALAssetChange.height(double height)
      : variant = null,
        scale = 1,
        size = Size(double.infinity, height),
        padding = null;

  ALAssetChange.square(double dimension)
      : variant = null,
        scale = 1,
        size = Size.square(dimension),
        padding = null;

  static ALAssetChange? combine(ALAssetChange? first, ALAssetChange? second) {
    if (first == null) {
      return second;
    } else if (second == null) {
      return first;
    } else {
      return ALAssetChange(
        variant: second.variant ?? first.variant,
        size: second.size ?? first.size,
        scale: second.scale * first.scale,
        padding: second.padding ?? first.padding,
      );
    }
  }

  @override
  List<Object?> get props => [variant, size, scale, padding];
}
