import 'package:flutter/material.dart';
import 'package:al/framework/theme/al_theme_colors.dart';

class ALThemeShadows extends ThemeExtension<ALThemeShadows> {
  final List<BoxShadow> appBarShadows;
  final List<BoxShadow> cardShadows;

  static final light = () {
    const colors = ALThemeColors.lightColors;

    return ALThemeShadows._(
      cardShadows: [
        _getShadow(colors.dark, 0.1, 0, 10, 40, 5),
      ],
      appBarShadows: [
        _getShadow(colors.appBarShadow1, 0.05, 0, 2, 3, 0),
        _getShadow(colors.appBarShadow2, 0.2, 0, 4, 12, 0),
      ],
    );
  }();

  static final dark = () {
    const colors = ALThemeColors.darkColors;

    return ALThemeShadows._(
      cardShadows: [
        _getShadow(colors.whiteBackground, 0.1, 0, 10, 40, 5),
      ],
      appBarShadows: [
        _getShadow(colors.appBarShadow1, 0.05, 0, 2, 3, 0),
        _getShadow(colors.appBarShadow2, 0.2, 0, 4, 12, 0),
      ]
    );
  }();

  ALThemeShadows._({
    required this.cardShadows,
    required this.appBarShadows,
  });

  @override
  ThemeExtension<ALThemeShadows> copyWith() => this;

  @override
  ThemeExtension<ALThemeShadows> lerp(
    ThemeExtension<ALThemeShadows>? other,
    double t,
  ) {
    return other is! ALThemeShadows ? this : other;
  }

  static BoxShadow _getShadow(
    Color color,
    double opacity,
    double x,
    double y,
    double blur,
    double spread,
  ) {
    return BoxShadow(
      color: color.withOpacity(opacity),
      offset: Offset(x, y),
      blurRadius: blur,
      spreadRadius: spread,
    );
  }
}
