import 'dart:io';

import 'package:flutter/material.dart';
import 'package:al/framework/theme/al_theme_colors.dart';

class ALThemeTextStyles extends ThemeExtension<ALThemeTextStyles> {
  static final String? _defaultFontFamily = Platform.isAndroid ? 'Roboto' : null;

  final TextStyle title1Bold;
  final TextStyle title2Heavy;
  final TextStyle title2Bold;
  final TextStyle title2Semibold;
  final TextStyle title3Bold;
  final TextStyle title3Light;
  final TextStyle headlineButtonBold;
  final TextStyle headlineBold;
  final TextStyle headlineMedium;
  final TextStyle headlineRegular;
  final TextStyle textHeavy;
  final TextStyle textBold;
  final TextStyle textSemibold;
  final TextStyle textSemiboldList;
  final TextStyle textMedium;
  final TextStyle textRegular;
  final TextStyle textListRegular;
  final TextStyle subheadHeavy;
  final TextStyle subheadBold;
  final TextStyle subheadSemibold;
  final TextStyle subheadMedium;
  final TextStyle subheadCapsMedium;
  final TextStyle subheadLight;
  final TextStyle caption1Semibold;
  final TextStyle caption1StatusBigSemibold;
  final TextStyle caption1StatusSmallSemibold;
  final TextStyle caption1StatusMedium;
  final TextStyle caption1Regular;
  final TextStyle caption1Light;
  final TextStyle caption1AlertRegular;
  final TextStyle caption2Bold;
  final TextStyle caption2Medium;
  final TextStyle caption2ProfileMedium;
  final TextStyle caption2Regular;
  final TextStyle caption2Light;

  final TextStyle pinKeyboard;
  final TextStyle pinTitle;

  static final light = _getStylesForThemeColors(ALThemeColors.lightColors);
  static final dark = _getStylesForThemeColors(ALThemeColors.darkColors);

  static ALThemeTextStyles _getStylesForThemeColors(ALThemeColors colors) {
    return ALThemeTextStyles._(
      title1Bold: _getStyle(26, 27, FontWeight.bold, colors.dark),
      title2Heavy: _getStyle(21, 18, FontWeight.w800, colors.dark),
      title2Bold: _getStyle(21, 24, FontWeight.bold, colors.dark),
      title2Semibold: _getStyle(21, 24, FontWeight.w600, colors.dark),
      title3Bold: _getStyle(18, 20, FontWeight.bold, colors.dark),
      title3Light: _getStyle(16, 12, FontWeight.w300, colors.slateGrey),
      headlineButtonBold: _getStyle(15, 16, FontWeight.bold, colors.dark, 0.5),
      headlineBold: _getStyle(15, 16, FontWeight.bold, colors.dark),
      headlineMedium: _getStyle(15, 16, FontWeight.w500, colors.dark),
      headlineRegular: _getStyle(15, 16, FontWeight.normal, colors.slateGrey, 0.2),
      textHeavy: _getStyle(15, 20, FontWeight.w800, colors.dark),
      textBold: _getStyle(15, 20, FontWeight.bold, colors.dark),
      textSemibold: _getStyle(15, 20, FontWeight.w600, colors.dark),
      textSemiboldList: _getStyle(15, 16, FontWeight.w600, colors.dark),
      textMedium: _getStyle(15, 20, FontWeight.w500, colors.dark),
      textRegular: _getStyle(15, 20, FontWeight.normal, colors.slateGrey),
      textListRegular: _getStyle(14, 16, FontWeight.normal, colors.slateGrey),
      subheadHeavy: _getStyle(14, 16, FontWeight.w800, colors.dark),
      subheadBold: _getStyle(14, 16, FontWeight.bold, colors.dark),
      subheadSemibold: _getStyle(14, 16, FontWeight.w600, colors.dark),
      subheadMedium: _getStyle(14, 16, FontWeight.w500, colors.slateGrey),
      subheadCapsMedium: _getStyle(14, 16, FontWeight.w500, colors.slateGrey, 1.5),
      subheadLight: _getStyle(14, 16, FontWeight.w300, colors.slateGrey),
      caption1Semibold: _getStyle(13, 14, FontWeight.w600, colors.dark),
      caption1StatusBigSemibold: _getStyle(13, 20, FontWeight.w600, colors.dark),
      caption1StatusSmallSemibold: _getStyle(13, 18, FontWeight.w600, colors.dark),
      caption1StatusMedium: _getStyle(14, 18, FontWeight.w500, colors.slateGrey),
      caption1Regular: _getStyle(13, 14, FontWeight.w400, colors.slateGrey),
      caption1Light: _getStyle(13, 14, FontWeight.w300, colors.slateGrey),
      caption1AlertRegular: _getStyle(13, 17, FontWeight.w400, colors.slateGrey),
      caption2Bold: _getStyle(11, 16, FontWeight.w700, colors.dark),
      caption2Medium: _getStyle(11, 16, FontWeight.w500, colors.slateGrey),
      caption2ProfileMedium: _getStyle(11, 13, FontWeight.w500, colors.slateGrey),
      caption2Regular: _getStyle(11, 14, FontWeight.w400, colors.slateGrey, 0.4),
      caption2Light: _getStyle(11, 16, FontWeight.w300, colors.slateGrey),
      pinKeyboard: _getStyle(27, 44, FontWeight.w400, Colors.black),
      pinTitle: _getStyle(34, 40, FontWeight.w700, colors.primary),
    );
  }

  TextTheme getTextTheme() => TextTheme(
        displayLarge: title1Bold,
        displayMedium: title1Bold,
        displaySmall: title2Bold,
        headlineMedium: title3Bold,
        headlineSmall: title1Bold,
        titleLarge: title1Bold,
        titleMedium: textListRegular,
        titleSmall: subheadMedium,
        bodyLarge: textSemibold,
        bodyMedium: textMedium,
        bodySmall: caption1Regular,
        labelSmall: title1Bold,
      );

  ALThemeTextStyles._({
    required this.title1Bold,
    required this.title2Heavy,
    required this.title2Bold,
    required this.title2Semibold,
    required this.title3Bold,
    required this.title3Light,
    required this.headlineButtonBold,
    required this.headlineBold,
    required this.headlineMedium,
    required this.headlineRegular,
    required this.textHeavy,
    required this.textBold,
    required this.textSemibold,
    required this.textSemiboldList,
    required this.textMedium,
    required this.textRegular,
    required this.textListRegular,
    required this.subheadHeavy,
    required this.subheadBold,
    required this.subheadSemibold,
    required this.subheadMedium,
    required this.subheadCapsMedium,
    required this.subheadLight,
    required this.caption1Semibold,
    required this.caption1StatusBigSemibold,
    required this.caption1StatusSmallSemibold,
    required this.caption1StatusMedium,
    required this.caption1Regular,
    required this.caption1Light,
    required this.caption1AlertRegular,
    required this.caption2Bold,
    required this.caption2Medium,
    required this.caption2ProfileMedium,
    required this.caption2Regular,
    required this.caption2Light,
    required this.pinKeyboard,
    required this.pinTitle,
  });

  @override
  ThemeExtension<ALThemeTextStyles> copyWith() => this;

  @override
  ThemeExtension<ALThemeTextStyles> lerp(
    ThemeExtension<ALThemeTextStyles>? other,
    double t,
  ) {
    return other is! ALThemeTextStyles ? this : other;
  }

  /// Компактная обертка вокруг [_styledText].
  static TextStyle _getStyle(
    double fontSize,
    double lineHeight,
    FontWeight fontWeight,
    Color color, [
    double letterSpacing = 0,
  ]) {
    return _styledText(
      fontSize: fontSize,
      fontFamily: 'Lora',
      lineHeight: lineHeight,
      fontWeight: fontWeight,
      color: color,
      letterSpacing: 0,
    );
  }

  /// Строит стиль текста.
  ///
  /// Значения [lineHeight] и [letterSpacing] соответствуют тем, которые
  /// задаются в макетах Figma.
  static TextStyle _styledText({
    String? fontFamily,
    required double fontSize,
    required double? lineHeight,
    required Color color,
    double letterSpacing = 0,
    FontWeight fontWeight = FontWeight.w400,
    bool isUnderlined = false,
    TextLeadingDistribution leadingDistribution = TextLeadingDistribution.even,
  }) {
    final deviceFontWeight = _getAvailableWeight(fontWeight);
    final deviceLetterSpacing = _getDeviceLetterSpacing(
      letterSpacing,
      fontSize: fontSize,
      fontWeight: deviceFontWeight,
    );

    return TextStyle(
      fontFamily: fontFamily ?? _defaultFontFamily,
      fontSize: fontSize,
      fontWeight: deviceFontWeight,
      height: lineHeight != null ? lineHeight / fontSize : null,
      letterSpacing: deviceLetterSpacing,
      leadingDistribution: leadingDistribution,
      color: color,
      decorationColor: isUnderlined ? color : null,
      decorationStyle: isUnderlined ? TextDecorationStyle.solid : null,
      decoration: isUnderlined ? TextDecoration.underline : TextDecoration.none,
    );
  }

  static FontWeight _getAvailableWeight(FontWeight fontWeight) {
    if (Platform.isAndroid) {
      // На Android мы применяем шрифт Roboto, у которого нет начертаний
      // ExtraLight, SemiBold и Heavy. Недоступные начертания заменяются на
      // близкие по весу.
      switch (fontWeight) {
        case FontWeight.w800:
          return FontWeight.w900;
        case FontWeight.w600:
          return FontWeight.w500;
        case FontWeight.w200:
          return FontWeight.w100;
        default:
          return fontWeight;
      }
    } else {
      return fontWeight;
    }
  }

  static double _getDeviceLetterSpacing(
    double figmaLetterSpacing, {
    required double fontSize,
    required FontWeight? fontWeight,
  }) {
    if (Platform.isIOS) {
      // Устройства iOS используют немного более широко расставленную версию
      // шрифта SF Pro, чем применяемая в Figma. Поэтому в численном плане
      // отступ всегда немного уже, чем на макетах.

      return figmaLetterSpacing - fontSize * 0.05;
    } else {
      final spacingAdjustmentFactor = _getRobotoSpacingAdjustmentFactor(fontWeight ?? FontWeight.normal);

      // return letterSpacing;
      return figmaLetterSpacing - fontSize * spacingAdjustmentFactor * 0.005;
    }
  }

  /// Устройства Android используют шрифт Roboto, который характерен тем,
  /// что с ростом веса символов, они меньше растут в ширину. Чтобы надписи
  /// на двух платформах выглядели одинаково, набранные тонкими начертаниями
  /// строки верстаются чуть более плотно.
  static int _getRobotoSpacingAdjustmentFactor(FontWeight fontWeight) {
    switch (fontWeight) {
      case FontWeight.w900:
        return -4;

      case FontWeight.w700:
        return 0;

      case FontWeight.w500:
        return 2;

      case FontWeight.w400:
        return 3;

      case FontWeight.w300:
        return 4;

      case FontWeight.w100:
        return 6;

      default:
        assert(false, 'Неподдерживаемый вес шрифта: $fontWeight');
        return 0;
    }
  }
}
