import 'package:flutter/material.dart';
import 'package:al/framework/extensions/build_context_extension.dart';

class ALBadgedIcon extends StatelessWidget {
  final Widget icon;
  final double iconSize;
  final String? badgeText;
  final Color? badgeColor;
  final Color? badgeTextColor;
  final double maxTabWidth;
  final double? maxTabHeight;
  final EdgeInsets badgedPadding;

  const ALBadgedIcon({
    super.key,
    required this.icon,
    required this.iconSize,
    this.badgeText,
    this.badgeColor,
    this.badgeTextColor,
    required this.maxTabWidth,
    this.maxTabHeight,
    this.badgedPadding = const EdgeInsets.only(right: 14, top: 2),
  });

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      height: maxTabHeight,
      width: maxTabWidth,
      child: Stack(
        children: [
          Align(
            alignment: Alignment.bottomCenter,
            child: icon,
          ),
          Visibility(
            visible: badgeText != null,
            child: _alignBadge(child: _buildBadge(context)),
          ),
        ],
      ),
    );
  }

  Widget _alignBadge({required Widget child}) {
    return IntrinsicHeight(
      child: Align(
        alignment: Alignment.topCenter,
        child: Container(
          alignment: Alignment.topRight,
          padding: badgedPadding,
          child: child,
        ),
      ),
    );
  }

  Widget _buildBadge(BuildContext context) {
    return IntrinsicWidth(
      child: Container(
        constraints: const BoxConstraints(minWidth: 16, minHeight: 16),
        padding: const EdgeInsets.only(left: 4, right: 4),
        decoration: BoxDecoration(
          shape: BoxShape.rectangle,
          color: badgeColor,
          borderRadius: const BorderRadius.all(Radius.circular(10)),
        ),
        child: Center(
          child: Text(
            badgeText ?? '',
            maxLines: 1,
            style: context.textStyles.caption2Bold.copyWith(
              fontSize: 12,
              color: badgeTextColor,
            ),
          ),
        ),
      ),
    );
  }
}
