import 'package:flutter/material.dart';
import 'package:al/framework/ui/widgets/buttons/al_button.dart';
import 'package:al/framework/ui/widgets/al_bottom_panel.dart';

/// Виджет оборачивает [scrollView] и добавляет панель с кнопкой Готово над клавиатурой.
/// Панель видна когда фокус есть хотя бы в одном из элементов [focusNodes]
/// Кнопка Готово скрывает клавиатуру.
///
/// Принципиально, чтобы [scrollView] был наследником виджета [ScrollView], иначе могут
/// возникнуть проблемы отрисовки нижней панели.
class AGKeyboardDoneAction extends StatefulWidget {
  final List<FocusNode> focusNodes;
  final ScrollView scrollView;
  final bool isAlwaysVisible;
  final Function()? onTap;

  const AGKeyboardDoneAction({
    super.key,
    required this.focusNodes,
    required this.scrollView,
    this.onTap,
    this.isAlwaysVisible = false,
  });

  @override
  State<AGKeyboardDoneAction> createState() => _AGKeyboardDoneActionState();
}

class _AGKeyboardDoneActionState extends State<AGKeyboardDoneAction> {
  var _isKeyboardDismissPanelVisible = false;

  @override
  void initState() {
    super.initState();
    for (final focus in widget.focusNodes) {
      focus.addListener(() {
        _onInputFocusChanged();
      });
    }
  }

  void _onInputFocusChanged() {
    final focusedIndex = widget.focusNodes.indexWhere((f) => f.hasFocus);
    setState(() {
      _isKeyboardDismissPanelVisible = focusedIndex >= 0;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        Expanded(
          child: widget.scrollView,
        ),
        Visibility(
          visible: _isKeyboardDismissPanelVisible || widget.isAlwaysVisible,
          child: _buildKeyboardDismissPanel(context),
        )
      ],
    );
  }

  Widget _buildKeyboardDismissPanel(BuildContext context) {
    return ALBottomPanel.bottomPanel(
      context: context,
      child: ALButton(
        text: "Готово",
        onPressed: () => _onDoneButtonClick(),
      ),
    );
  }

  void _onDoneButtonClick() {
    widget.onTap?.call();
    FocusScope.of(context).unfocus();
  }
}
