import 'package:al/auth/res/auth_strings.dart';
import 'package:al/auth/res/auth_styles.dart';
import 'package:al/framework/extensions/build_context_extension.dart';
import 'package:al/framework/ui/widgets/al_pin_dots/al_digit_keyboard.dart';
import 'package:al/framework/ui/widgets/al_pin_dots/al_pin_dots.dart';
import 'package:flutter/material.dart';

const _pinMaxLength = 4;

class ALPin extends StatefulWidget {
  final ValueSetter<String> onPinEntered;
  final VoidCallback onPinChanged;
  final bool isPinCorrect;
  final bool hasError;
  final int attemptCount;

  const ALPin({
    super.key,
    required this.onPinEntered,
    required this.onPinChanged,
    required this.isPinCorrect,
    required this.attemptCount,
    required this.hasError,
  });

  @override
  State<ALPin> createState() => _ALPinState();
}

class _ALPinState extends State<ALPin> {
  late final PinDotsController pinDotsController;

  @override
  void initState() {
    pinDotsController = PinDotsController(
      onPinEntered: widget.onPinEntered,
      pinLength: _pinMaxLength,
      withConfirmation: false,
    );
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    if (widget.attemptCount == 3) {
      return Text(
        AuthStrings.callManager,
        textAlign: TextAlign.center,
        style: AuthStyles.authErrorText,
      );
    }
    return Column(
      crossAxisAlignment: CrossAxisAlignment.center,
      mainAxisSize: MainAxisSize.max,
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Expanded(
          child: ListenableBuilder(
            listenable: pinDotsController,
            builder: (context, child) {
              return PinDots(
                size: 16,
                pin: pinDotsController.pin,
                pinLength: pinDotsController.pinLength,
                theme: PinDotTheme(
                  enteredColor: context.colors.primary,
                  unenteredColor: context.colors.slateGrey.withOpacity(0.1),
                  successColor: context.colors.green,
                  errorColor: context.colors.red,
                ),
                isSuccess: widget.isPinCorrect,
                hasError: widget.hasError,
                spacing: 24,
              );
            },
          ),
        ),
        Center(
          child: DigitKeyboard(
            onTap: (value) {
              pinDotsController.onDigitEntered(int.parse(value));
              widget.onPinChanged();
            },
            onTapBackspace: () {
              pinDotsController.onBackspace();
              widget.onPinChanged();
            },
            onLongTapBackspace: pinDotsController.clear,
            digitStyle: context.textStyles.pinKeyboard,
          ),
        ),
      ],
    );
  }
}
