import 'package:flutter/material.dart';
import 'package:al/framework/extensions/build_context_extension.dart';

class ALRadioItem<T> {
  final String title;
  final T value;

  ALRadioItem({required this.title, required this.value});
}

/// Радиокнопка. Радиокнопки располагают группами по несколько штук,
/// причём может быть выбрана только одна кнопка из группы.
class ALRadio<T> extends StatelessWidget {
  final T value;
  final ValueChanged<T?>? onChanged;
  final Color? activeColor;
  final MaterialTapTargetSize? materialTapTargetSize;
  final bool toggleable;
  final VisualDensity? visualDensity;
  final bool autofocus;
  final FocusNode? focusNode;
  final Color? focusColor;
  final Color? hoverColor;
  final bool isEnabled;
  final Color? disabledColor;
  final Color? unselectedWidgetColor;
  final Color? activeDisableColor;
  final T? groupValue;

  const ALRadio({
    super.key,
    required this.value,
    required this.groupValue,
    required this.onChanged,
    this.isEnabled = true,
    this.disabledColor,
    this.unselectedWidgetColor,
    this.activeDisableColor,
    this.activeColor,
    this.toggleable = false,
    this.focusColor,
    this.hoverColor,
    this.materialTapTargetSize,
    this.visualDensity,
    this.focusNode,
    this.autofocus = false,
  });

  @override
  Widget build(BuildContext context) {
    return Theme(
      data: Theme.of(context).copyWith(
        disabledColor: value == groupValue
            ? activeDisableColor ?? context.colors.selectionDisableActive
            : unselectedWidgetColor ?? context.colors.coolGrey,
        unselectedWidgetColor: unselectedWidgetColor,
      ),
      child: Radio(
        value: value,
        groupValue: groupValue,
        onChanged: isEnabled ? onChanged : null,
        toggleable: toggleable,
        activeColor: activeColor ?? context.colors.primary,
        focusColor: focusColor,
        hoverColor: hoverColor,
        materialTapTargetSize: materialTapTargetSize,
        visualDensity: visualDensity,
        focusNode: focusNode,
        autofocus: autofocus,
      ),
    );
  }
}
