import 'dart:io';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:al/framework/extensions/build_context_extension.dart';

/// Типовой класс для хранения значений виджета
class ALSwitchItem {
  final String title;
  final bool isSelected;

  ALSwitchItem({required this.title, required this.isSelected});
}

enum SwitchPlatformStyle { android, ios }

class ALSwitch extends StatelessWidget {
  final SwitchPlatformStyle? platformStyle;
  final bool isEnabled;
  final bool value;
  final ValueChanged<bool> onChanged;
  final ImageProvider? activeThumbImage;
  final ImageErrorListener? onActiveThumbImageError;
  final ImageProvider? inactiveThumbImage;
  final ImageErrorListener? onInactiveThumbImageError;
  final MaterialTapTargetSize? materialTapTargetSize;
  final DragStartBehavior dragStartBehavior;
  final Color? focusColor;
  final Color? hoverColor;
  final FocusNode? focusNode;
  final bool autofocus;
  final Color? trackOutlineColor;

  const ALSwitch({
    super.key,
    required this.value,
    required this.onChanged,
    this.platformStyle,
    this.isEnabled = true,
    this.activeThumbImage,
    this.onActiveThumbImageError,
    this.inactiveThumbImage,
    this.onInactiveThumbImageError,
    this.materialTapTargetSize,
    this.dragStartBehavior = DragStartBehavior.start,
    this.focusColor,
    this.hoverColor,
    this.focusNode,
    this.autofocus = false,
    this.trackOutlineColor = Colors.transparent,
  });

  @override
  Widget build(BuildContext context) {
    final style = platformStyle ??
        (Platform.isIOS
            ? SwitchPlatformStyle.ios
            : SwitchPlatformStyle.android);
    return style == SwitchPlatformStyle.android
        ? _buildAndroidSwitch(context)
        : _buildIOSSwitch(context);
  }

  Widget _buildAndroidSwitch(BuildContext context) {
    return Switch(
      value: value,
      onChanged: isEnabled ? onChanged : null,
      activeColor: context.colors.fixed.whiteBackground,
      activeTrackColor: _getActiveTrackColor(context),
      inactiveThumbColor: _getInactiveThumbColor(context),
      inactiveTrackColor: _getInactiveTrackColor(context),
      activeThumbImage: activeThumbImage,
      onActiveThumbImageError: onActiveThumbImageError,
      inactiveThumbImage: inactiveThumbImage,
      onInactiveThumbImageError: onInactiveThumbImageError,
      materialTapTargetSize: materialTapTargetSize,
      dragStartBehavior: dragStartBehavior,
      focusColor: focusColor,
      hoverColor: hoverColor,
      focusNode: focusNode,
      autofocus: autofocus,
      trackOutlineColor: _getTrackOutlineColor(),
    );
  }

  MaterialStateProperty<Color?> _getTrackOutlineColor() {
    return MaterialStateProperty.resolveWith(
        (Set<MaterialState> states) => trackOutlineColor);
  }

  Color _getInactiveThumbColor(BuildContext context) {
    return context.colors.fixed.whiteBackground;
  }

  Color _getInactiveTrackColor(BuildContext context) {
    return isEnabled ? context.colors.coolGrey : context.colors.paleGrey;
  }

  Color _getActiveTrackColor(BuildContext context) {
    return isEnabled
        ? context.colors.dodgerBlue
        : context.colors.dodgerBlue.withOpacity(0.5);
  }

  Widget _buildIOSSwitch(BuildContext context) => CupertinoSwitch(
        value: value,
        onChanged: isEnabled ? onChanged : null,
        activeColor: isEnabled
            ? context.colors.dodgerBlue
            : context.colors.dodgerBlue.withOpacity(0.5),
        trackColor:
            isEnabled ? context.colors.coolGrey : context.colors.paleGrey,
        dragStartBehavior: dragStartBehavior,
      );
}
