import 'package:flutter/material.dart';
import 'package:al/framework/extensions/build_context_extension.dart';
import 'package:al/framework/res/images/al_image_asset.dart';

class ALImageButton extends StatelessWidget {
  final ALImageAsset icon;

  /// Цвет иконки.
  ///
  /// Если `null`, иконка использует собственный цвет ассета.
  final Color? iconColor;

  /// Цвет фона кнопки.
  ///
  /// Если `null`, используется цвет `paleGrey` текущей темы.
  final Color? backgroundColor;

  /// Цвет фона кнопки, если она неактивна.
  ///
  /// Если `null`, используется значение [backgroundColor].
  final Color? disabledBackgroundColor;

  /// Цвет окраски места касания.
  ///
  /// Если `null`, используется цвет `veryCoolGrey` текущей темы.
  final Color? splashColor;

  final double radius;
  final double height;
  final double width;

  final bool isEnabled;
  final VoidCallback onPressed;

  const ALImageButton({
    super.key,
    required this.icon,
    this.iconColor,
    this.backgroundColor,
    this.disabledBackgroundColor,
    this.splashColor,
    this.radius = 10,
    this.height = 54,
    this.width = 56,
    this.isEnabled = true,
    required this.onPressed,
  });

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      height: height,
      width: width,
      child: _buildButton(context),
    );
  }

  Widget _buildButton(BuildContext context) {
    return TextButton(
      style: _getButtonStyle(context),
      onPressed: isEnabled ? onPressed : null,
      child: icon.buildWidget(
        context,
        color: iconColor,
      ),
    );
  }

  ButtonStyle _getButtonStyle(BuildContext context) {
    final backgroundColor = this.backgroundColor ?? context.colors.paleGrey;
    final disabledBackgroundColor =
        this.disabledBackgroundColor ?? backgroundColor;
    final splashColor = this.splashColor ?? context.colors.veryCoolGrey;

    return ButtonStyle(
      splashFactory: InkSplash.splashFactory,
      overlayColor: MaterialStateColor.resolveWith((states) => splashColor),
      shape: MaterialStateProperty.all(_buildBorder(backgroundColor)),
      padding: MaterialStateProperty.all(EdgeInsets.zero),
      backgroundColor: MaterialStateColor.resolveWith((states) {
        return states.contains(MaterialState.disabled)
            ? disabledBackgroundColor
            : backgroundColor;
      }),
    );
  }

  OutlinedBorder _buildBorder(Color color) {
    return RoundedRectangleBorder(
      borderRadius: BorderRadius.circular(radius),
      side: BorderSide(width: 1, color: color),
    );
  }
}
