import 'package:device_info_plus/device_info_plus.dart';
import 'dart:io';

class DeviceInfo {
  static const unknownValue = "unknown";

  final String deviceModelName;
  final String systemVersion;
  final String model;
  final String manufacturer;
  final String sdkVersion;

  DeviceInfo({
    required this.deviceModelName,
    required this.systemVersion,
    required this.model,
    required this.manufacturer,
    required this.sdkVersion,
  });
}

class DeviceInfoReader {
  Future<DeviceInfo> getInfo() async {
    final deviceInfoPlugin = DeviceInfoPlugin();

    if (Platform.isAndroid) {
      final info = await deviceInfoPlugin.androidInfo;
      return DeviceInfo(
        deviceModelName: info.device,
        systemVersion: info.version.release,
        model: info.model,
        manufacturer: info.manufacturer,
        sdkVersion: info.version.sdkInt.toString(),
      );
    } else if (Platform.isIOS) {
      final info = await deviceInfoPlugin.iosInfo;
      return DeviceInfo(
        deviceModelName: info.localizedModel,
        systemVersion: info.systemVersion,
        model: info.utsname.machine,
        manufacturer: "apple",
        sdkVersion: DeviceInfo.unknownValue,
      );
    }
    return DeviceInfo(
      deviceModelName: DeviceInfo.unknownValue,
      systemVersion: DeviceInfo.unknownValue,
      model: DeviceInfo.unknownValue,
      manufacturer: DeviceInfo.unknownValue,
      sdkVersion: DeviceInfo.unknownValue,
    );
  }
}
