import 'package:al/appbar/appbar_assembly.dart';
import 'package:al/appbar/ui/appbar_coordinator.dart';
import 'package:al/auth/ui/auth_coordinator.dart';
import 'package:al/activation/activation_assembly.dart';
import 'package:al/activation/ui/activation_coordinator.dart';
import 'package:al/launcher/ui/launcher_coordinator.dart';
import 'package:al/session_list/session_list_assembly.dart';
import 'package:al/session_list/ui/session_list_coordinator.dart';
import 'package:appmetrica_plugin/appmetrica_plugin.dart';
import 'package:flutter/material.dart';
import 'package:al/auth/auth_assembly.dart';
import 'package:al/debug_settings/debug_settings_assembly.dart';
import 'package:al/debug_settings/ui/debug_settings_coordinator.dart';
import 'package:al/framework/analytics/analytics_notifier_widget.dart';
import 'package:al/framework/di/di_container.dart';
import 'package:al/framework/environment/build_type.dart';
import 'package:al/framework/framework_assembly.dart';
import 'package:al/framework/log/crash_logger.dart';
import 'package:al/framework/log/log.dart';
import 'package:al/framework/res/al_contstants.dart';
import 'package:al/framework/theme/al_theme.dart';
import 'package:al/launcher/launcher_assembly.dart';
import 'package:al/main_coordinator.dart';

final diContainer = DIContainer();

final mainCoordinator = MainCoordinator(
  diContainer: diContainer,
  onShowDebugSettings: settingsCoordinator.showDebugSettings,
);

final appBarCoordinator = AppBarCoordinator(
  diContainer: diContainer,
);

final activationCoordinator = ActivationCoordinator(
  diContainer: diContainer,
  onGetAppBar: appBarCoordinator.getAppBar,
);

final authCoordinator = AuthCoordinator(
  diContainer: diContainer,
  onGetAppBar: appBarCoordinator.getAppBar,
);

final sessionListCoordinator = SessionListCoordinator(
  diContainer: diContainer,
  onGetAppBar: appBarCoordinator.getAppBar,
);

final launcherCoordinator = LauncherCoordinator(
  diContainer: diContainer,
  onGetActivationPage: () => activationCoordinator.getIdentificationPage(),
  onGetAuthPage: () => authCoordinator.getAuthPage(),
  onGetLoggedInPage: () => sessionListCoordinator.getSessionListPage(),
);

final settingsCoordinator = DebugSettingsCoordinator(
  diContainer: diContainer,
);

void main() {
  _mainForBuildType(BuildType.internal);
}

@pragma('vm:entry-point')
void mainInternal() {
  _mainForBuildType(BuildType.internal);
}

@pragma('vm:entry-point')
void mainStore() {
  _mainForBuildType(BuildType.store);
}

void _mainForBuildType([BuildType buildType = BuildType.store]) async {
  WidgetsFlutterBinding.ensureInitialized();

  _registerAssemblies(buildType: buildType);
  await AppMetrica.activate(
      const AppMetricaConfig(ALConstants.yandexAppMetricaApiKey));

  final crashLogger = diContainer.resolve<CrashLogger>();
  Log.configure(
    isLogEnabled: true,
    crashLogger: crashLogger,
  );

  FlutterError.onError = (details) {
    debugPrint(details.toString());
    final yaError = AppMetricaErrorDescription.fromFlutterErrorDetails(details);
    AppMetrica.reportUnhandledException(yaError);
  };

  runApp(const App());
}

void _registerAssemblies({required BuildType buildType}) {
  diContainer.registerAssemblies([
    FrameworkAssembly(buildType: buildType),
    AppBarAssembly(),
    LauncherAssembly(),
    ActivationAssembly(),
    AuthAssembly(),
    SessionListAssembly(),
    DebugSettingsAssembly(),
  ]);
}

class App extends StatelessWidget {
  const App({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'AL',
      theme: ALTheme.light,
      darkTheme: ALTheme.dark,
      debugShowCheckedModeBanner: false,
      home: AnalyticsNotifierWidget(
        child: launcherCoordinator.getLauncherPage(),
      ),
    );
  }
}
