import 'package:al/activation/logic/repository/activation_repository.dart';
import 'package:al/auth/logic/repository/auth_repository.dart';
import 'package:al/session_list/entities/hall_session.dart';
import 'package:al/session_list/logic/repository/session_list_repository.dart';
import 'package:al/session_list/session_list_dependencies.dart';
import 'package:al/session_list/types/hall_session_status.dart';
import 'package:bloc/bloc.dart';
import 'package:equatable/equatable.dart';

part 'session_list_state.dart';

class SessionListCubit extends Cubit<SessionListState> {
  final ISessionListLogoutDelegate logoutDelegate;
  final ActivationRepository activationRepository;
  final SessionListRepository sessionListRepository;
  final AuthRepository authRepository;

  SessionListCubit({
    required this.logoutDelegate,
    required this.activationRepository,
    required this.sessionListRepository,
    required this.authRepository,
  }) : super(SessionListInProgress(
          hallName: activationRepository.hallInfo.hallName,
          hallSessions: const [],
        ));

  Future<void> initialize() async {
    _getHallSessions();
  }

  Future<void> changeSessionStatus(HallSession session) async {
    emit(SessionListInProgress(
      hallName: state.hallName,
      hallSessions: state.hallSessions,
    ));

    HallSessionStatus newStatus;

    if (session.status == HallSessionStatus.waiting) {
      newStatus = HallSessionStatus.going;
    } else {
      newStatus = HallSessionStatus.closed;
    }

    await sessionListRepository.changeSessionStatus(
      sessionId: session.id,
      status: newStatus,
      currentSessions: state.hallSessions,
    );

    _getHallSessions();
  }

  Future<void> logout() async {
    await authRepository.logout(hallId: activationRepository.hallInfo.hallId);
    logoutDelegate.notifySessionListLogoutCompletion();
  }

  Future<void> _getHallSessions() async {
    emit(SessionListInProgress(
      hallName: state.hallName,
      hallSessions: state.hallSessions,
    ));

    final sessions = await sessionListRepository.getSessionList();

    emit(SessionListInitial(
      hallName: state.hallName,
      hallSessions: sessions ?? [], // TODO сделать обработку ошибки
    ));
  }
}
