import 'package:al/activation/logic/repository/activation_repository.dart';
import 'package:al/framework/network/request_sender.dart';
import 'package:al/session_list/entities/hall_session.dart';
import 'package:al/session_list/logic/network/session_list_request.dart';
import 'package:al/session_list/logic/network/session_list_response.dart';
import 'package:al/session_list/logic/network/session_status_request.dart';
import 'package:al/session_list/logic/network/session_status_response.dart';
import 'package:al/session_list/types/hall_session_status.dart';
import 'package:collection/collection.dart';

class SessionListRepository {
  final ActivationRepository activationRepository;
  final RequestSender requestSender;

  SessionListRepository({
    required this.activationRepository,
    required this.requestSender,
  });

  Future<List<HallSession>?> getSessionList() async {
    // TODO вставить актуальный hallId
    //const hallId = '99b9571a-ff54-4302-9a44-0750832493fa';
    final hallId = activationRepository.hallInfo.hallId;

    try {
      final response = await requestSender.send(
        SessionListRequest(hallId: hallId),
        SessionListResponse(),
      );

      return response.hallInfo.sessions;
    } on Exception catch (_) {
      // TODO написать обработку ошибок
    }

    return null;
  }

  Future<void> changeSessionStatus({
    required String sessionId,
    required HallSessionStatus status,
    required List<HallSession> currentSessions,
  }) async {
    // Если начинаем новое дело, ищем существующее дело со статусом "Активно" и завершаем его
    if (status == HallSessionStatus.going) {
      final activeSession = currentSessions.firstWhereOrNull(
        (session) => session.status == HallSessionStatus.going,
      );

      if (activeSession != null) {
        await requestSender.send(
          SessionStatusRequest(
            sessionId: activeSession.id,
            status: HallSessionStatus.closed,
          ),
          SessionStatusResponse(),
        );
      }
    }

    // Выставляем статус у текущего дела
    await requestSender.send(
      SessionStatusRequest(
        sessionId: sessionId,
        status: status,
      ),
      SessionStatusResponse(),
    );
  }
}
