import 'package:al/framework/ui/widgets/buttons/al_button.dart';
import 'package:al/session_list/entities/hall_session.dart';
import 'package:al/session_list/logic/bloc/session_list_cubit.dart';
import 'package:al/session_list/types/hall_session_status.dart';
import 'package:flutter/material.dart';

class SessionActionDialog extends StatelessWidget {
  final HallSession hallSession;
  final SessionListCubit cubit;

  const SessionActionDialog({
    super.key,
    required this.hallSession,
    required this.cubit,
  });

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      backgroundColor: Colors.white,
      contentPadding: const EdgeInsets.symmetric(vertical: 32.0),
      content: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          Text(
            _getActionTitle(),
            style: const TextStyle(fontSize: 24.0),
          ),
          Text(
            '№${hallSession.primaryCaseNumber}',
            style: const TextStyle(fontSize: 24.0),
          ),
        ],
      ),
      actions: [
        _getButton(
          text: 'Да',
          onPressed: () {
            cubit.changeSessionStatus(hallSession);
            Navigator.of(context).pop();
          },
          color: const Color.fromARGB(255, 4, 34, 49),
        ),
        _getButton(
          text: 'Нет',
          onPressed: () =>
              Navigator.of(context).pop(), // TODO передавать из координатора
          color: Colors.grey,
        )
      ],
    );
  }

  String _getActionTitle() {
    switch (hallSession.status) {
      case HallSessionStatus.waiting:
        return 'Начать заседание по делу';
      default:
        return 'Завершить заседание по делу';
    }
  }

  Widget _getButton({
    required String text,
    required VoidCallback onPressed,
    required Color color,
  }) {
    return SizedBox(
      width: 180.0,
      height: 56.0,
      child: ALButton(
        text: text,
        splashColor: Colors.white.withOpacity(0.1),
        titleStyle: const TextStyle(
          fontSize: 24.0,
          color: Colors.white,
        ),
        onPressed: onPressed,
        color: color,
      ),
    );
  }
}
