import 'package:al/session_list/entities/hall_session.dart';
import 'package:al/session_list/res/session_list_styles.dart';
import 'package:al/session_list/types/hall_session_status.dart';
import 'package:flutter/material.dart';

class SessionButton extends StatelessWidget {
  final HallSession hallSession;
  final VoidCallback onPressed;

  const SessionButton({
    super.key,
    required this.hallSession,
    required this.onPressed,
  });

  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      onPressed: onPressed,
      style: ButtonStyle(
        padding: const MaterialStatePropertyAll(
          EdgeInsets.symmetric(horizontal: 16, vertical: 8),
        ),
        backgroundColor: _getBackgroundColor(),
      ),
      child: _getButtonText(),
    );
  }

  MaterialStatePropertyAll<Color> _getBackgroundColor() {
    if (hallSession.status == HallSessionStatus.going) {
      return const MaterialStatePropertyAll(Color(0xFFEA4612));
    } else {
      return const MaterialStatePropertyAll(Color(0xFF2F6FC1));
    }
  }

  Widget _getButtonText() {
    return Text(
      hallSession.status == HallSessionStatus.going
          ? "Завершить заседание"
          : "Начать заседание",
      style: SessionListStyles.buttonText,
    );
  }
}
