#!/usr/bin/env python3
#
# Скрипт генерирует файл для запуска автотестов, импортирующий и исполняющий все автотесты в указанном каталоге.
#
# Принимает в качестве аргумента рабочий каталог, в котором нужно найти тесты и сгенерировать раннер
#
# Примеры:
# ./scripts/unittests/generate_main_unit_test.py .
# ./scripts/unittests/generate_main_unit_test.py ./widgets_demo

import sys
import glob
import codecs
import re
import os
from string import Template

working_folder = sys.argv[1]
# working_folder = 'D:\\Projects\\ag'
test_root_folder = f'{working_folder}{os.sep}test{os.sep}'
test_files_search_pattern = f'{test_root_folder}**{os.sep}*_test.dart'
main_test_path = f'{test_root_folder}unit_test.dart'

# Ищем все файлы с тестами
test_files = glob.glob(test_files_search_pattern, recursive=True)

if main_test_path in test_files:
    test_files.remove(main_test_path)


def get_module(path):
    filename = re.findall(r"\w+.dart", string=path)[0]
    return filename.replace('.dart', '')


def get_relative_path(path):
    return path.replace(f'{test_root_folder}', '')


def fix_path_separators(path):
    return path.replace('\\', '/')

# Формирует файл с классом для запуска всех тестов

imports = ""
for f in test_files:
    imports = imports + "import '" + \
        fix_path_separators(get_relative_path(f)) + \
        "' as " + get_module(f) + ";\n"

funcs = ""
for f in test_files:
    funcs = funcs + "  " + get_module(f) + ".main();\n"

driver_str = """// Файл генерируется автоматически
$imports
void main() {
$funcs}
"""
driver_template = Template(driver_str)
driver_str = driver_template.safe_substitute(imports=imports, funcs=funcs)

# Записываем класс для запуска всех тестов в файл
runner_file = codecs.open(main_test_path, "w", "utf-8")
runner_file.write(driver_str)
runner_file.close()
