// ignore_for_file: avoid_print

import 'package:flutter/material.dart';
import 'package:al/framework/res/images/al_images.dart';
import 'package:al/framework/ui/widgets/buttons/al_button.dart';
import 'package:al/framework/ui/widgets/buttons/al_button_icon.dart';

class ButtonsPage extends StatelessWidget {
  const ButtonsPage({super.key});

  @override
  Widget build(BuildContext context) {
    return ListView(
      padding: const EdgeInsets.all(10),
      children: _buildButtons(context).map((e) => _buildListItem(e)).toList(),
    );
  }

  List<Widget> _buildButtons(BuildContext context) {
    return [
      _buildFilledButtons(context),
      _buildOutlinedButtons(context),
      _buildTextButtons(context),
      _buildTonalButtons(context),
    ].expand((x) => x).toList();
  }

  List<Widget> _buildFilledButtons(BuildContext context) {
    return [
      const Text('Filled buttons'),
      ALButton(
        type: ALButtonType.filled,
        onPressed: () => print('Click'),
        text: 'Filled',
      ),
      ALButton(
        type: ALButtonType.filled,
        color: Colors.redAccent,
        onPressed: () => print('Click'),
        text: 'Filled with color',
      ),
      ALButton(
        type: ALButtonType.filled,
        onPressed: () => print('Click'),
        text: 'Filled small',
        height: 28,
      ),
      const ALButton(
        type: ALButtonType.filled,
        onPressed: null,
        text: 'Filled disabled',
      ),
      ALButton(
        type: ALButtonType.filled,
        onPressed: () => print('Click'),
        isLoading: true,
        text: 'Filled loading',
      ),
      ALButton(
        type: ALButtonType.filled,
        onPressed: () => print('Click'),
        isLoading: true,
        color: Colors.redAccent,
        text: 'Filled loading with color',
      ),
      ALButton(
        type: ALButtonType.filled,
        onPressed: () => print('Click'),
        text: 'Filled with left icon',
        leftIcon: ALButtonIcon(
          ALImages.iconSearch
        ),
      ),
      ALButton(
        type: ALButtonType.filled,
        onPressed: () => print('Click'),
        text: 'Filled with right icon',
        rightIcon: ALButtonIcon(
          ALImages.iconSearch
        ),
      ),
      ALButton(
        type: ALButtonType.filled,
        onPressed: () => print('Click'),
        text: 'Filled with both custom icons',
        leftIcon: ALButtonIcon(
          ALImages.iconSearch,
          color: Colors.redAccent,
          size: 14,
          padding: const EdgeInsets.only(right: 4),
        ),
        rightIcon: ALButtonIcon(
          ALImages.iconSearch,
          color: Colors.greenAccent,
          size: 20,
          padding: const EdgeInsets.only(left: 12),
        ),
      ),
    ];
  }

  List<Widget> _buildOutlinedButtons(BuildContext context) {
    return [
      const Text('Outlined buttons'),
      ALButton(
        type: ALButtonType.outlined,
        onPressed: () => print('Click'),
        text: 'Outlined',
      ),
      ALButton(
        type: ALButtonType.outlined,
        color: Colors.redAccent,
        onPressed: () => print('Click'),
        text: 'Outlined with color',
      ),
      ALButton(
        type: ALButtonType.outlined,
        onPressed: () => print('Click'),
        text: 'Outlined small',
        height: 28,
      ),
      const ALButton(
        type: ALButtonType.outlined,
        onPressed: null,
        text: 'Outlined disabled',
      ),
      ALButton(
        type: ALButtonType.outlined,
        onPressed: () => print('Click'),
        isLoading: true,
        text: 'Outlined loading',
      ),
      ALButton(
        type: ALButtonType.outlined,
        onPressed: () => print('Click'),
        isLoading: true,
        text: 'Outlined loading with color',
        color: Colors.redAccent,
      ),
      ALButton(
        type: ALButtonType.outlined,
        onPressed: () => print('Click'),
        text: 'Outlined with left icon',
        leftIcon: ALButtonIcon(
            ALImages.iconSearch
        ),
      ),
      ALButton(
        type: ALButtonType.outlined,
        onPressed: () => print('Click'),
        text: 'Outlined with right icon',
        rightIcon: ALButtonIcon(
            ALImages.iconSearch
        ),
      ),
      ALButton(
        type: ALButtonType.outlined,
        onPressed: () => print('Click'),
        text: 'Outlined with both custom icons',
        leftIcon: ALButtonIcon(
          ALImages.iconSearch,
          color: Colors.redAccent,
          size: 14,
          padding: const EdgeInsets.only(right: 4),
        ),
        rightIcon: ALButtonIcon(
          ALImages.iconSearch,
          color: Colors.greenAccent,
          size: 20,
          padding: const EdgeInsets.only(left: 12),
        ),
      ),
    ];
  }

  List<Widget> _buildTextButtons(BuildContext context) {
    return [
      const Text('Text buttons'),
      ALButton(
        type: ALButtonType.text,
        onPressed: () => print('Click'),
        text: 'Text',
      ),
      ALButton(
        type: ALButtonType.text,
        color: Colors.redAccent,
        onPressed: () => print('Click'),
        text: 'Text with color',
      ),
      ALButton(
        type: ALButtonType.text,
        onPressed: () => print('Click'),
        text: 'Text small',
        height: 28,
      ),
      const ALButton(
        type: ALButtonType.text,
        onPressed: null,
        text: 'Text disabled',
      ),
      ALButton(
        type: ALButtonType.text,
        onPressed: () => print('Click'),
        isLoading: true,
        text: 'Text loading',
      ),
      ALButton(
        type: ALButtonType.text,
        onPressed: () => print('Click'),
        isLoading: true,
        text: 'Text loading with color',
        color: Colors.redAccent,
      ),
      ALButton(
        type: ALButtonType.text,
        onPressed: () => print('Click'),
        text: 'Text with left icon',
        leftIcon: ALButtonIcon(
            ALImages.iconSearch
        ),
      ),
      ALButton(
        type: ALButtonType.text,
        onPressed: () => print('Click'),
        text: 'Text with right icon',
        rightIcon: ALButtonIcon(
            ALImages.iconSearch
        ),
      ),
      ALButton(
        type: ALButtonType.text,
        onPressed: () => print('Click'),
        text: 'Text with both custom icons',
        leftIcon: ALButtonIcon(
          ALImages.iconSearch,
          color: Colors.redAccent,
          size: 14,
          padding: const EdgeInsets.only(right: 4),
        ),
        rightIcon: ALButtonIcon(
          ALImages.iconSearch,
          color: Colors.greenAccent,
          size: 20,
          padding: const EdgeInsets.only(left: 12),
        ),
      )
    ];
  }

  List<Widget> _buildTonalButtons(BuildContext context) {
    return [
      const Text('Tonal buttons'),
      ALButton(
        type: ALButtonType.tonal,
        onPressed: () => print('Click'),
        text: 'Tonal',
      ),
      ALButton(
        type: ALButtonType.tonal,
        color: Colors.redAccent,
        onPressed: () => print('Click'),
        text: 'Tonal with color',
      ),
      ALButton(
        type: ALButtonType.tonal,
        onPressed: () => print('Click'),
        text: 'Tonal small',
        height: 28,
      ),
      const ALButton(
        type: ALButtonType.tonal,
        onPressed: null,
        text: 'Tonal disabled',
      ),
      ALButton(
        type: ALButtonType.tonal,
        onPressed: () => print('Click'),
        isLoading: true,
        text: 'Tonal loading',
      ),
      ALButton(
        type: ALButtonType.tonal,
        onPressed: () => print('Click'),
        isLoading: true,
        color: Colors.redAccent,
        text: 'Tonal loading with color',
      ),
      ALButton(
        type: ALButtonType.tonal,
        onPressed: () => print('Click'),
        text: 'Tonal with left icon',
        leftIcon: ALButtonIcon(
          ALImages.iconSearch
        ),
      ),
      ALButton(
        type: ALButtonType.tonal,
        onPressed: () => print('Click'),
        text: 'Tonal with right icon',
        rightIcon: ALButtonIcon(
          ALImages.iconSearch
        ),
      ),
      ALButton(
        type: ALButtonType.tonal,
        onPressed: () => print('Click'),
        text: 'Tonal with both custom icons',
        leftIcon: ALButtonIcon(
          ALImages.iconSearch,
          color: Colors.redAccent,
          size: 14,
          padding: const EdgeInsets.only(right: 4),
        ),
        rightIcon: ALButtonIcon(
          ALImages.iconSearch,
          color: Colors.greenAccent,
          size: 20,
          padding: const EdgeInsets.only(left: 12),
        ),
      ),
      //---------------Outlined buttons---------------//
      const Text('Outlined buttons'),
      ALButton(
        type: ALButtonType.outlined,
        onPressed: () => print('Click'),
        text: 'Outlined',
      ),
      ALButton(
        type: ALButtonType.outlined,
        color: Colors.redAccent,
        onPressed: () => print('Click'),
        text: 'Outlined with color',
      ),
      ALButton(
        type: ALButtonType.outlined,
        onPressed: () => print('Click'),
        text: 'Outlined small',
        height: 28,
      ),
      const ALButton(
        type: ALButtonType.outlined,
        onPressed: null,
        text: 'Outlined disabled',
      ),
      ALButton(
        type: ALButtonType.outlined,
        onPressed: () => print('Click'),
        isLoading: true,
        text: 'Outlined loading',
      ),
      ALButton(
        type: ALButtonType.outlined,
        onPressed: () => print('Click'),
        isLoading: true,
        text: 'Outlined loading with color',
        color: Colors.redAccent,
      ),
      ALButton(
        type: ALButtonType.outlined,
        onPressed: () => print('Click'),
        text: 'Outlined with left icon',
        leftIcon: ALButtonIcon(
            ALImages.iconSearch
        ),
      ),
      ALButton(
        type: ALButtonType.outlined,
        onPressed: () => print('Click'),
        text: 'Outlined with right icon',
        rightIcon: ALButtonIcon(
            ALImages.iconSearch
        ),
      ),
      ALButton(
        type: ALButtonType.outlined,
        onPressed: () => print('Click'),
        text: 'Outlined with both custom icons',
        leftIcon: ALButtonIcon(
          ALImages.iconSearch,
          color: Colors.redAccent,
          size: 14,
          padding: const EdgeInsets.only(right: 4),
        ),
        rightIcon: ALButtonIcon(
          ALImages.iconSearch,
          color: Colors.greenAccent,
          size: 20,
          padding: const EdgeInsets.only(left: 12),
        ),
      ),
      //---------------Text buttons---------------//
      const Text('Text buttons'),
      ALButton(
        type: ALButtonType.text,
        onPressed: () => print('Click'),
        text: 'Text',
      ),
      ALButton(
        type: ALButtonType.text,
        color: Colors.redAccent,
        onPressed: () => print('Click'),
        text: 'Text with color',
      ),
      ALButton(
        type: ALButtonType.text,
        onPressed: () => print('Click'),
        text: 'Text small',
        height: 28,
      ),
      const ALButton(
        type: ALButtonType.text,
        onPressed: null,
        text: 'Text disabled',
      ),
      ALButton(
        type: ALButtonType.text,
        onPressed: () => print('Click'),
        isLoading: true,
        text: 'Text loading',
      ),
      ALButton(
        type: ALButtonType.text,
        onPressed: () => print('Click'),
        isLoading: true,
        text: 'Text loading with color',
        color: Colors.redAccent,
      ),
      ALButton(
        type: ALButtonType.text,
        onPressed: () => print('Click'),
        text: 'Text with left icon',
        leftIcon: ALButtonIcon(
            ALImages.iconSearch
        ),
      ),
      ALButton(
        type: ALButtonType.text,
        onPressed: () => print('Click'),
        text: 'Text with right icon',
        rightIcon: ALButtonIcon(
            ALImages.iconSearch
        ),
      ),
      ALButton(
        type: ALButtonType.text,
        onPressed: () => print('Click'),
        text: 'Text with both custom icons',
        leftIcon: ALButtonIcon(
          ALImages.iconSearch,
          color: Colors.redAccent,
          size: 14,
          padding: const EdgeInsets.only(right: 4),
        ),
        rightIcon: ALButtonIcon(
          ALImages.iconSearch,
          color: Colors.greenAccent,
          size: 20,
          padding: const EdgeInsets.only(left: 12),
        ),
      )
    ];
  }

  Padding _buildListItem(Widget e) {
    return Padding(
      padding: const EdgeInsets.only(bottom: 10),
      child: e,
    );
  }
}
