import 'package:flutter/material.dart';
import 'package:al/framework/ui/widgets/chips/al_chips_tabbar.dart';

class ChipsPage extends StatefulWidget {
  const ChipsPage({super.key});

  @override
  State<StatefulWidget> createState() => _ChipsPageState();
}

class _ChipsPageState extends State<ChipsPage> with TickerProviderStateMixin {
  final items = [
    ALChipsTabBarItem(ALChipsTabBarItemType.icon, 'icon/settings'),
    ALChipsTabBarItem(ALChipsTabBarItemType.text, 'Все'),
    ALChipsTabBarItem(ALChipsTabBarItemType.text, 'Город'),
    ALChipsTabBarItem(ALChipsTabBarItemType.text, 'Культура'),
    ALChipsTabBarItem(ALChipsTabBarItemType.text, 'Наука'),
    ALChipsTabBarItem(ALChipsTabBarItemType.text, 'Искусство'),
    ALChipsTabBarItem(ALChipsTabBarItemType.text, 'Строительство'),
    ALChipsTabBarItem(ALChipsTabBarItemType.text, 'Экология'),
    ALChipsTabBarItem(ALChipsTabBarItemType.text, 'Ветеринария'),
    ALChipsTabBarItem(ALChipsTabBarItemType.text, 'Здравоохранение'),
  ];

  late TabController _tabController;

  static const TextStyle _pageStyle = TextStyle(
    fontSize: 30,
    fontWeight: FontWeight.bold,
  );

  late List<Widget> _pages;

  @override
  void initState() {
    _tabController =
        TabController(initialIndex: 1, length: items.length, vsync: this);

    _pages = items
        .map((e) => Center(
              child: Text(
                e.type == ALChipsTabBarItemType.text ? e.value : "Icon",
                style: _pageStyle,
              ),
            ))
        .toList();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Column(
        children: [
          ALChipsTabBar(
            context: context,
            controller: _tabController,
            items: items,
            onSelectItem: (index) {
              debugPrint('Выбран чипс $index');
            },
          ),
          Expanded(
            child: TabBarView(
              controller: _tabController,
              children: _pages,
            ),
          ),
        ],
      ),
      floatingActionButton: FloatingActionButton(
        onPressed: switchToNextItem,
        backgroundColor: Colors.amber,
        child: const Icon(Icons.navigate_next),
      ),
    );
  }

  void switchToNextItem() {
    var selectedIndex = _tabController.index;
    if (selectedIndex < items.length - 1) {
      selectedIndex += 1;
    } else {
      selectedIndex = 0;
    }
    _tabController.index = selectedIndex;
  }
}
