import 'package:flutter/material.dart';
import 'package:al/framework/extensions/build_context_extension.dart';
import 'package:al/framework/ui/widgets/al_shimmer.dart';

class ShimmerPage extends StatelessWidget {
  const ShimmerPage({super.key});

  @override
  Widget build(BuildContext context) {
    return ALShimmer(
      context: context,
      child: _buildListView(context),
    );
  }

  Widget _buildListView(BuildContext context) {
    return ListView.builder(
      padding: const EdgeInsets.symmetric(vertical: 8),
      physics: const NeverScrollableScrollPhysics(),
      itemCount: 20,
      itemBuilder: (context, index) => _buildListItem(context),
    );
  }

  Widget _buildListItem(BuildContext context) {
    return Column(
      children: [
        Padding(
          padding: const EdgeInsets.fromLTRB(20, 8, 20, 20),
          child: _buildListItemContent(),
        ),
        Container(
          margin: const EdgeInsets.only(left: 64),
          height: 1,
          color: context.colors.paleGrey,
        )
      ],
    );
  }

  Widget _buildListItemContent() {
    return Row(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        _buildRect(32, 32, 16),
        const SizedBox(width: 12),
        Expanded(
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              const SizedBox(height: 3),
              _buildRect(252, 11, 4),
              const SizedBox(height: 5),
              _buildRect(128, 11, 4),
              const SizedBox(height: 10),
              _buildRect(56, 18, 4),
            ],
          ),
        ),
      ],
    );
  }

  Widget _buildRect(double width, double height, double cornerRadius) {
    return ClipRRect(
      borderRadius: BorderRadius.circular(cornerRadius),
      child: Container(
        color: Colors.black,
        width: width,
        height: height,
      ),
    );
  }
}
