import 'dart:async';

import 'package:altv/activation/logic/entities/activation_hall_info.dart';
import 'package:altv/framework/network/request_sender.dart';
import 'package:altv/framework/storages/secure_storage.dart';
import 'package:altv/activation/logic/network/activation_check_request.dart';
import 'package:altv/activation/logic/network/activation_check_response.dart';

class ActivationRepository {
  final ISecureStorage secureStorage;
  final RequestSender requestSender;

  late final ActivationHallInfo hallInfo;

  ActivationRepository({
    required this.secureStorage,
    required this.requestSender,
  });

  Future<bool> checkActivation() async {
    final uuid = secureStorage.uuid!;

    try {
      final response = await requestSender.send(
        ActivationCheckRequest(uuid: uuid),
        ActivationCheckResponse(),
      );

      if (response.activationHallInfo != null) {
        hallInfo = response.activationHallInfo!;
        return true;
      }
    } on Exception catch (_) {
      // TODO добавить обработку ошибок
    }

    return false;
  }

  Future<ActivationHallInfo> checkActivationUntilActivated() async {
    final uuid = secureStorage.uuid!;
    final activationInfo = await _getActivationInfo(uuid: uuid);

    return activationInfo!;
  }

  Future<ActivationHallInfo?> _getActivationInfo({required String uuid}) async {
    await Future.delayed(const Duration(seconds: 10));

    try {
      final response = await requestSender.send(
        ActivationCheckRequest(uuid: uuid),
        ActivationCheckResponse(),
      );

      if (response.activationHallInfo != null) {
        hallInfo = response.activationHallInfo!;
        return response.activationHallInfo;
      }
    } on Exception catch (_) {
      // TODO добавить обработку ошибок
    }

    return await _getActivationInfo(uuid: uuid);
  }
}
