import 'package:bloc/bloc.dart';
import 'package:altv/framework/environment/environment.dart';
import 'package:altv/framework/environment/server_route.dart';

part 'environment_settings_state.dart';

class EnvironmentSettingsCubit extends Cubit<EnvironmentSettingsState> {
  static const defaultCustomServerAddress = "http://0.0.0.0:3000";

  static const routes = [
    ServerRoute.development,
    ServerRoute.production,
  ];

  final Environment environment;

  EnvironmentSettingsCubit({required this.environment})
      : super(_getStateForCurrentSettings(environment));

  static EnvironmentSettingsInitial _getStateForCurrentSettings(Environment environment) {
    return EnvironmentSettingsInitial(
      routes: routes,
      selectedRoute: environment.serverRoute,
      customServerAddress: environment.customServerAddress ?? defaultCustomServerAddress,
      isCustomServerAddressEnabled: environment.isCustomServerAddressEnabled,
      isAnalyticsDebugEnabled: environment.isAnalyticsDebugEnabled,
    );
  }

  Future<void> selectRoute(ServerRoute? route) async {
    await environment.setServerRoute(route);
    emit(EnvironmentSettingsInitial.fromOther(
      state as EnvironmentSettingsInitial,
      selectedRoute: route,
    ));
  }

  Future<void> setCustomAddress(String address) async {
    await environment.setCustomServerAddress(address);
    emit(EnvironmentSettingsInitial.fromOther(
      state as EnvironmentSettingsInitial,
      customServerAddress: address,
    ));
  }

  Future<void> setCustomAddressEnabled(bool isEnabled) async {
    await environment.setCustomServerAddressEnabled(isEnabled);

    if (state is EnvironmentSettingsInitial && isEnabled) {
      final address = (state as EnvironmentSettingsInitial).customServerAddress;
      environment.setCustomServerAddress(address);
    }

    emit(EnvironmentSettingsInitial.fromOther(
      state as EnvironmentSettingsInitial,
      isCustomServerAddressEnabled: isEnabled,
    ));
  }

  Future<void> setAnalyticsDebugEnabled(bool? isEnabled) async {
    if (isEnabled != null) {
      await environment.setAnalyticsDebugEnabled(isEnabled: isEnabled);
    }

    if (!isClosed) {
      emit(EnvironmentSettingsInitial.fromOther(
        state as EnvironmentSettingsInitial,
        isAnalyticsDebugEnabled: isEnabled,
      ));
    }
  }
}
