import 'package:bloc/bloc.dart';
import 'package:equatable/equatable.dart';
import 'package:altv/debug_settings/logic/entities/feature_settings_item.dart';
import 'package:altv/debug_settings/logic/repository/feature_settings_repository.dart';
import 'package:altv/framework/environment/feature_id.dart';

part 'feature_settings_state.dart';

class FeatureSettingsCubit extends Cubit<FeatureSettingsState> {
  final FeatureSettingsRepository repository;

  FeatureSettingsCubit({required this.repository})
      : super(FeatureSettingsInitial(items: _getFeatureItems(repository)));

  setFeatureOverride(FeatureID featureId, {required bool? value}) async {
    await repository.overrideFeature(featureId, isAvailable: value);
    emit(FeatureSettingsInitial(items: _getFeatureItems(repository)));
  }

  resetOverrides() async {
    await repository.resetFeatureOverrides();
    emit(FeatureSettingsInitial(items: _getFeatureItems(repository)));
  }

  static List<FeatureSettingsItem> _getFeatureItems(
    FeatureSettingsRepository repository,
  ) {
    return FeatureID.values.map((id) {
      return FeatureSettingsItem(
        id: id,
        isReleased: FeatureIDAdapter.toReleaseStatus(id),
        description: FeatureIDAdapter.toDescription(id),
        overrideValue: repository.getFeatureOverrideValue(id),
      );
    }).toList();
  }
}
