import 'package:altv/framework/environment/feature_id.dart';
import 'package:altv/framework/storages/preferences_storage.dart';

class FeatureSettingsRepository {
  final IPreferencesStorage _preferencesStorage;

  FeatureSettingsRepository({
    required IPreferencesStorage preferencesStorage,
  }) : _preferencesStorage = preferencesStorage;

  bool? getFeatureOverrideValue(FeatureID feature) =>
      _preferencesStorage.featureOverrides[feature.toString()];

  Future<void> overrideFeature(
    FeatureID feature, {
    required bool? isAvailable,
  }) async {
    if (isAvailable == null || isAvailable == FeatureIDAdapter.toReleaseStatus(feature)) {
      _preferencesStorage.featureOverrides.remove(feature.toString());
    } else {
      _preferencesStorage.featureOverrides[feature.toString()] = isAvailable;
    }
    await _preferencesStorage.save();
  }

  Future<void> resetFeatureOverrides() async {
    _preferencesStorage.featureOverrides = {};
    await _preferencesStorage.save();
  }
}
