import 'package:flutter/material.dart';
import 'package:altv/framework/ui/widgets/buttons/al_back_button.dart';
import 'package:altv/framework/ui/widgets/al_app_bar.dart';

class DebugSettingsPage extends StatelessWidget {

  final Function({required BuildContext context}) onBack;
  final Function({required BuildContext context}) onShowEnvironmentSettings;
  final Function({required BuildContext context}) onShowFeatureSettings;

  const DebugSettingsPage({
    super.key,
    required this.onBack,
    required this.onShowEnvironmentSettings,
    required this.onShowFeatureSettings,
  });

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: ALAppBar(
        titleText: 'Настройки',
        leading: _buildBackButton(context),
      ),
      body: SafeArea(child: _buildContents(context)),
    );
  }

  Widget _buildBackButton(BuildContext context) {
    return ALBackButton(
      onPressed: () => onBack(context: context),
    );
  }

  Widget _buildContents(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        _buildSettingsItem(
          title: 'Настройки окружения',
          onTap: () => onShowEnvironmentSettings(context: context)
        ),
        _buildSettingsItem(
          title: 'Настройки фич',
          onTap: () => onShowFeatureSettings(context: context),
        ),
      ],
    );
  }

  Widget _buildSettingsItem({required String title, required VoidCallback onTap}) {
    return InkWell(
      onTap: onTap,
      child: Padding(
        padding: const EdgeInsets.all(16),
        child: Row(
          children: [
            Text(title)
          ],
        )
      ),
    );
  }
}
