import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:altv/debug_settings/logic/bloc/environment_settings/environment_settings_cubit.dart';
import 'package:altv/debug_settings/logic/bloc/feature_settings/feature_settings_cubit.dart';
import 'package:altv/debug_settings/ui/debug_settings/debug_settings_page.dart';
import 'package:altv/debug_settings/ui/environment_settings/environment_settings_page.dart';
import 'package:altv/debug_settings/ui/feature_settings/feature_settings_page.dart';
import 'package:altv/framework/di/di_container.dart';
import 'package:altv/framework/ui/navigation/navigation_coordinator.dart';

class DebugSettingsCoordinator extends NavigationCoordinator {
  final DIContainer diContainer;

  DebugSettingsCoordinator({required this.diContainer});

  void showEnvironmentSettings({required BuildContext context}) {
    push(
      context: context,
      page: BlocProvider<EnvironmentSettingsCubit>(
        create: (context) => diContainer.resolve<EnvironmentSettingsCubit>(),
        child: EnvironmentSettingsPage(onBack: pop),
      ),
    );
  }

  void showFeatureSettings({required BuildContext context}) {
    push(
      context: context,
      page: BlocProvider<FeatureSettingsCubit>(
        create: (context) => diContainer.resolve<FeatureSettingsCubit>(),
        child: FeatureSettingsPage(onBack: pop),
      ),
    );
  }

  void showDebugSettings({required BuildContext context}) {
    push(
      context: context,
      page: DebugSettingsPage(
        onBack: pop,
        onShowEnvironmentSettings: showEnvironmentSettings,
        onShowFeatureSettings: showFeatureSettings
      ),
    );
  }
}
