import 'package:appmetrica_plugin/appmetrica_plugin.dart';
import 'package:altv/framework/analytics/analytics_event.dart';
import 'package:altv/framework/log/log.dart';
import 'package:altv/framework/ui/widgets/al_toast.dart';
import 'package:synchronized/synchronized.dart';

class AnalyticsSender {
  final bool isAnalyticsDebugEnabled;

  static final _toastLock = Lock();

  const AnalyticsSender({required this.isAnalyticsDebugEnabled});

  Future<void> send(AnalyticsEvent event) async {
    await _sendYandex(event);
    if (isAnalyticsDebugEnabled) {
      _showToast(event);
    }
    Log.i("Событие аналитики: ${event.toString()}");
  }

  void _showToast(AnalyticsEvent event) {
    // Чтобы тосты вставали в очередь, оборачиваем в synchronized
    _toastLock.synchronized(
      () async {
        ALToast.showShortMessage(event.toString());
        await Future.delayed(const Duration(seconds: 2));
      },
    );
  }

  Future<void> _sendYandex(AnalyticsEvent event) async {
    await AppMetrica.reportEvent(event.name);
  }
}
