import 'package:flutter/material.dart';
import 'package:altv/framework/errors/error_handler/error_handler_formatter.dart';
import 'package:altv/framework/errors/error_handler/error_handler_widget.dart';
import 'package:altv/framework/framework_dependencies.dart';
import 'package:altv/framework/log/log.dart';
import 'package:altv/framework/ui/widgets/al_alert.dart';

class ErrorHandler {
  final ErrorHandlerFormatter formatter;
  final IFrameworkErrorHandlerLogoutCaller logoutCaller;

  ErrorHandler({
    required this.formatter,
    required this.logoutCaller,
  });

  Widget buildErrorWidget({
    required Exception exception,
    required VoidCallback onRetry,
  }) {
    return ErrorHandlerWidget(
      headerText: formatter.getHeaderText(exception),
      detailsText: formatter.getDetailsText(exception),
      technicalInfoText: formatter.getTechnicalInfoText(exception),
      actionButtonText: formatter.getActionButtonText(exception),
      onActionButtonTap: formatter.isAuthException(exception)
          ? logoutCaller.errorHandlerLogOut
          : onRetry,
    );
  }

  void showException(Exception exception, {required BuildContext context}) {
    if (formatter.isCrashReportNeeded(exception)) {
      Log.crashException(
        exception,
        message: formatter.getCrashReportMessage(exception),
        stack: StackTrace.current,
      );
    }
    if (formatter.isAuthException(exception)) {
      _showAuthException(exception, context);
    } else {
      _showAlert(
        text: formatter.getDetailsText(exception),
        technicalInfo: formatter.getTechnicalInfoText(exception),
        context: context,
      );
    }
  }

  void _showAuthException(Exception exception, BuildContext context) {
    final message =
        "${formatter.getHeaderText(exception)}\n${formatter.getDetailsText(exception)}";
    ALAlert.show(message, context: context, buttons: [
      ALAlertButton(
        text: formatter.getActionButtonText(exception),
        action: () => logoutCaller.errorHandlerLogOut(),
      ),
    ]);
  }

  void _showAlert({
    required String text,
    required String? technicalInfo,
    required BuildContext context,
  }) {
    final message = technicalInfo != null && technicalInfo != text
        ? "$text\n\n$technicalInfo"
        : text;
    ALAlert.show(message, context: context, buttons: [
      ALAlertButton(text: "Закрыть", action: null),
    ]);
  }
}
