import 'package:altv/framework/errors/exceptions/connection_failed_exception.dart';
import 'package:altv/framework/errors/exceptions/internal_exception.dart';
import 'package:altv/framework/errors/exceptions/message_exception.dart';
import 'package:altv/framework/errors/exceptions/no_auth_exception.dart';
import 'package:altv/framework/errors/exceptions/no_connection_exception.dart';
import 'package:altv/framework/errors/exceptions/server_message_exception/server_message_exception.dart';
import 'package:altv/framework/errors/exceptions/server_page_not_found_exception.dart';

class ErrorHandlerFormatter {
  bool isAuthException(Exception exception) {
    if (exception is NoAuthException) {
      return true;
    } else if (exception is ServerMessageException) {
      return exception.type == ServerMessageExceptionType.noAuth;
    } else {
      return false;
    }
  }

  String getHeaderText(Exception exception) {
    if (isAuthException(exception)) {
      return 'Не удалось авторизоваться';
    } else if (exception is ServerMessageException &&
        exception.type == ServerMessageExceptionType.general) {
      return "";
    } else {
      return 'Не удалось загрузить данные';
    }
  }

  String getDetailsText(Exception exception) {
    if (isAuthException(exception)) {
      return 'Попробуйте войти в приложение еще раз';
    } else if (exception is ConnectionFailedException) {
      return 'Не удалось отправить запрос. Повторите попытку позже';
    } else if (exception is MessageException) {
      return exception.message;
    } else if (exception is NoConnectionException) {
      return 'Проверьте подключение к интернету и повторите попытку';
    } else if (exception is ServerMessageException) {
      return _getServerExceptionMessage(exception) ?? 'Не удалось выполнить операцию';
    } else if (exception is ServerPageNotFoundException) {
      return 'Страница не найдена';
    } else {
      return 'Не удалось выполнить операцию';
    }
  }

  String? _getServerExceptionMessage(ServerMessageException exception) {
    switch (exception.type) {
      case ServerMessageExceptionType.general:
        return exception.message?.text ?? '';
      default:
        return 'Повторите попытку позже';
    }
  }

  String? getTechnicalInfoText(Exception exception) {
    if (exception is ConnectionFailedException) {
      return exception.cause.toString();
    } else if (exception is ServerMessageException) {
      return 'Код ${exception.code}: ${exception.message ?? ''}';
    } else {
      return exception.toString();
    }
  }

  String getActionButtonText(Exception exception) {
    if (isAuthException(exception)) {
      return 'Повторить вход';
    } else {
      return 'Повторить';
    }
  }

  bool isCrashReportNeeded(Exception exception) {
    final e = exception;
    if (e is MessageException ||
        e is NoConnectionException ||
        e is ServerMessageException &&
            e.code != ServerMessageExceptionType.general.index) {
      return false;
    }

    return true;
  }

  String getCrashReportMessage(Exception exception) {
    if (exception is ConnectionFailedException) {
      return 'Обработка ConnectionFailedException';
    } else if (exception is InternalException) {
      return "Обработка InternalException";
    } else {
      return 'Обработка UnknownException';
    }
  }
}
