import 'package:collection/collection.dart';
import 'package:altv/framework/errors/exceptions/server_message_exception/server_message_exception_key.dart';
import 'package:typed_json/typed_json.dart';
import 'package:equatable/equatable.dart';

class ServerMessageExceptionMessage extends Equatable {
  final ServerMessageExceptionKey? key;
  final String? attribute;
  final String? text;
  final String? value;

  const ServerMessageExceptionMessage({
    required this.key,
    this.attribute,
    this.text,
    this.value,
  });

  ServerMessageExceptionMessage copyWith({
    ServerMessageExceptionKey? key,
    String? attribute,
    String? text,
    String? value,
  }) {
    return ServerMessageExceptionMessage(
      key: key ?? this.key,
      attribute: attribute ?? this.attribute,
      text: text ?? this.text,
      value: value ?? this.value,
    );
  }

  static ServerMessageExceptionMessage? fromJson(Json json) {
    try {
      return json
          .toObjectList((j) => ServerMessageExceptionMessage(
                attribute: j['attribute'].stringValue,
                key: j['key'].get(ServerMessageExceptionKeyAdapter()),
                text: j['text'].stringValue,
                value: j['value'].stringValue,
              ))
          ?.firstOrNull;
    } catch (_) {
      return null;
    }
  }

  @override
  List<Object?> get props => [key, attribute, text];
}
