extension IterableExtension<E> on Iterable<E> {
  bool containsWhere(bool Function(E element) test) {
    return firstOrNullWhere((element) => test(element)) != null;
  }

  bool notContainsWhere(bool Function(E element) test) {
    return !containsWhere(test);
  }

  E? firstOrNullWhere(bool Function(E element) test) {
    for (E item in this) {
      if (test(item)) {
        return item;
      }
    }
    return null;
  }

  E? lastOrNullWhere(bool Function(E element) test) {
    E? last;
    for (E item in this) {
      if (test(item)) {
        last = item;
      }
    }
    return last;
  }
}
