import 'dart:math';
import 'package:mask_text_input_formatter/mask_text_input_formatter.dart';

extension StringExtension on String {
  String get capitalized {
    if (isEmpty) {
      return "";
    } else if (length == 1) {
      return toUpperCase();
    } else {
      return this[0].toUpperCase() + substring(1);
    }
  }

  bool checkRegexp(String pattern) {
    RegExpMatch? match = RegExp(pattern).firstMatch(this);
    if (match == null) {
      return false;
    } else {
      return match.start == 0 && match.end == length;
    }
  }

  /// Накладываем маску, например, форматирует номера телефонов.
  /// Доступные паттерны добавляются по мере необходимости. Сейчас:
  /// * '#' - цифра
  String applyMask(String mask) {
    if (isEmpty) {
      return "";
    }

    final maskFormatter = MaskTextInputFormatter(
      mask: mask,
      filter: {"#": RegExp(r'[0-9]')},
    );
    return maskFormatter.maskText(this);
  }

  String get applyPhoneMask {
    if (length == 11) {
      if (startsWith("7")) {
        return applyMask("+# (###) ###-##-##");
      } else if (startsWith("8")) {
        return applyMask("# (###) ###-##-##");
      }
    } else if (length == 5) {
      return applyMask("###-##");
    } else if (length == 6) {
      return applyMask("##-##-##");
    } else if (length == 7) {
      return applyMask("###-##-##");
    }
    return this;
  }

  String replaceLast(Pattern from, String to) {
    var startIndex = max(lastIndexOf(from), 0);
    return replaceFirst(from, to, startIndex);
  }
}
