import 'package:intl/date_symbol_data_custom.dart';
import 'package:intl/date_symbol_data_local.dart';
import 'package:intl/date_time_patterns.dart';
import 'package:intl/intl.dart';

class ALDateFormat {
  /// 2020-12-31T11:20:41
  static const ymdhms = "yyyy-MM-dd'T'HH:mm:ss";

  /// 2020-12-31
  static const ymd = "yyyy-MM-dd";

  /// 01.01.2021 11:20:41
  static const dmyhms = "dd.MM.yyyy HH:mm:ss";

  /// 01.01.2021 11:20
  static const dmyhm = "dd.MM.yyyy HH:mm";

  /// 11:20    01.01.2021
  static const hmdmy = "HH:mm    dd.MM.yyyy";

  /// 01.01.2021
  static const dmy = "dd.MM.yyyy";

  /// 2021
  static const yyyy = "yyyy";

  /// 11:20
  static const hhmm = "HH:mm";

  /// 01.01
  static const dm = "dd.MM";

  /// 1
  static const d = "d";

  /// 1 января 2021
  static const literalDmy = "d MMMM yyyy";

  /// 1 января
  static const literalDm = "d MMMM";

  /// Январь
  static const literalM = "MMMM";

  /// Январь 2021
  static const literalMy = "MMMM yyyy";

  /// 1 января 2021, 12:00
  static const literalDmyhm = "d MMMM yyyy, HH:mm";
}

class ALDateFormatter {
  static String format(DateTime value, String format) {
    _init();
    return DateFormat(format, "ru").format(value);
  }

  static DateTime fromString(String value, String format) {
    _init();
    return DateFormat(format, "ru").parse(value);
  }

  static bool _isInitialized = false;
  static _init() {
    // Вручную инициализируем русскую локализацию дат, чтобы не возникало конфликтов
    // между intl и flutter_localizations. Если инициализировать локали через
    // стандартный метод initializeDateFormatting(), на некоторых телефонах могут
    // быть краши.

    if (!_isInitialized) {
      initializeDateFormattingCustom(
        locale: 'ru',
        symbols: dateTimeSymbolMap()['ru'],
        patterns: dateTimePatternMap()['ru'],
      );
      _isInitialized = true;
    }
  }
}
