import 'package:altv/framework/analytics/analytics_sender.dart';
import 'package:altv/framework/di/di_assembly.dart';
import 'package:altv/framework/di/di_container.dart';
import 'package:altv/framework/environment/build_type.dart';
import 'package:altv/framework/environment/environment.dart';
import 'package:altv/framework/environment/features.dart';
import 'package:altv/framework/errors/error_handler/error_handler.dart';
import 'package:altv/framework/errors/error_handler/error_handler_formatter.dart';
import 'package:altv/framework/framework_dependencies.dart';
import 'package:altv/framework/log/crash_logger.dart';
import 'package:altv/framework/network/request_sender.dart';
import 'package:altv/framework/storages/preferences_storage.dart';
import 'package:altv/framework/storages/secure_storage.dart';
import 'package:altv/framework/timer/logic/repositories/server_timer_repository.dart';
import 'package:altv/framework/utils/app_info_reader.dart';

class FrameworkAssembly extends DIAssembly {
  final BuildType buildType;

  FrameworkAssembly({required this.buildType});

  @override
  assembly(DIContainer container) {
    container.registerSingleton<IPreferencesStorage>(
      (container) => PreferencesStorage(),
    );

    container.registerSingleton<ISecureStorage>(
      (container) => SecureStorage(),
    );

    container.registerSingleton(
      (container) => CrashLogger(),
    );

    container.registerSingleton<Environment>(
      (container) => Environment(
        buildType: buildType,
        preferencesStorage: container.resolve<IPreferencesStorage>(),
      ),
    );

    container.registerSingleton(
      (container) => AnalyticsSender(
        isAnalyticsDebugEnabled:
            container.resolve<Environment>().isAnalyticsDebugEnabled,
      ),
    );

    container.registerFactory(
      (container) => AppInfoReader(),
    );

    container.registerSingleton(
      (container) => Features(
        environment: container.resolve<Environment>(),
        preferencesStorage: container.resolve<IPreferencesStorage>(),
      ),
    );

    container.registerSingleton<RequestSender>(
      (container) => RequestSender(
        environment: container.resolve<Environment>(),
      ),
    );

    container.registerInstance<ErrorHandlerFormatter>(
      ErrorHandlerFormatter(),
    );

    container.registerSingleton<ErrorHandler>(
      (container) => ErrorHandler(
        formatter: container.resolve<ErrorHandlerFormatter>(),
        logoutCaller: container.resolve<IFrameworkErrorHandlerLogoutCaller>(),
      ),
    );

    container.registerSingleton(
      (container) => ServerTimerRepository(
        requestSender: container.resolve<RequestSender>(),
      ),
    );
  }
}
