import 'package:appmetrica_plugin/appmetrica_plugin.dart';
import 'package:altv/framework/log/log.dart';

abstract class ICrashLogger {
  Future<void> logException(
    Exception e, {
    required StackTrace stack,
    String? message,
  });

  Future<void> logError(
    Error e, {
    required StackTrace stack,
    String? message,
  });
}

class CrashLoggerStub implements ICrashLogger {
  @override
  Future<void> logError(
    Error e, {
    required StackTrace stack,
    String? message,
  }) async {
    Log.e("Exception ($message):\n$e");
  }

  @override
  Future<void> logException(
    Exception e, {
    required StackTrace stack,
    String? message,
  }) async {
    Log.e("Exception ($message):\n$e");
  }
}

class CrashLogger implements ICrashLogger {
  @override
  Future<void> logError(
    Error e, {
    required StackTrace stack,
    String? message,
  }) async {
    final yaDesc = AppMetricaErrorDescription.fromObjectAndStackTrace(e, stack);
    AppMetrica.reportError(message: message, errorDescription: yaDesc);
  }

  @override
  Future<void> logException(
    Exception e, {
    required StackTrace stack,
    String? message,
  }) async {
    final yaDesc = AppMetricaErrorDescription.fromObjectAndStackTrace(e, stack);
    AppMetrica.reportError(message: message, errorDescription: yaDesc);
  }
}
