import 'dart:async';

import 'package:dio/dio.dart';
import 'package:altv/framework/res/al_contstants.dart';
import 'package:typed_json/typed_json.dart';

enum HttpMethod { post, get, delete }

abstract class IRequest {
  const IRequest();

  /// HTTP-тип запроса.
  HttpMethod get httpMethod;

  /// Тип запрашиваемых данных. Подставляется в заголовки.
  String get accept => ALConstants.apiAccept;

  /// Версия API сервера
  String get apiVersion => ALConstants.apiVersion;

  /// Метод API мобильного сервиса. Подставляется в адрес запроса.
  String get apiMethod;

  /// Требуется ли авторизация для отправки метода
  bool get isAuthRequired => true;

  /// Кастомный базовый URL. Если не указан, то берется из Environment
  String? get baseUrlOverride => null;

  /// Дополнительные параметры запроса. Подставляется в адрес запроса.
  Map<String, dynamic> getParameters();

  /// Дополнительные заголовки.
  Map<String, String> getHeaders() => {};

  /// Тело запроса. В зависимости от запроса может возвращать Json, String или FormData
  FutureOr<Object> getRawBody();
}

/// Базовый класс для GET-запросов
abstract class IGetRequest extends IRequest {
  const IGetRequest();

  @override
  HttpMethod get httpMethod => HttpMethod.get;

  @override
  Json getRawBody() => Json.empty();
}

/// Базовый класс для POST-запросов с Json в body
abstract class IPostRequest extends IRequest {
  const IPostRequest();

  @override
  HttpMethod get httpMethod => HttpMethod.post;

  @override
  Map<String, dynamic> getParameters() => {};

  @override
  Object getRawBody() => getBody();

  Json getBody();
}

/// Базовый класс для POST-запросов с FormData в body
abstract class IFromDataPostRequest extends IRequest {
  const IFromDataPostRequest();

  @override
  HttpMethod get httpMethod => HttpMethod.post;

  @override
  Map<String, dynamic> getParameters() => {};

  @override
  Future<Object> getRawBody() => getBody();

  Future<FormData> getBody();
}
