import 'dart:async';

import 'package:dio/dio.dart';
import 'package:typed_json/typed_json.dart';

/// Базовый класс для ответов
abstract class IBaseResponse {
  const IBaseResponse();

  /// Тип возвращаемых данных
  ResponseType get responseType => ResponseType.bytes;

  /// Возвращает raw-данные ответа
  FutureOr<void> rawResult(dynamic data);
}

/// Класс для json ответов
abstract class IResponse extends IBaseResponse {
  const IResponse();

  @override
  ResponseType get responseType => ResponseType.json;

  @override
  FutureOr<void> rawResult(dynamic data) {
    final json = Json(data);
    parseResult(json);
  }

  void parseResult(Json json);
}

/// Класс для json ответов
abstract class IPlainResponse extends IBaseResponse {
  const IPlainResponse();

  @override
  ResponseType get responseType => ResponseType.plain;

  @override
  FutureOr<void> rawResult(dynamic data) {
    parseResult(data);
  }

  void parseResult(String data);
}
