import 'package:flutter/material.dart';

class ALThemeColors extends ThemeExtension<ALThemeColors> {
  /// Набор цветов для отображения в контексте фиксированной яркости (например,
  /// поверх кнопки, выкрашенной в яркий цвет).
  ALThemeColors get fixed => lightColors;

  Color get transparent => Colors.transparent;

  Color get skeleton => veryCoolGrey;

  Color get primary => blue;

  Color get darkGrey => slateGrey;

  Color get overlayBackground => overlay;

  Color get white => whiteBackground;

  Color get selectionDisableActive => lightBlue;

  final Brightness brightness;

  final Color dark;
  final Color slateGrey;
  final Color overlay;
  final Color coolGrey;
  final Color veryCoolGrey;
  final Color paleGrey;
  final Color paleGreyDisabled;
  final Color veryPaleGrey;
  final Color whiteBackground;
  final Color whiteCard;
  final Color whiteElevation;

  final Color blue;
  final Color dodgerBlue;
  final Color dodgerBlueLink;

  final Color iris;
  final Color lightIndigo;
  final Color lavender;
  final Color pink;
  final Color orange;
  final Color yellow;
  final Color butterscotch;
  final Color green;
  final Color red;

  final Color lightBlue;
  final Color lightPink;
  final Color veryLightPink;

  final Color appBarShadow1;
  final Color appBarShadow2;
  final Color popupBackground;

  static const lightColors = ALThemeColors._(
    dark: Color(0xff34415A),
    slateGrey: Color(0xff131415),
    coolGrey: Color(0xffb8b8c0),
    veryCoolGrey: Color(0xffe4e4e4),
    paleGrey: Color(0xfff0f0f2),
    paleGreyDisabled: Color(0xfff0f0f2),
    veryPaleGrey: Color(0xfff6f6f7),
    whiteBackground: Color(0xffffffff),
    whiteCard: Color(0xffFAF7FB),
    whiteElevation: Color(0xffffffff),
    blue: Color(0xff2F6FC1),
    dodgerBlue: Color(0xff3f8cff),
    dodgerBlueLink: Color(0xff3f8cff),
    iris: Color(0xff5545b8),
    lightIndigo: Color(0xff6d5dd3),
    lavender: Color(0xffa599f1),
    pink: Color(0xffda75e6),
    orange: Color(0xffff744c),
    yellow: Color(0xfff9b523),
    butterscotch: Color(0xffffc64b),
    lightBlue: Color(0xffa0d7e7),
    lightPink: Color(0xffffe7e0),
    veryLightPink: Color(0xffffe7e0),
    appBarShadow1: Color(0x0c1e2c5e),
    appBarShadow2: Color(0x33435f8a),
    popupBackground: Color(0x70868ca4),
    overlay: Color(0xff404750),
    green: Colors.green,
    red: Color(0xffEA4612),
  );

  static const darkColors = ALThemeColors._(
    brightness: Brightness.dark,
    dark: Color(0xffffffff),
    slateGrey: Color(0xfff6f6f7),
    coolGrey: Color(0xffb8b8c0),
    veryCoolGrey: Color(0xff656679),
    paleGrey: Color(0xff656679),
    paleGreyDisabled: Color(0xff282a47),
    veryPaleGrey: Color(0xff656679),
    whiteBackground: Color(0xff11142d),
    whiteCard: Color(0xff353752),
    whiteElevation: Color(0xff44455b),
    blue: Color(0xff0049c6),
    dodgerBlue: Color(0xff3f8cff),
    dodgerBlueLink: Color(0xff72aaff),
    iris: Color(0xff5545b8),
    lightIndigo: Color(0xff6d5dd3),
    lavender: Color(0xffa599f1),
    pink: Color(0xffda75e6),
    orange: Color(0xffff744c),
    yellow: Color(0xfff9b523),
    butterscotch: Color(0xffffc64b),
    lightBlue: Color(0xffa0d7e7),
    lightPink: Color(0xffffe7e0),
    veryLightPink: Color(0xffffe7e0),
    appBarShadow1: Color(0x0c1e2c5e),
    appBarShadow2: Color(0x33435f8a),
    popupBackground: Color(0x70353752),
    overlay: Color(0xb3353752),
    green: Colors.green,
    red: Color(0xffEA4612),
  );

  const ALThemeColors._({
    this.brightness = Brightness.light,
    required this.dark,
    required this.slateGrey,
    required this.coolGrey,
    required this.veryCoolGrey,
    required this.paleGrey,
    required this.paleGreyDisabled,
    required this.veryPaleGrey,
    required this.whiteBackground,
    required this.whiteCard,
    required this.whiteElevation,
    required this.blue,
    required this.dodgerBlue,
    required this.dodgerBlueLink,
    required this.iris,
    required this.lightIndigo,
    required this.lavender,
    required this.green,
    required this.red,
    required this.pink,
    required this.orange,
    required this.yellow,
    required this.butterscotch,
    required this.lightBlue,
    required this.lightPink,
    required this.veryLightPink,
    required this.appBarShadow1,
    required this.appBarShadow2,
    required this.popupBackground,
    required this.overlay,
  });

  @override
  ThemeExtension<ALThemeColors> copyWith() => this;

  @override
  ThemeExtension<ALThemeColors> lerp(
    ThemeExtension<ALThemeColors>? other,
    double t,
  ) {
    if (other is! ALThemeColors) {
      return this;
    }

    return ALThemeColors._(
      dark: Color.lerp(dark, other.dark, t)!,
      slateGrey: Color.lerp(slateGrey, other.slateGrey, t)!,
      coolGrey: Color.lerp(coolGrey, other.coolGrey, t)!,
      veryCoolGrey: Color.lerp(veryCoolGrey, other.veryCoolGrey, t)!,
      paleGrey: Color.lerp(paleGrey, other.paleGrey, t)!,
      paleGreyDisabled: Color.lerp(paleGreyDisabled, other.paleGreyDisabled, t)!,
      veryPaleGrey: Color.lerp(veryPaleGrey, other.veryPaleGrey, t)!,
      whiteBackground: Color.lerp(whiteBackground, other.whiteBackground, t)!,
      whiteCard: Color.lerp(whiteCard, other.whiteCard, t)!,
      whiteElevation: Color.lerp(whiteElevation, other.whiteElevation, t)!,
      blue: Color.lerp(blue, other.blue, t)!,
      dodgerBlue: Color.lerp(dodgerBlue, other.dodgerBlue, t)!,
      dodgerBlueLink: Color.lerp(dodgerBlueLink, other.dodgerBlueLink, t)!,
      iris: Color.lerp(iris, other.iris, t)!,
      lightIndigo: Color.lerp(lightIndigo, other.lightIndigo, t)!,
      lavender: Color.lerp(lavender, other.lavender, t)!,
      pink: Color.lerp(pink, other.pink, t)!,
      orange: Color.lerp(orange, other.orange, t)!,
      yellow: Color.lerp(yellow, other.yellow, t)!,
      butterscotch: Color.lerp(butterscotch, other.butterscotch, t)!,
      lightBlue: Color.lerp(lightBlue, other.lightBlue, t)!,
      lightPink: Color.lerp(lightPink, other.lightPink, t)!,
      veryLightPink: Color.lerp(veryLightPink, other.veryLightPink, t)!,
      appBarShadow1: Color.lerp(appBarShadow1, other.appBarShadow1, t)!,
      appBarShadow2: Color.lerp(appBarShadow2, other.appBarShadow2, t)!,
      popupBackground: Color.lerp(popupBackground, other.popupBackground, t)!,
      overlay: Color.lerp(overlay, other.overlay, t)!,
      green: Color.lerp(green, other.green, t)!,
      red: Color.lerp(red, other.red, t)!,
    );
  }
}
