import 'dart:io';

import 'package:flutter/material.dart';
import 'package:altv/framework/theme/al_theme_colors.dart';

class ALThemeTextStyles extends ThemeExtension<ALThemeTextStyles> {
  static final String? _defaultFontFamily = Platform.isAndroid ? 'Roboto' : null;

  final TextStyle headlineLarge;
  final TextStyle headline;
  final TextStyle headlineSmallHeavy;
  final TextStyle headlineSmallBold;
  final TextStyle headlineSmallSemibold;
  final TextStyle titleLarge;
  final TextStyle title;
  final TextStyle titleSmallBold;
  final TextStyle titleSmallMedium;
  final TextStyle titleSmallRegular;
  final TextStyle bodyHeavy;
  final TextStyle bodyBold;
  final TextStyle bodySemibold;
  final TextStyle bodyMedium;
  final TextStyle bodyRegular;
  final TextStyle bodySmallRegular;
  final TextStyle bodySmallHeavy;
  final TextStyle bodySmallBold;
  final TextStyle bodySmallSemibold;
  final TextStyle bodySmallMedium;
  final TextStyle bodySmallLight;
  final TextStyle labelLargeSemibold;
  final TextStyle labelLargeMedium;
  final TextStyle labelLargeRegular;
  final TextStyle labelLargeLight;
  final TextStyle labelBold;
  final TextStyle labelMedium;
  final TextStyle labelRegular;
  final TextStyle labelLight;

  final TextStyle pinKeyboard;
  final TextStyle pinTitle;

  static final light = _getStylesForThemeColors(ALThemeColors.lightColors);
  static final dark = _getStylesForThemeColors(ALThemeColors.darkColors);

  static ALThemeTextStyles _getStylesForThemeColors(ALThemeColors colors) {
    return ALThemeTextStyles._(
      headlineLarge: _getStyle(30, 32, FontWeight.bold, colors.dark),
      headline: _getStyle(26, 27, FontWeight.bold, colors.dark),
      headlineSmallHeavy: _getStyle(21, 18, FontWeight.w800, colors.dark),
      headlineSmallBold: _getStyle(21, 24, FontWeight.bold, colors.dark),
      headlineSmallSemibold: _getStyle(21, 24, FontWeight.w600, colors.dark),
      titleLarge: _getStyle(18, 20, FontWeight.bold, colors.dark),
      title: _getStyle(16, 12, FontWeight.w300, colors.slateGrey),
      titleSmallBold: _getStyle(15, 16, FontWeight.bold, colors.dark),
      titleSmallMedium: _getStyle(15, 16, FontWeight.w500, colors.dark),
      titleSmallRegular: _getStyle(15, 16, FontWeight.normal, colors.slateGrey, 0.2),
      bodyHeavy: _getStyle(15, 20, FontWeight.w800, colors.dark),
      bodyBold: _getStyle(15, 20, FontWeight.bold, colors.dark),
      bodySemibold: _getStyle(15, 20, FontWeight.w600, colors.dark),
      bodyMedium: _getStyle(15, 20, FontWeight.w500, colors.dark),
      bodyRegular: _getStyle(15, 20, FontWeight.normal, colors.slateGrey),
      bodySmallRegular: _getStyle(14, 16, FontWeight.normal, colors.slateGrey),
      bodySmallHeavy: _getStyle(14, 16, FontWeight.w800, colors.dark),
      bodySmallBold: _getStyle(14, 16, FontWeight.bold, colors.dark),
      bodySmallSemibold: _getStyle(14, 16, FontWeight.w600, colors.dark),
      bodySmallMedium: _getStyle(14, 16, FontWeight.w500, colors.slateGrey),
      bodySmallLight: _getStyle(14, 16, FontWeight.w300, colors.slateGrey),
      labelLargeSemibold: _getStyle(13, 14, FontWeight.w600, colors.dark),
      labelLargeMedium: _getStyle(14, 18, FontWeight.w500, colors.slateGrey),
      labelLargeRegular: _getStyle(13, 14, FontWeight.w400, colors.slateGrey),
      labelLargeLight: _getStyle(13, 14, FontWeight.w300, colors.slateGrey),
      labelBold: _getStyle(11, 16, FontWeight.w700, colors.dark),
      labelMedium: _getStyle(11, 16, FontWeight.w500, colors.slateGrey),
      labelRegular: _getStyle(11, 14, FontWeight.w400, colors.slateGrey, 0.4),
      labelLight: _getStyle(11, 16, FontWeight.w300, colors.slateGrey),
      pinKeyboard: _getStyle(27, 44, FontWeight.w400, Colors.black),
      pinTitle: _getStyle(34, 40, FontWeight.w700, colors.primary),
    );
  }

  TextTheme getTextTheme() => TextTheme(
    displayLarge: headlineLarge,
    displayMedium: headlineLarge,
    displaySmall: headlineLarge,
    headlineLarge: headlineLarge,
    headlineMedium: headline,
    headlineSmall: headlineSmallSemibold,
    titleLarge: titleLarge,
    titleMedium: title,
    titleSmall: titleSmallMedium,
    bodyLarge: bodySemibold,
    bodyMedium: bodyRegular,
    bodySmall: bodySmallRegular,
    labelLarge: labelLargeSemibold,
    labelMedium: labelBold,
    labelSmall: labelLight,
  );

  ALThemeTextStyles._({
    required this.headlineLarge,
    required this.headline,
    required this.headlineSmallHeavy,
    required this.headlineSmallBold,
    required this.headlineSmallSemibold,
    required this.titleLarge,
    required this.title,
    required this.titleSmallBold,
    required this.titleSmallMedium,
    required this.titleSmallRegular,
    required this.bodyHeavy,
    required this.bodyBold,
    required this.bodySemibold,
    required this.bodyMedium,
    required this.bodyRegular,
    required this.bodySmallRegular,
    required this.bodySmallHeavy,
    required this.bodySmallBold,
    required this.bodySmallSemibold,
    required this.bodySmallMedium,
    required this.bodySmallLight,
    required this.labelLargeSemibold,
    required this.labelLargeMedium,
    required this.labelLargeRegular,
    required this.labelLargeLight,
    required this.labelBold,
    required this.labelMedium,
    required this.labelRegular,
    required this.labelLight,
    required this.pinKeyboard,
    required this.pinTitle,
  });

  @override
  ThemeExtension<ALThemeTextStyles> copyWith() => this;

  @override
  ThemeExtension<ALThemeTextStyles> lerp(
    ThemeExtension<ALThemeTextStyles>? other,
    double t,
  ) {
    return other is! ALThemeTextStyles ? this : other;
  }

  /// Компактная обертка вокруг [_styledText].
  static TextStyle _getStyle(
    double fontSize,
    double lineHeight,
    FontWeight fontWeight,
    Color color, [
    double letterSpacing = 0,
  ]) {
    return _styledText(
      fontSize: fontSize,
      lineHeight: lineHeight,
      fontWeight: fontWeight,
      color: color,
      letterSpacing: 0,
    );
  }

  /// Строит стиль текста.
  ///
  /// Значения [lineHeight] и [letterSpacing] соответствуют тем, которые
  /// задаются в макетах Figma.
  static TextStyle _styledText({
    String? fontFamily,
    required double fontSize,
    required double? lineHeight,
    required Color color,
    double letterSpacing = 0,
    FontWeight fontWeight = FontWeight.w400,
    bool isUnderlined = false,
    TextLeadingDistribution leadingDistribution = TextLeadingDistribution.even,
  }) {
    final deviceFontWeight = _getAvailableWeight(fontWeight);
    final deviceLetterSpacing = _getDeviceLetterSpacing(
      letterSpacing,
      fontSize: fontSize,
      fontWeight: deviceFontWeight,
    );

    return TextStyle(
      fontFamily: fontFamily ?? _defaultFontFamily,
      fontSize: fontSize,
      fontWeight: deviceFontWeight,
      height: lineHeight != null ? lineHeight / fontSize : null,
      letterSpacing: deviceLetterSpacing,
      leadingDistribution: leadingDistribution,
      color: color,
      decorationColor: isUnderlined ? color : null,
      decorationStyle: isUnderlined ? TextDecorationStyle.solid : null,
      decoration: isUnderlined ? TextDecoration.underline : TextDecoration.none,
    );
  }

  static FontWeight _getAvailableWeight(FontWeight fontWeight) {
    if (Platform.isAndroid) {
      // На Android мы применяем шрифт Roboto, у которого нет начертаний
      // ExtraLight, SemiBold и Heavy. Недоступные начертания заменяются на
      // близкие по весу.
      switch (fontWeight) {
        case FontWeight.w800:
          return FontWeight.w900;
        case FontWeight.w600:
          return FontWeight.w500;
        case FontWeight.w200:
          return FontWeight.w100;
        default:
          return fontWeight;
      }
    } else {
      return fontWeight;
    }
  }

  static double _getDeviceLetterSpacing(
    double figmaLetterSpacing, {
    required double fontSize,
    required FontWeight? fontWeight,
  }) {
    if (Platform.isIOS) {
      // Устройства iOS используют немного более широко расставленную версию
      // шрифта SF Pro, чем применяемая в Figma. Поэтому в численном плане
      // отступ всегда немного уже, чем на макетах.

      return figmaLetterSpacing - fontSize * 0.05;
    } else {
      final spacingAdjustmentFactor =
          _getRobotoSpacingAdjustmentFactor(fontWeight ?? FontWeight.normal);

      // return letterSpacing;
      return figmaLetterSpacing - fontSize * spacingAdjustmentFactor * 0.005;
    }
  }

  /// Устройства Android используют шрифт Roboto, который характерен тем,
  /// что с ростом веса символов, они меньше растут в ширину. Чтобы надписи
  /// на двух платформах выглядели одинаково, набранные тонкими начертаниями
  /// строки верстаются чуть более плотно.
  static int _getRobotoSpacingAdjustmentFactor(FontWeight fontWeight) {
    switch (fontWeight) {
      case FontWeight.w900:
        return -4;

      case FontWeight.w700:
        return 0;

      case FontWeight.w500:
        return 2;

      case FontWeight.w400:
        return 3;

      case FontWeight.w300:
        return 4;

      case FontWeight.w100:
        return 6;

      default:
        assert(false, 'Неподдерживаемый вес шрифта: $fontWeight');
        return 0;
    }
  }
}
