import 'dart:async';

import 'package:altv/framework/timer/logic/network/server_time_request.dart';
import 'package:altv/framework/timer/logic/network/server_time_response.dart';
import 'package:altv/framework/formatters/al_date_formatter.dart';
import 'package:altv/framework/network/request_sender.dart';

class ServerTimerRepository {
  final RequestSender requestSender;

  final _eventsController = StreamController<DateTime>.broadcast();
  late final eventStream = _eventsController.stream;

  DateTime? _time;
  Timer? _timeUpdateTimer;

  ServerTimerRepository({
    required this.requestSender,
  });

  /// Возвращает текущее сохраненное серверное время.
  ///
  /// Если оно еще не было сохранено, то запрашивает его с сервера и создает
  /// таймер, инкрементирующий время раз в минуту.
  Future<DateTime> getCurrentTime({
    bool createNewTimer = false,
  }) async {
    if (_time != null) return _time!;

    final response = await requestSender.send(
      ServerTimeRequest(),
      ServerTimeResponse(),
    );

    _time = ALDateFormatter.fromString(
      response.serverTime,
      ALDateFormat.ymdhms,
    );

    if (createNewTimer) {
      _timeUpdateTimer?.cancel();
      _timeUpdateTimer = _startNewTimer();
    }

    return _time!;
  }

  Timer _startNewTimer() {
    return Timer.periodic(
      const Duration(seconds: 60),
      (_) {
        _time = _time!.add(const Duration(seconds: 60));
        _eventsController.add(_time!);
      },
    );
  }
}
