import 'package:flutter/material.dart';
import 'package:altv/framework/extensions/build_context_extension.dart';

class ALBottomPanel extends StatelessWidget {
  final double? height;
  final Color color;
  final List<BoxShadow>? boxShadow;
  final BorderSide? topBorder;
  final EdgeInsets padding;

  final Widget child;

  const ALBottomPanel.custom({
    super.key,
    required this.height,
    required this.color,
    this.boxShadow,
    required this.topBorder,
    required this.child,
    this.padding = EdgeInsets.zero,
  });

  /// Нижняя панель в стиле нижнего таббара, с заданной высотой.
  ALBottomPanel.bottomTabBar({
    super.key,
    required BuildContext context,
    required this.height,
    required this.child,
  })  : color = context.colors.whiteCard,
        boxShadow = context.shadows.cardShadows,
        topBorder = BorderSide(width: 1, color: context.colors.paleGrey),
        padding = EdgeInsets.zero;

  /// Нижняя панель в стиле универсальной кнопочной панели "Готово", "Завершить", "Поделиться"/"Продолжить" и т.п.
  ///
  /// Имеет заранее заданные отступы по краям. Высота панели определяется высотой [child]'а.
  ALBottomPanel.bottomPanel({
    super.key,
    required BuildContext context,
    required this.child,
  })  : height = null,
        color = context.colors.white,
        boxShadow = context.shadows.appBarShadows,
        topBorder = BorderSide(
          width: 1,
          color: context.colors.paleGrey.withOpacity(0.5),
        ),
        padding = const EdgeInsets.fromLTRB(16, 13, 16, 12);

  @override
  Widget build(BuildContext context) {
    final border = topBorder != null ? Border(top: topBorder!) : null;
    return Container(
      width: double.infinity,
      decoration: BoxDecoration(
        boxShadow: boxShadow,
        color: color,
        border: border,
      ),
      child: SafeArea(
        left: false,
        right: false,
        top: false,
        child: Container(
          margin: padding,
          height: height,
          child: child,
        ),
      ),
    );
  }
}
