import 'package:flutter/material.dart';
import 'package:altv/framework/extensions/build_context_extension.dart';
import 'package:altv/framework/types/al_device_type.dart';

typedef ALWidgetBuilder = Widget Function(BuildContext context);

/// Виджет, который поддерживает несколько билдеров, в зависимости от экрана,
/// на который выведено приложение.
/// Набор билдеров будет зависеть от макетов конкретного приложения
class ALDeviceDependentBuilder extends StatelessWidget {
  /// Флаг того, что этот виджет должен адаптировать свою верстку к типу
  /// устройства, на котором отображается.
  ///
  /// Если `false`, во всех случаях будет вызываться [phoneBuilder].
  final bool isDeviceDependentLayout;

  final ALWidgetBuilder phoneBuilder;
  final ALWidgetBuilder tabletBuilder;
  final ALWidgetBuilder? wideTabletBuilder;

  const ALDeviceDependentBuilder({
    super.key,
    this.isDeviceDependentLayout = true,
    required this.phoneBuilder,
    required this.tabletBuilder,
    this.wideTabletBuilder,
  });

  @override
  Widget build(BuildContext context) {
    final deviceType = isDeviceDependentLayout ? context.deviceType : ALDeviceType.phone;

    return deviceType
        .pickValue(
          phone: phoneBuilder,
          tablet: tabletBuilder,
          wideTablet: wideTabletBuilder,
        )
        .call(context);
  }
}
