import 'package:flutter/material.dart';

// Grid, высота строк которого не фиксирована и зависит от их содержимого
class ALGrid<T> extends StatelessWidget {
  final List<T> items;
  final Widget Function(T) itemBuilder;
  final int crossAxisCount;
  final double crossAxisSpacing;
  final double mainAxisSpacing;
  final EdgeInsets padding;

  const ALGrid({
    super.key,
    required this.items,
    required this.itemBuilder,
    required this.crossAxisCount,
    this.crossAxisSpacing = 10,
    this.mainAxisSpacing = 10,
    this.padding = EdgeInsets.zero
  });

  @override
  Widget build(BuildContext context) {
    return items.isEmpty ? const SizedBox.shrink() : SingleChildScrollView(
      padding: padding,
      child: _buildGrid(_getGridItems()),
    );
  }

  Widget _buildGrid(List<List<Widget>> items) {
    return Column(
      children: items.map((row) => Padding(
          padding: EdgeInsets.only(bottom: mainAxisSpacing),
        child: IntrinsicHeight(
          child: Row(
            children: row,
          ),
        ),
      )).toList(),
    );
  }

  List<List<Widget>> _getGridItems() {
    final List<List<Widget>> result = List.generate(
      (items.length / crossAxisCount).ceil(), (index) => []
    );
    for (int i = 0; i < items.length; i++) {
      result[i ~/ crossAxisCount].add(Flexible(child: itemBuilder(items[i])));
      if (result[i ~/ crossAxisCount].length != (crossAxisCount - 1) * 2 + 1) {
        result[i ~/ crossAxisCount].add(SizedBox(width: crossAxisSpacing));
      }
    }
    final itemsToAddCount = (crossAxisCount - 1) * 2 + 1 - result.last.length;
    if (itemsToAddCount != 0) {
      for (int i = 0; i < itemsToAddCount; i++) {
        result.last.add(const Flexible(child: SizedBox()));
      }
    }
    return result;
  }
}
