import 'package:flutter/material.dart';
import 'package:altv/framework/extensions/build_context_extension.dart';
import 'package:inner_drawer/inner_drawer.dart';

/// Добавляет выдвигающуюся боковую панель справа, используется в профиле.
/// Виджет боковой панели передается в [rightDrawer]. Компонент требует,
/// чтобы дочерним виджетом был Scaffold.
class ALRightDrawer extends StatefulWidget {
  final Scaffold scaffold;
  final Widget rightDrawer;

  const ALRightDrawer({
    super.key,
    required this.scaffold,
    required this.rightDrawer,
  });

  @override
  ALRightDrawerState createState() => ALRightDrawerState();
}

class ALRightDrawerState extends State<ALRightDrawer> {
  final _innerDrawerKey = GlobalKey<InnerDrawerState>();

  @override
  Widget build(BuildContext context) {
    return InnerDrawer(
      key: _innerDrawerKey,
      rightChild: _buildDrawer(context),
      colorTransitionChild: Colors.transparent,
      colorTransitionScaffold: Colors.transparent,
      onTapClose: true,
      rightAnimationType: InnerDrawerAnimation.linear,
      boxShadow: const [],
      offset: const IDOffset.horizontal(0.5),
      scaffold: widget.scaffold,
    );
  }

  Widget _buildDrawer(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        border: Border(
          left: BorderSide(width: 1, color: context.colors.paleGrey),
        ),
      ),
      child: widget.rightDrawer,
    );
  }

  void toggle() {
    _innerDrawerKey.currentState?.toggle();
  }
}
