import 'package:flutter/material.dart';
import 'package:altv/framework/extensions/build_context_extension.dart';

/// Кнопка, имитирующая гиперссылку
class ALHrefButton extends StatefulWidget {
  final String text;
  final VoidCallback onTap;
  final TextStyle? baseTextStyle;

  /// Цвет кнопки в обычном состоянии.
  ///
  /// Если `null`, используется цвет `dodgerBlue` текущей темы.
  final Color? regularColor;

  /// Цвет кнопки в нажатом состоянии.
  ///
  /// Если `null`, используется цвет `blue` текущей темы.
  final Color? pressedColor;

  const ALHrefButton({
    super.key,
    required this.text,
    this.baseTextStyle,
    required this.onTap,
    this.regularColor,
    this.pressedColor,
  });

  @override
  State<ALHrefButton> createState() => _ALHrefButtonState();
}

class _ALHrefButtonState extends State<ALHrefButton> {
  bool _isTapped = false;

  Color get _regularColor => widget.regularColor ?? context.colors.dodgerBlue;
  Color get _pressedColor => widget.pressedColor ?? context.colors.blue;

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTapDown: (details) => setState(() => _isTapped = true),
      onTapUp: (details) => setState(() => _isTapped = false),
      onTapCancel: () => setState(() => _isTapped = false),
      onTap: () => widget.onTap(),
      child: _buildLinkContent(
        _isTapped ? (_pressedColor) : (_regularColor),
      ),
    );
  }

  Widget _buildLinkContent(Color color) {
    return RichText(
      text: TextSpan(
        text: widget.text,
        style: (widget.baseTextStyle ?? context.textStyles.titleSmallMedium).copyWith(
          color: color,
          decoration: TextDecoration.underline,
          decorationStyle: TextDecorationStyle.solid,
        ),
      ),
    );
  }
}
