import 'package:equatable/equatable.dart';
import 'package:flutter/material.dart';
import 'package:altv/framework/extensions/build_context_extension.dart';
import 'package:altv/framework/theme/al_theme_colors.dart';

class ALChipsMultiSelectBarItem extends Equatable {
  final String title;
  final Color selectedColor;

  const ALChipsMultiSelectBarItem({
    required this.title,
    required this.selectedColor,
  });

  @override
  List<Object> get props => [title, selectedColor.value];
}

/// Панель для чипсов - фишек выбора, представляющих набор заданных вариантов
/// с множественным выбором
class ALChipsMultiSelectBar extends StatelessWidget {
  final List<ALChipsMultiSelectBarItem> items;
  final List<int> selectedIndexes;
  final Function(List<int> selected)? onSelectionChange;

  final Color backgroundColor;
  final Color defaultColor;
  final Color defaultTextColor;
  final Color selectedTextColor;
  final EdgeInsets padding;

  ALChipsMultiSelectBar({
    super.key,
    required BuildContext context,
    required this.items,
    required this.selectedIndexes,
    this.onSelectionChange,
    Color? backgroundColor,
    Color? defaultColor,
    Color? defaultTextColor,
    Color? selectedTextColor,
    this.padding = const EdgeInsets.only(top: 14.0, bottom: 5.0),
  })  : backgroundColor = backgroundColor ?? context.colors.white,
        defaultColor = defaultColor ?? context.colors.paleGrey,
        defaultTextColor = defaultTextColor ?? context.colors.slateGrey,
        selectedTextColor = selectedTextColor ?? ALThemeColors.lightColors.white;

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: padding,
      color: backgroundColor,
      alignment: Alignment.bottomLeft,
      child: SingleChildScrollView(
        physics: const ClampingScrollPhysics(),
        scrollDirection: Axis.horizontal,
        child: Padding(
          padding: const EdgeInsets.symmetric(horizontal: 17),
          child: Row(
            children: _tabsBuilder(context),
          ),
        ),
      ),
    );
  }

  List<Widget> _tabsBuilder(BuildContext context) {
    return Iterable<int>.generate(items.length)
        .map((index) => _buildItem(context, index))
        .toList();
  }

  Widget _buildItem(BuildContext context, int index) {
    return GestureDetector(
      onTap: () => _onTapItem(index),
      child: Padding(
        padding: const EdgeInsets.symmetric(horizontal: 3),
        child: ClipRRect(
          borderRadius: BorderRadius.circular(8),
          child: Container(
            alignment: Alignment.center,
            color: _getBackgroundColor(index),
            child: _chipsItem(context, index),
          ),
        ),
      ),
    );
  }

  Widget _chipsItem(BuildContext context, int index) {
    return Padding(
      padding: const EdgeInsets.only(left: 9, right: 9, bottom: 3),
      child: Text(
        items[index].title,
        style: context.textStyles.bodyMedium.copyWith(
          color: _getTextColor(index),
        ),
      ),
    );
  }

  Color _getTextColor(int index) {
    return selectedIndexes.contains(index)
        ? selectedTextColor
        : defaultTextColor;
  }

  Color _getBackgroundColor(int index) {
    return selectedIndexes.contains(index)
        ? items[index].selectedColor
        : defaultColor;
  }

  void _onTapItem(int index) {
    var selected = List<int>.from(selectedIndexes);
    if (selected.contains(index)) {
      selected.remove(index);
    } else {
      selected.add(index);
    }
    selected.sort();
    onSelectionChange?.call(selected);
  }
}
