import 'package:bloc/bloc.dart';
import 'package:flutter/foundation.dart';
import 'package:altv/framework/ui/widgets/network_image/network_image_no_cache/logic/bloc/al_network_image_no_cache_state.dart';
import 'package:altv/framework/ui/widgets/network_image/network_image_no_cache/logic/repositories/al_network_image_no_cache_repository.dart';

class ALNetworkImageNoCacheCubit extends Cubit<FRPJNetworkImageNoCacheState> {
  final ALNetworkImageNoCacheRepository repository;
  Uint8List? _imageBytes;

  ALNetworkImageNoCacheCubit({required this.repository})
      : super(const FRPJNetworkImageNoCacheInitial());

  Future<void> init(String url) async {
    if (_imageBytes != null && state.url == url) {
      emit(FRPJNetworkImageNoCacheLoaded(url: url, imageInfo: _imageBytes!));
    } else {
      await _loadData(url);
    }
  }

  Future<void> reload(String url) async {
    await _loadData(url);
  }

  Future<void> _loadData(String url) async {
    if (state is FRPJNetworkImageNoCacheLoading) return;
    emit(FRPJNetworkImageNoCacheLoading(url: url));
    _imageBytes = await repository.loadImage(url);
    emit(FRPJNetworkImageNoCacheLoaded(url: url, imageInfo: _imageBytes!));
  }

  onErrorHandled() {
    emit(FRPJNetworkImageNoCacheLoaded(url: state.url, imageInfo: null));
  }
}
