import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:altv/framework/ui/widgets/network_image/network_image_no_cache/logic/bloc/al_network_image_no_cache_cubit.dart';
import 'package:altv/framework/ui/widgets/network_image/network_image_no_cache/logic/bloc/al_network_image_no_cache_state.dart';

class ALNetworkImageNoCacheWidget extends StatefulWidget {
  final Widget Function(BuildContext context) placeholder;

  final Widget errorWidget;

  final Widget Function(BuildContext context, Uint8List imageInfo) imageBuilder;

  final String url;

  final bool isReloadRequired;
  final Function()? onReloadInvoked;

  const ALNetworkImageNoCacheWidget({
    super.key,
    required this.url,
    required this.placeholder,
    required this.errorWidget,
    required this.imageBuilder,
    this.isReloadRequired = false,
    this.onReloadInvoked,
  });

  @override
  State<StatefulWidget> createState() {
    return _FRPJNetworkImageNoCacheState();
  }
}

class _FRPJNetworkImageNoCacheState extends State<ALNetworkImageNoCacheWidget> {
  @override
  void initState() {
    super.initState();
    final cubit = context.read<ALNetworkImageNoCacheCubit>();
    if (widget.isReloadRequired) {
      cubit.reload(widget.url);
    } else {
      cubit.init(widget.url);
    }
  }

  @override
  Widget build(BuildContext context) {
    return BlocConsumer<ALNetworkImageNoCacheCubit, FRPJNetworkImageNoCacheState>(
      builder: _build,
      listener: _onStateChanged,
    );
  }

  Widget _build(BuildContext context, FRPJNetworkImageNoCacheState state) {
    if (widget.isReloadRequired) {
      this.context.read<ALNetworkImageNoCacheCubit>().reload(widget.url);
    }

    if (state is FRPJNetworkImageNoCacheInitial ||
        state is FRPJNetworkImageNoCacheLoading) {
      return widget.placeholder(context);
    } else if (state is FRPJNetworkImageNoCacheLoaded) {
      final imageInfo = state.imageInfo;
      if (imageInfo != null) {
        return widget.imageBuilder(context, imageInfo);
      } else {
        return widget.errorWidget;
      }
    }
    return Container();
  }

  _onStateChanged(BuildContext context, FRPJNetworkImageNoCacheState state) {
    if (state is FRPJNetworkImageNoCacheLoading) {
      widget.onReloadInvoked?.call();
    }
  }
}
