import 'package:flutter/material.dart';
import 'package:altv/framework/errors/error_handler/error_handler.dart';
import 'package:altv/framework/ui/widgets/paging/al_paging_list_view.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';

class ALPagingGridView extends StatelessWidget {
  final ALPagingListViewState state;
  final ErrorHandler errorHandler;
  final RefreshController controller;
  final ScrollController? scrollController;
  final Function() onLoad;
  final Function() onReload;
  final Function() onLoadingNextPage;
  final IndexedWidgetBuilder itemBuilder;
  final IndexedWidgetBuilder? separatorBuilder;
  final int itemCount;
  final int columns;
  final bool hasNextPage;
  final Widget Function() skeletonBuilder;
  final Widget Function() emptyListBuilder;
  final Exception? failureReason;
  final EdgeInsets? gridPadding;
  final EdgeInsets headerIndicatorMargin;
  final EdgeInsets footerIndicatorMargin;
  final bool shrinkWrap;
  final bool enablePullDown;
  final Widget? header;
  final Widget? footer;

  const ALPagingGridView({
    super.key,
    this.columns = 1,
    required this.state,
    required this.errorHandler,
    required this.controller,
    this.scrollController,
    required this.onLoad,
    required this.onReload,
    required this.onLoadingNextPage,
    required this.itemBuilder,
    required this.itemCount,
    required this.hasNextPage,
    required this.skeletonBuilder,
    required this.emptyListBuilder,
    required this.failureReason,
    this.separatorBuilder,
    this.gridPadding,
    this.headerIndicatorMargin = const EdgeInsets.only(top: 16.0),
    this.footerIndicatorMargin = const EdgeInsets.only(bottom: 24.0, top: 24.0),
    this.shrinkWrap = false,
    this.enablePullDown = true,
    this.header,
    this.footer,
  })  : assert(
          columns > 0,
          'ALPagingGridView должен иметь 1 или больше колонок',
        );

  @override
  Widget build(BuildContext context) {
    return ALPagingListView(
      state: state,
      errorHandler: errorHandler,
      controller: controller,
      scrollController: scrollController,
      onLoad: onLoad,
      onReload: onReload,
      onLoadingNextPage: onLoadingNextPage,
      itemBuilder: _buildListItem,
      itemCount: (itemCount / columns).ceil(),
      hasNextPage: hasNextPage,
      skeletonBuilder: skeletonBuilder,
      emptyListBuilder: emptyListBuilder,
      failureReason: failureReason,
      separatorBuilder: separatorBuilder,
      listPadding: gridPadding,
      headerIndicatorMargin: headerIndicatorMargin,
      footerIndicatorMargin: footerIndicatorMargin,
      shrinkWrap: shrinkWrap,
      enablePullDown: enablePullDown,
      header: header,
      footer: footer,
    );
  }

  Widget _buildListItem(BuildContext context, int rowIndex) {
    if (columns == 1) {
      return itemBuilder(context, rowIndex);
    }

    final rowElements = Iterable<int>.generate(columns).map((i) {
      final itemIndex = i + rowIndex * columns;

      return itemIndex < itemCount
          ? itemBuilder(context, itemIndex)
          : const SizedBox.shrink();
    });

    return IntrinsicHeight(
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        children: rowElements.map((e) => Expanded(child: e)).toList(),
      ),
    );
  }
}
