import 'package:altv/framework/extensions/iterable_extension.dart';
import 'package:flutter_inappwebview/flutter_inappwebview.dart';

class ALWebViewController {
  InAppWebViewController? _webViewController;

  set webViewController(InAppWebViewController controller) {
    _webViewController = controller;
  }

  Future<String?> getMetaTagContent({required String name}) async {
    final sel = 'meta[name="$name"]';

    final headResult = await _webViewController?.evaluateJavascript(
      source: "document.head.querySelector('$sel').getAttribute('content')",
    );
    if (headResult != null && headResult is String) {
      return headResult;
    }

    final documentResult = await _webViewController?.evaluateJavascript(
      source: "document.querySelector('$sel').getAttribute('content')",
    );
    if (documentResult != null && documentResult is String) {
      return documentResult;
    }

    return null;
  }

  Future<void> reload() async {
    await _webViewController?.reload();
  }

  Future<void> loadHtml(String html) async {
    await _webViewController?.loadData(data: html);
  }

  Future<void> loadUrl(Uri url) async {
    final request = URLRequest(url: WebUri.uri(url));
    await _webViewController?.loadUrl(urlRequest: request);
  }

  /// Если [url] есть в истории навигации - выполняется возврат к нему,
  /// при этом конечная страница будет в том же состоянии что до ухода с нее.
  /// Если [url] нет в истории - будет открыта новая страница
  Future<void> goBackToUrl(Uri url) async {
    final lastItem = await _getLastBackForwardListItem(url);
    if (lastItem != null) {
      await _webViewController?.goTo(historyItem: lastItem);
    } else {
      loadUrl(url);
    }
  }

  Future<WebHistoryItem?> _getLastBackForwardListItem(Uri url) async {
    final history = await _webViewController?.getCopyBackForwardList();
    final urlSegments = url.pathSegments;
    return history?.list?.lastOrNullWhere(
      (item) {
        if (item.url == null) {
          return false;
        }
        final itemSegments = item.url!.pathSegments;
        if (itemSegments.length < urlSegments.length) {
          return false;
        }
        for (var i = 0; i < urlSegments.length; i++) {
          if (itemSegments[i] != urlSegments[i]) {
            return false;
          }
        }
        return true;
      },
    );
  }
}
