import 'dart:async';

import 'package:altv/framework/storages/secure_storage.dart';
import 'package:altv/hearing_session/logic/repository/hearing_session_repository.dart';
import 'package:bloc/bloc.dart';
import 'package:equatable/equatable.dart';

part 'hearing_session_state.dart';

class HearingSessionCubit extends Cubit<HearingSessionState> {
  final HearingSessionRepository repository;

  late final StreamSubscription _eventsSubscription;

  HearingSessionCubit({
    required ISecureStorage secureStorage,
    required this.repository,
  }) : super(HearingSessionInitial(
          primaryCaseNumber: '',
          uuid: secureStorage.uuid!,
        ));

  void initialize() {
    _eventsSubscription =
        repository.eventStream.listen(_onHearingSessionObtained);
    repository.getCurrentSession();
    repository.listenForNewSessions();
  }

  _onHearingSessionObtained(String event) async {
    // Если началось новое дело
    if (event.isNotEmpty && state.primaryCaseNumber != event) {
      await _startNewSessionAlert(
        primaryCaseNumber: event,
        alertSeconds: 15,
      );

      emit(HearingSessionInitial(
        primaryCaseNumber: event,
        uuid: state.uuid,
      ));
    }
  }

  Future<void> _startNewSessionAlert({
    required String primaryCaseNumber,
    required int alertSeconds,
  }) async {
    emit(HearingSessionNewStarted(
      primaryCaseNumber: primaryCaseNumber,
      uuid: state.uuid,
      isSignalRed: true,
      isAudioNotification: true,
    ));

    await Future.delayed(const Duration(seconds: 1));

    for (int i = 0; i < alertSeconds - 1; i++) {
      emit(HearingSessionNewStarted(
        primaryCaseNumber: primaryCaseNumber,
        uuid: state.uuid,
        isSignalRed: !(state as HearingSessionNewStarted).isSignalRed,
        isAudioNotification: false,
      ));

      await Future.delayed(const Duration(seconds: 1));
    }
  }

  @override
  Future<void> close() {
    _eventsSubscription.cancel();
    repository.deactivateSocket();
    return super.close();
  }
}
