// ignore_for_file: public_member_api_docs, sort_constructors_first
import 'dart:async';

import 'package:altv/framework/network/request_sender.dart';
import 'package:altv/framework/res/al_contstants.dart';
import 'package:altv/framework/storages/secure_storage.dart';
import 'package:altv/hearing_session/logic/entities/hearing_session_info.dart';
import 'package:altv/hearing_session/logic/network/hearing_session_request.dart';
import 'package:altv/hearing_session/logic/network/hearing_session_response.dart';
import 'package:flutter/foundation.dart';
import 'package:stomp_dart_client/stomp_dart_client.dart';

class HearingSessionRepository {
  final ISecureStorage secureStorage;
  final RequestSender requestSender;

  final _eventsController = StreamController<String>.broadcast();
  late final eventStream = _eventsController.stream;

  StompClient? _stompClient;

  HearingSessionRepository({
    required this.secureStorage,
    required this.requestSender,
  });

  /// Возвращает номер текущего дела в [eventStream] репозитория
  Future<void> getCurrentSession() async {
    final uuid = secureStorage.uuid!;

    try {
      final response = await requestSender.send(
        HearingSessionRequest(uuid: uuid),
        HearingSessionResponse(),
      );

      if (response.primaryCaseNumber != null) {
        _eventsController.add(response.primaryCaseNumber!);
      }
    } on Exception catch (_) {
      // TODO вставить обработку ошибок
    }
  }

  Future<void> listenForNewSessions() async {
    _stompClient = StompClient(
      config: StompConfig(
        url: ALConstants.serverSocketAddressDev,
        onConnect: _onSocketConnect,
      ),
    );

    _stompClient?.activate();
  }

  void _onSocketConnect(StompFrame sf) {
    debugPrint('Connected to socket ${ALConstants.serverSocketAddressDev}');
    debugPrint('Socket connect message: ${sf.body}');

    final uuid = secureStorage.uuid!;

    _stompClient?.subscribe(
      destination: '/topic/small-tv',
      callback: (frame) => _filterData(uuid, frame.body),
    );
  }

  void _filterData(String uuid, String? data) {
    debugPrint('Socket subcribe message: $data');

    final session = HearingSessionInfo.fromJsonString(data);
    if (session?.deviceId == uuid) {
      _eventsController.add(session!.primaryCaseNumber);
    }
  }

  void deactivateSocket() {
    _stompClient?.deactivate();
  }
}
