import 'package:altv/framework/utils/sound_player.dart';
import 'package:altv/hearing_session/logic/bloc/hearing_session_cubit.dart';
import 'package:altv/hearing_session/logic/formatters/hearing_session_formatter.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

class HearingSessionPage extends StatefulWidget {
  final PreferredSizeWidget Function({
    required BuildContext context,
    Widget? title,
    List<Widget>? actions,
  }) onGetAppBar;

  const HearingSessionPage({
    super.key,
    required this.onGetAppBar,
  });

  @override
  State<HearingSessionPage> createState() => _HearingSessionPageState();
}

class _HearingSessionPageState extends State<HearingSessionPage> {
  HearingSessionCubit get _cubit => context.read<HearingSessionCubit>();

  @override
  void initState() {
    _cubit.initialize();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return BlocConsumer<HearingSessionCubit, HearingSessionState>(
        builder: _buildCurrentState, listener: _onStateChanged);
  }

  void _onStateChanged(BuildContext context, HearingSessionState state) {
    if (state is HearingSessionNewStarted) {
      if (state.isAudioNotification) {
        SoundPlayer.playHearingStartSound();
      }
    }
  }

  Widget _buildCurrentState(BuildContext context, HearingSessionState state) {
    final formatter = HearingSessionFormatter(state: state);

    return Scaffold(
      appBar: widget.onGetAppBar(
        context: context,
        title: Text(
          'UUID ${state.uuid}',
          style: const TextStyle(
            color: Colors.white,
          ),
        ),
      ),
      body: _buildContent(state, formatter),
      backgroundColor: formatter.backgroundColor,
    );
  }

  Widget _buildContent(
    HearingSessionState state,
    HearingSessionFormatter formatter,
  ) {
    if (state.primaryCaseNumber.isNotEmpty) {
      return _getSessionTextInfo(state, formatter);
    } else {
      return const SizedBox.shrink();
    }
  }

  Widget _getSessionTextInfo(
    HearingSessionState state,
    HearingSessionFormatter formatter,
  ) {
    return Center(
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          Text(
            formatter.headerText,
            style: TextStyle(
              fontSize: 28.0,
              color: formatter.headerTextColor,
              fontWeight: FontWeight.w500,
            ),
          ),
          const SizedBox(height: 20.0),
          Text(
            formatter.middleText,
            style: TextStyle(
              fontSize: 24.0,
              color: formatter.middleTextColor,
              fontWeight: FontWeight.w500,
            ),
          ),
          Text(
            formatter.state.primaryCaseNumber,
            style: TextStyle(
              fontSize: 24.0,
              color: Colors.blue[900],
              fontWeight: FontWeight.bold,
            ),
          ),
        ],
      ),
    );
  }
}
