import 'dart:io';
import 'package:altv/activation/activation_dependencies.dart';
import 'package:altv/activation/logic/repository/activation_repository.dart';
import 'package:altv/framework/di/di_assembly.dart';
import 'package:altv/framework/di/di_container.dart';
import 'package:altv/framework/di/di_keys.dart';
import 'package:altv/framework/environment/environment.dart';
import 'package:altv/framework/framework_dependencies.dart';
import 'package:altv/framework/network/request_sender.dart';
import 'package:altv/framework/storages/preferences_storage.dart';
import 'package:altv/framework/storages/secure_storage.dart';
import 'package:altv/framework/timer/logic/repositories/server_timer_repository.dart';
import 'package:altv/launcher/launcher_dependencies.dart';
import 'package:altv/launcher/logic/bloc/launcher_cubit.dart';
import 'package:altv/launcher/logic/repositories/launcher_repository.dart';
import 'package:altv/launcher/logic/stages/launcher_check_device_activation_stage.dart';
import 'package:altv/launcher/logic/stages/launcher_check_uuid_stage.dart';
import 'package:altv/launcher/logic/stages/launcher_get_server_time_stage.dart';
import 'package:altv/launcher/logic/stages/launcher_init_storages_stage.dart';
import 'package:altv/launcher/logic/stages/launcher_logout_stage.dart';

class LauncherAssembly extends DIAssembly {
  @override
  void assembly(DIContainer container) {
    container.registerSingleton(
      (container) => LauncherRepository(
        requestSender: container.resolve<RequestSender>(),
      ),
    );
    container.registerSingleton(
      (container) => LauncherInitStoragesStage(
        isIOS: Platform.isIOS,
        preferencesStorage: container.resolve<IPreferencesStorage>(),
        secureStorage: container.resolve<ISecureStorage>(),
        environment: container.resolve<Environment>(),
      ),
    );
    container.registerSingleton(
      (container) => LauncherLogoutStage(
        secureStorage: container.resolve<ISecureStorage>(),
        preferencesStorage: container.resolve<IPreferencesStorage>(),
      ),
    );
    container.registerFactory(
      (container) => LauncherGetServerTimeStage(
          repository: container.resolve<ServerTimerRepository>()),
    );
    container.registerFactory(
      (container) => LauncherCheckUuidStage(
          secureStorage: container.resolve<ISecureStorage>(),
          repository: container.resolve<LauncherRepository>()),
    );
    container.registerFactory(
      (container) => LauncherCheckDeviceActivationStage(
        secureStorage: container.resolve<ISecureStorage>(),
        repository: container.resolve<ActivationRepository>(),
      ),
    );
    container.registerSingleton(
      (container) => LauncherCubit(
        initStoragesStage: container.resolve<LauncherInitStoragesStage>(),
        getServerTimeStage: container.resolve<LauncherGetServerTimeStage>(),
        logoutStage: container.resolve<LauncherLogoutStage>(),
        checkUuidAssignedStage: container.resolve<LauncherCheckUuidStage>(),
        checkDeviceActivationStage:
            container.resolve<LauncherCheckDeviceActivationStage>(),
      ),
    );
    container.registerFactory<IFrameworkErrorHandlerLogoutCaller>(
      (container) => container.resolve<LauncherCubit>(),
    );

    container.registerFactory<ILauncherUserLogoutCaller>(
      (container) => container.resolve<LauncherCubit>(),
    );

    container.registerFactory<IActivationCompletionDelegate>(
      (container) => container.resolve<LauncherCubit>(),
    );
    container.registerFactory<Stream>(
      (container) => container.resolve<LauncherCubit>().logoutStream,
      name: DIKeys.logoutStream,
    );
  }
}
