import 'dart:async';

import 'package:altv/activation/activation_dependencies.dart';
import 'package:altv/launcher/logic/stages/launcher_check_device_activation_stage.dart';
import 'package:altv/launcher/logic/stages/launcher_check_uuid_stage.dart';
import 'package:altv/launcher/logic/stages/launcher_get_server_time_stage.dart';
import 'package:altv/launcher/logic/stages/launcher_init_storages_stage.dart';
import 'package:altv/launcher/logic/stages/launcher_logout_stage.dart';
import 'package:bloc/bloc.dart';
import 'package:equatable/equatable.dart';
import 'package:flutter/widgets.dart';
import 'package:altv/framework/framework_dependencies.dart';
import 'package:altv/launcher/launcher_dependencies.dart';

part 'launcher_state.dart';

class LauncherCubit extends Cubit<LauncherState>
    implements
        IFrameworkErrorHandlerLogoutCaller,
        ILauncherUserLogoutCaller,
        IActivationCompletionDelegate {
  final LauncherInitStoragesStage initStoragesStage;
  final LauncherLogoutStage logoutStage;
  final LauncherGetServerTimeStage getServerTimeStage;
  final LauncherCheckUuidStage checkUuidAssignedStage;
  final LauncherCheckDeviceActivationStage checkDeviceActivationStage;

  final _logoutStreamController = StreamController();
  late final Stream logoutStream =
      _logoutStreamController.stream.asBroadcastStream();

  LauncherCubit({
    required this.initStoragesStage,
    required this.logoutStage,
    required this.getServerTimeStage,
    required this.checkUuidAssignedStage,
    required this.checkDeviceActivationStage,
  }) : super(LauncherInitial());

  Future<void> notifyAppStarted() async {
    await initStoragesStage();

    // Получение текущего времени с сервера
    await getServerTimeStage();

    // Проверка присвоения устройству UUID
    await checkUuidAssignedStage();

    // Проверка привязанного зала
    final isActivated = await checkDeviceActivationStage();
    if (isActivated) {
      notifyActivationCompletion();
    } else {
      emit(LauncherActivationInitial());
    }
  }

  Future<void> logIn() async {
    await _startBackgroundServices();
  }

  Future<void> logOut() async {
    _stopBackgroundServices();
    await logoutStage();
    _logoutStreamController.add(null);
  }

  Future<void> _startBackgroundServices() async {
    // Пока не требуется
  }

  Future<void> _stopBackgroundServices() async {
    // Пока не требуется
  }

  // IFrameworkErrorHandlerLogoutCaller
  @override
  Future<void> errorHandlerLogOut() async {
    logOut();
  }

  // ILauncherUserLogoutCaller
  @override
  void userLogout() {
    logOut();
  }

  // IActivationCompletionDelegate
  @override
  void notifyActivationCompletion() {
    emit(LauncherSessionInitial());
  }
}
