import 'package:altv/framework/environment/environment.dart';
import 'package:altv/framework/storages/preferences_storage.dart';
import 'package:altv/framework/storages/secure_storage.dart';

class LauncherInitStoragesStage {
  final bool isIOS;
  final ISecureStorage secureStorage;
  final IPreferencesStorage preferencesStorage;
  final Environment environment;

  LauncherInitStoragesStage({
    required this.isIOS,
    required this.secureStorage,
    required this.preferencesStorage,
    required this.environment,
  });

  Future<void> call() async {
    try {
      await secureStorage.load();
    } on Error {
      await secureStorage.clear(fully: true);
      await secureStorage.load();
    }

    try {
      await preferencesStorage.load();
    } on Error {
      await preferencesStorage.clear(fully: true);
      await preferencesStorage.load();
    }

    if (preferencesStorage.appWasLaunched != true) {
      // На iOS очищаем защищенное хранилище после переустановки приложения
      if (isIOS) {
        await secureStorage.clear();
      }
      preferencesStorage.appWasLaunched = true;
      await preferencesStorage.save();
    }

    // Если смена контура недоступна или контур еще не выбран,
    // нужно прописать дефолтный контур для текущего типа сборки.
    // Нативный раннер будет опираться на выбранный контур при отправке запросов,
    // так что лучше перестраховаться на случай установки продуктовой сборки
    // поверх тестовой.
    if (!environment.isDeveloperToolsAvailable ||
        preferencesStorage.serverRoute == null) {
      preferencesStorage.serverRoute = environment.defaultServerRoute;
      await preferencesStorage.save();
    }
  }
}
