import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:altv/launcher/logic/bloc/launcher_cubit.dart';

class LauncherPage extends StatefulWidget {
  final Widget Function() onGetActivationPage;
  final Widget Function() onGetHearingSessionPage;

  const LauncherPage({
    super.key,
    required this.onGetActivationPage,
    required this.onGetHearingSessionPage,
  });

  @override
  State<StatefulWidget> createState() => _LauncherPageState();
}

class _LauncherPageState extends State<LauncherPage> {
  final _activationRequiredKey = GlobalKey<NavigatorState>();
  final _hearingSessionKey = GlobalKey<NavigatorState>();

  GlobalKey<NavigatorState>? _currentStateKey;

  LauncherCubit get _cubit => context.read<LauncherCubit>();

  @override
  void initState() {
    super.initState();
    _cubit.notifyAppStarted();
  }

  @override
  Widget build(BuildContext context) {
    return _buildBackButtonHandler(
      context: context,
      child: BlocBuilder<LauncherCubit, LauncherState>(
        builder: (context, state) {
          switch (state) {
            case LauncherInitial():
              return Container(color: Colors.blue);
            case LauncherActivationInitial():
              return _buildActivationPage();
            case LauncherSessionInitial():
              return _buildHearingSessionPage();
          }
        },
      ),
    );
  }

  Widget _buildBackButtonHandler({
    required BuildContext context,
    required Widget child,
  }) {
    // На iOS кнопки назад нет, возвращаем сам виджет
    if (Platform.isIOS) {
      return child;
    }
    return PopScope(
      canPop: false,
      onPopInvoked: (didPop) async {
        final didPopResult =
            await _currentStateKey?.currentState?.maybePop() ?? false;
        // Если вернулся true - возврат произошел или был запрещен PopScope внутри виджета.
        // Если false - это возврат из корневого виджета, надо закрывать приложение.
        if (!didPopResult) {
          SystemNavigator.pop();
        }
      },
      child: child,
    );
  }

  Widget _buildActivationPage() {
    return _buildNavigatorStack(
      _activationRequiredKey,
      (context) => widget.onGetActivationPage(),
    );
  }

  Widget _buildHearingSessionPage() {
    return _buildNavigatorStack(
      _hearingSessionKey,
      (context) => widget.onGetHearingSessionPage(),
    );
  }

  Widget _buildNavigatorStack(
    GlobalKey<NavigatorState> key,
    WidgetBuilder widgetBuilder,
  ) {
    _currentStateKey = key;
    return Navigator(
      key: key,
      onGenerateRoute: (settings) {
        return MaterialPageRoute(builder: widgetBuilder, settings: settings);
      },
    );
  }
}
