import 'package:altv/activation/activation_assembly.dart';
import 'package:altv/activation/ui/activation_coordinator.dart';
import 'package:altv/appbar/appbar_assembly.dart';
import 'package:altv/appbar/ui/appbar_coordinator.dart';
import 'package:altv/hearing_session/hearing_session_assembly.dart';
import 'package:altv/hearing_session/ui/hearing_session_coordinator.dart';
import 'package:altv/launcher/ui/launcher_coordinator.dart';
import 'package:altv/main_coordinator.dart';
import 'package:appmetrica_plugin/appmetrica_plugin.dart';
import 'package:flutter/material.dart';
import 'package:altv/debug_settings/debug_settings_assembly.dart';
import 'package:altv/debug_settings/ui/debug_settings_coordinator.dart';
import 'package:altv/framework/di/di_container.dart';
import 'package:altv/framework/environment/build_type.dart';
import 'package:altv/framework/framework_assembly.dart';
import 'package:altv/framework/log/crash_logger.dart';
import 'package:altv/framework/log/log.dart';
import 'package:altv/framework/res/al_contstants.dart';
import 'package:altv/framework/theme/al_theme.dart';
import 'package:altv/launcher/launcher_assembly.dart';

final diContainer = DIContainer();

final mainCoordinator = MainCoordinator(
  diContainer: diContainer,
  onShowDebugSettings: settingsCoordinator.showDebugSettings,
);

final appBarCoordinator = AppBarCoordinator(
  diContainer: diContainer,
);

final activationCoordinator = ActivationCoordinator(
  diContainer: diContainer,
  onGetAppBar: appBarCoordinator.getAppBar,
);

final hearingSessionCoordinator = HearingSessionCoordinator(
  diContainer: diContainer,
  onGetAppBar: appBarCoordinator.getAppBar,
);

final launcherCoordinator = LauncherCoordinator(
  diContainer: diContainer,
  onGetActivationPage: activationCoordinator.getIdentificationPage,
  onGetHearingSessionPage: hearingSessionCoordinator.getHearingSessionPage,
);

final settingsCoordinator = DebugSettingsCoordinator(
  diContainer: diContainer,
);

void main() {
  _mainForBuildType(BuildType.store);
}

@pragma('vm:entry-point')
void mainInternal() {
  _mainForBuildType(BuildType.internal);
}

@pragma('vm:entry-point')
void mainStore() {
  _mainForBuildType(BuildType.store);
}

void _mainForBuildType([BuildType buildType = BuildType.store]) async {
  WidgetsFlutterBinding.ensureInitialized();

  _registerAssemblies(buildType: buildType);
  await AppMetrica.activate(
      const AppMetricaConfig(ALConstants.yandexAppMetricaApiKey));

  final crashLogger = diContainer.resolve<CrashLogger>();
  Log.configure(
    isLogEnabled: true,
    crashLogger: crashLogger,
  );

  FlutterError.onError = (details) {
    debugPrint(details.toString());
    final yaError = AppMetricaErrorDescription.fromFlutterErrorDetails(details);
    AppMetrica.reportUnhandledException(yaError);
  };

  runApp(const MyApp());
}

void _registerAssemblies({required BuildType buildType}) {
  diContainer.registerAssemblies([
    FrameworkAssembly(buildType: buildType),
    AppBarAssembly(),
    LauncherAssembly(),
    ActivationAssembly(),
    HearingSessionAssembly(),
    DebugSettingsAssembly(),
  ]);
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ALTheme.light,
      home: launcherCoordinator.getLauncherPage(),
    );
  }
}
