import 'package:flutter/material.dart';
import 'package:altv/framework/analytics/analytics_event.dart';
import 'package:altv/framework/analytics/analytics_sender.dart';
import 'package:altv/framework/di/di_container.dart';
import 'package:altv/framework/extensions/build_context_extension.dart';
import 'package:altv/framework/log/log.dart';
import 'package:altv/framework/ui/navigation/navigation_coordinator.dart';
import 'package:altv/framework/ui/widgets/buttons/al_button.dart';
import 'package:altv/framework/ui/widgets/al_app_bar.dart';

class MainCoordinator extends NavigationCoordinator {
  final DIContainer diContainer;

  final Function({required BuildContext context}) onShowDebugSettings;

  MainCoordinator({
    required this.diContainer,
    required this.onShowDebugSettings,
  });

  Widget getDebugPage() {
    return MyHomePage(
      analyticsSender: diContainer.resolve<AnalyticsSender>(),
      onShowDebugSettings: onShowDebugSettings,
    );
  }
}

class MyHomePage extends StatelessWidget {
  final AnalyticsSender analyticsSender;
  final Function({required BuildContext context}) onShowDebugSettings;

  const MyHomePage({
    super.key,
    required this.analyticsSender,
    required this.onShowDebugSettings,
  });

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: ALAppBar(
        backgroundColor: context.colors.primary,
        titleText: 'AL',
      ),
      body: Padding(
        padding: const EdgeInsets.all(16),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.stretch,
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            ALButton(
              onPressed: () =>
                  analyticsSender.send(AnalyticsEvents.analyticsTest),
              text: 'Тест аналитики',
            ),
            const SizedBox(height: 10),
            ALButton(
              onPressed: () => Log.crashException(
                Exception('Test exception'),
                stack: StackTrace.current,
                message: 'Test crash message',
              ),
              text: 'Тест краш',
            ),
            const SizedBox(height: 10),
            ALButton(
              onPressed: () => onShowDebugSettings(context: context),
              text: 'Настройки',
            ),
          ],
        ),
      ),
    );
  }
}
