import 'package:flutter/material.dart';
import 'package:altv/framework/res/images/al_image_asset.dart';
import 'package:altv/framework/theme/al_theme.dart';
import 'package:altv/framework/extensions/build_context_extension.dart';
import 'package:altv/framework/ui/widgets/al_app_bar.dart';
import 'package:altv/framework/ui/widgets/buttons/al_back_button.dart';
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:widgets_demo/pages.dart';

void main() {
  ALImageAsset.enableModuleImport = true;
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      locale: const Locale("ru", "RU"),
      supportedLocales: const [Locale("ru", "RU")],
      localizationsDelegates: const [
        GlobalCupertinoLocalizations.delegate,
        GlobalMaterialLocalizations.delegate,
        GlobalWidgetsLocalizations.delegate,
      ],
      debugShowCheckedModeBanner: false,
      title: "Widgets Demo",
      theme: ALTheme.light,
      darkTheme: ALTheme.dark,
      home: const WidgetPages(),
    );
  }
}

class WidgetPages extends StatelessWidget {
  const WidgetPages({super.key});

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: ALAppBar(
        titleText: "Виджеты",
        titleTextStyle: context.textStyles.headline,
      ),
      body: _getRootWidget(),
    );
  }

  Widget _getRootWidget() {
    return ListView.builder(
      itemCount: pages.length,
      itemBuilder: (context, index) {
        final page = pages[index];
        return ListTile(
          title: Text(page.title),
          onTap: () => _showWidgetPage(context, page),
        );
      },
    );
  }

  _showWidgetPage(BuildContext context, PageWidget page) {
    Navigator.of(context).push(
      MaterialPageRoute(builder: (context) {
        return Scaffold(
          appBar: page.hasAppBar
              ? ALAppBar(
                titleText: page.title,
                leading: ALBackButton(
                  onPressed: () => Navigator.of(context).pop(),
                ),
              )
              : null,
          body: page.child,
        );
      }),
    );
  }
}
