import 'package:flutter/material.dart';
import 'package:altv/framework/res/images/al_images.dart';
import 'package:altv/framework/ui/widgets/input/al_input_text.dart';
import 'package:altv/framework/ui/widgets/input/al_keyboard_actions.dart';

class InputTextPage extends StatefulWidget {
  const InputTextPage({super.key});

  @override
  State<InputTextPage> createState() => _InputTextPageState();
}

class _InputTextPageState extends State<InputTextPage> {
  // Константы
  final _activeCitizenMessage = "Активный гражданин";
  final _titleMessage = "Обычное текстовое поле";
  final _titleMessage2 = "Текстовое поле с ошибкой";
  final _titleMessage3 = "Текстовое поле с ошибкой и иконками";
  final _titleMessage4 = "Многострочное поле";
  final _enterMessageHint = "Введите текст";
  final _errorMessage = "Такого email не существует";

  // Текстовое поле ввода 1
  final _text1FocusNode = FocusNode();
  final _text1Controller = TextEditingController();

  // Текстовое поле ввода 2
  var _text1ErrorMessage = "";
  final _text2FocusNode = FocusNode();
  final _text2Controller = TextEditingController();

  // Текстовое поле ввода 3
  var _text2ErrorMessage = "";
  final _text3FocusNode = FocusNode();
  final _text3Controller = TextEditingController();

  // Текстовое поле ввода 4
  final _text4FocusNode = FocusNode();
  final _text4Controller = TextEditingController();

  @override
  void dispose() {
    _text1FocusNode.dispose();
    _text2FocusNode.dispose();
    _text3FocusNode.dispose();
    _text4FocusNode.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    List<Widget> inputs = _buildInputs(context);

    // Обёртка [ALKeyboardActions] позволяет реагировать на появление клавиатуры и
    // назначения действий переходов и скрытия клавиатуры. Вместо нее можно
    // использовать [ALKeyboardDoneAction], которая еще добавляет кнопку "Готово"
    // над клавиатурой (ListView передавать в scrollView вместо child)
    return ALKeyboardActions(
      // Указываем список фокусов, между которыми нужно выполнять переходы
      focusNodes: [
        _text1FocusNode,
        _text2FocusNode,
        _text3FocusNode,
        _text4FocusNode,
      ],
      child: ListView(
        padding: const EdgeInsets.all(10),
        children: inputs.map((w) => _buildListItem(w)).toList(),
      ),
    );
  }

  List<Widget> _buildInputs(BuildContext context) {
    return [
      _buildInputText1(),
      _buildInputText2(),
      _buildInputText3(),
      _buildInputText4(),
    ];
  }

  Widget _buildListItem(Widget w) {
    return Padding(
      padding: const EdgeInsets.only(bottom: 10),
      child: w,
    );
  }

  ALInputText _buildInputText1() {
    return ALInputText(
      hintText: _enterMessageHint,
      title: _titleMessage,
      focusNode: _text1FocusNode,
      controller: _text1Controller,
    );
  }

  ALInputText _buildInputText2() {
    _text2Controller.addListener(() {
      setState(() {
        _text1ErrorMessage = _text2Controller.text.isNotEmpty
            ? "Вы ввели '${_text2Controller.text}' "
            : "";
      });
    });

    return ALInputText(
      hintText: _enterMessageHint,
      title: _titleMessage2,
      errorText: _text1ErrorMessage,
      focusNode: _text2FocusNode,
      controller: _text2Controller,
    );
  }

  ALInputText _buildInputText3() {
    _text3Controller.addListener(() {
      setState(() {
        _text2ErrorMessage =
            _text3Controller.text.isNotEmpty ? _errorMessage : "";
      });
    });

    return ALInputText(
      hintText: _enterMessageHint,
      title: _titleMessage3,
      errorText: _text2ErrorMessage,
      leftWidget: ALImages.iconSearch.buildWidget(context),
      rightWidget: ALImages.iconClose.buildWidget(context),
      leftWidgetWidth: 16,
      rightWidgetWidth: 16,
      onClickLeftWidget: () {
        setState(() {
          _text3Controller.text = _activeCitizenMessage;
          _text2ErrorMessage =
              _text3Controller.text.isNotEmpty ? _errorMessage : "";
        });
      },
      onClickRightWidget: () {
        String text = _text1Controller.text;
        _text1Controller.text = "";
        ScaffoldMessenger.of(context).showSnackBar(
          SnackBar(content: Text("Вы удалили текст $text")),
        );
      },
      focusNode: _text3FocusNode,
      controller: _text3Controller,
    );
  }

  ALInputText _buildInputText4() {
    _text4Controller.addListener(() {
      setState(() {});
    });
    return ALInputText(
      hintText: _enterMessageHint,
      title: _titleMessage4,
      focusNode: _text4FocusNode,
      controller: _text4Controller,
      inputType: TextInputType.multiline,
      maxLength: 500,
      maxLines: 10,
      minLines: 1,
    );
  }
}
