import 'package:flutter/material.dart';
import 'package:altv/framework/ui/widgets/buttons/al_button.dart';
import 'package:altv/framework/ui/widgets/popup/al_modal_popup.dart';
import 'package:altv/framework/ui/widgets/popup/al_alert_popup.dart';

class PopupPage extends StatelessWidget {
  const PopupPage({super.key});

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: Padding(
        padding: const EdgeInsets.all(16),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.stretch,
          children: [
            ALButton(
              text: 'Список 4',
              onPressed: () {
                _showList4(context);
              },
            ),
            const SizedBox(height: 10),
            ALButton(
              text: 'Список 10',
              onPressed: () {
                _showList10(context);
              },
            ),
            const SizedBox(height: 10),
            ALButton(
              text: 'Список 20',
              onPressed: () {
                _showList20(context);
              },
            ),
            const SizedBox(height: 10),
            ALButton(
              text: 'По высоте контента',
              onPressed: () {
                _showSelfSizedPopup(context);
              },
            ),
            const SizedBox(height: 10),
            ALButton(
              text: 'Список 20, нельзя закрыть жестом',
              onPressed: () {
                _showList20DisabledDrag(context);
              },
            ),
            const SizedBox(height: 10),
            ALButton(
              text: 'Пример диалога',
              onPressed: () {
                _showAlertPopup(context);
              },
            ),
          ],
        ),
      ),
    );
  }

  _showList4(BuildContext context) {
    showALModalPopup(
      context: context,
      bottomOffset: 0,
      body: _buildList(context, 4),
      isScrollingEnabled: true,
    );
  }

  _showList10(BuildContext context) {
    showALModalPopup(
      context: context,
      bottomOffset: 0,
      body: _buildList(context, 10),
      isScrollingEnabled: true,
    );
  }

  _showList20(BuildContext context) {
    showALModalPopup(
      context: context,
      bottomOffset: 0,
      body: _buildList(context, 20),
      isScrollingEnabled: true,
    );
  }

  _showList20DisabledDrag(BuildContext context) {
    showALModalPopup(
        context: context,
        bottomOffset: 0,
        body: _buildList(context, 20),
        isScrollingEnabled: true,
        enableDrag: false
    );
  }

  _showSelfSizedPopup(BuildContext context) {
    showALModalPopup(
      context: context,
      bottomOffset: 0,
      body: Container(height: 100, color: Colors.redAccent,),
    );
  }

  _buildList(BuildContext context, int itemCount) {
    return ListView.builder(
      padding: EdgeInsets.zero,
      shrinkWrap: true,
      physics: const NeverScrollableScrollPhysics(),
      itemCount: itemCount,
      itemBuilder: (context, i) =>
          ListTile(
            title: Text('Item $i'),
          ),
    );
  }

  _showAlertPopup(BuildContext context) {
    showALAlertPopup(
      context: context,
      title: "Адрес регистрации не совпадает с адресом регистрации",
      text:
      """Адрес регистрации не совпадает с адресом регистрации, указанным в Едином Личном кабинете mos.ru

Нажмите «Обновить», чтобы использовать адрес, указанный на mos.ru или «Редактировать» для изменения адреса в Едином Личном кабинете mos.ru""",
      buttons: [
        ALAlertPopupButton(
          buttonType: ALButtonType.tonal,
          text: "Редактировать",
          // ignore: avoid_print
          onPressed: () => print("Редактировать"),
        ),
        ALAlertPopupButton(
          buttonType: ALButtonType.filled,
          text: "Обновить",
          // ignore: avoid_print
          onPressed: () => print("Обновить"),
        )
      ],
    );
  }
}
