import 'package:flutter/material.dart';
import 'package:altv/framework/ui/widgets/al_radio.dart';
import 'package:altv/framework/ui/widgets/al_switch.dart';

enum RadioGroup { first, second }

class SwitchPage extends StatefulWidget {
  const SwitchPage({super.key});

  @override
  State<StatefulWidget> createState() => _SwitchPageState();
}

class _SwitchPageState extends State<SwitchPage> {
  RadioGroup _radioValue = RadioGroup.first;
  List<ALRadioItem> radioItems = [
    ALRadioItem(title: "Заголовок 1 для радиобаттона", value: RadioGroup.first),
    ALRadioItem(
        title: "Заголовок 2 для радиобаттона", value: RadioGroup.second),
  ];

  List<ALSwitchItem> switchItems = [
    ALSwitchItem(title: "Заголовок 1 для свитча", isSelected: false),
    ALSwitchItem(title: "Заголовок 2 для свитча", isSelected: true),
  ];

  @override
  Widget build(BuildContext context) {
    return ListView(
      children: [
        _buildTitle("Радиобаттон"),
        _buildRadioItem(radioItems[0], isEnabled: true),
        _buildRadioItem(radioItems[1], isEnabled: true),
        _buildRadioItem(radioItems[0], isEnabled: false),
        _buildRadioItem(radioItems[1], isEnabled: false),
        _buildTitle("Переключатель (Android)"),
        ..._buildSwitches(isEnabled: true, style: SwitchPlatformStyle.android),
        ..._buildSwitches(isEnabled: false, style: SwitchPlatformStyle.android),
        _buildTitle("Переключатель (iOS)"),
        ..._buildSwitches(isEnabled: true, style: SwitchPlatformStyle.ios),
        ..._buildSwitches(isEnabled: false, style: SwitchPlatformStyle.ios),
      ],
    );
  }

  Widget _buildTitle(String title) {
    return Padding(
      padding: const EdgeInsets.all(16),
      child: Text(
        title,
        // ignore: prefer_const_constructors
        style: TextStyle(
          fontSize: 16,
          fontWeight: FontWeight.w600,
        ),
      ),
    );
  }

  // Radio
  Widget _buildRadioItem(ALRadioItem item, {required bool isEnabled}) {
    return Align(
      alignment: Alignment.centerLeft,
      child: ALRadio<RadioGroup>(
        value: item.value,
        groupValue: _radioValue,
        isEnabled: isEnabled,
        onChanged: (value) => _radioChanged(value ?? RadioGroup.first),
      ),
    );
  }

  _radioChanged(RadioGroup value) {
    setState(() {
      _radioValue = value;
    });
  }

  // Switch
  List<Widget> _buildSwitches({
    required bool isEnabled,
    required SwitchPlatformStyle style,
  }) {
    return switchItems.map((e) {
      return _buildSwitchItem(item: e, isEnabled: isEnabled, style: style);
    }).toList();
  }

  Widget _buildSwitchItem({
    required ALSwitchItem item,
    required bool isEnabled,
    required SwitchPlatformStyle style,
  }) {
    return Align(
      alignment: Alignment.centerLeft,
      child: ALSwitch(
        platformStyle: style,
        value: item.isSelected,
        isEnabled: isEnabled,
        onChanged: (value) => _switchChanged(item, value),
      ),
    );
  }

  _switchChanged(ALSwitchItem item, bool value) {
    List<ALSwitchItem> items = switchItems
        .map((e) => e.title == item.title
            ? ALSwitchItem(title: item.title, isSelected: value)
            : e)
        .toList();
    setState(() {
      switchItems = items;
    });
  }
}
